package keystash;

import java.awt.Color;
import java.awt.Component;
import java.awt.Font;
import java.awt.FontFormatException;
import java.awt.Toolkit;
import java.awt.datatransfer.Clipboard;
import java.awt.datatransfer.StringSelection;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.ByteArrayOutputStream;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.UnsupportedEncodingException;
import java.security.InvalidAlgorithmParameterException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.spec.InvalidKeySpecException;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import javax.crypto.BadPaddingException;
import javax.crypto.IllegalBlockSizeException;
import javax.crypto.NoSuchPaddingException;
import javax.swing.JFileChooser;
import javax.swing.Timer;
import javax.swing.UIManager;
import javax.swing.plaf.ColorUIResource;
import keystash.command.Processor;
import keystash.crypto.Aes;
import keystash.crypto.Crypto;
import keystash.crypto.KeyLength;
import keystash.crypto.WordBook;
import keystash.crypto.PhraseGenerator;
import keystash.gui.Console;
import keystash.gui.Dialog;
import keystash.gui.MenuItem;
import keystash.gui.TableContent;
import keystash.http.Api;
import keystash.util.Constants;
import keystash.util.Convert;
import keystash.util.Db;
import keystash.util.Memory;
import keystash.util.PasswordStrength;
import keystash.util.Structure;
import keystash.util.Time;
import keystash.util.Token;
import org.apache.commons.codec.DecoderException;
import org.h2.tools.ChangeFileEncryption;

public class KeyStashGUI extends javax.swing.JFrame {

    public char[] secretToken;
    public static char[] globalPassword;
    public static char[] secret;
    public int tmpList;
    public static int backgroundMenu = 0;
    public static Integer row = null;
    public List<Integer> list = new ArrayList<>();
    public static boolean isWalletEncrypted = false;
    public static boolean lockClearClipboardButton = false;
    public static boolean enableApi = false;
    public static boolean guiShowWarnings = Constants.showWarnings;

    public KeyStashGUI()

            throws SQLException,
            FontFormatException,
            IOException {

        initComponents();

        ColorUIResource colorResource = new ColorUIResource(Color.CYAN.darker().darker());
        UIManager.put("nimbusOrange", colorResource);

        this.addWindowListener(new WindowAdapter() {
            @Override
            public void windowClosing(WindowEvent we) {
                StringSelection stringSelection = new StringSelection("");
                Clipboard clpbrd = Toolkit.getDefaultToolkit().getSystemClipboard();
                clpbrd.setContents(stringSelection, null);
            }
        });

        setIconAndFont();

        try {
            Structure.createWallet();
        } catch (Exception e) {
            System.err.println("Creating wallet structure and connection failed.");
        }

        try {
            Structure.createSettings();
        } catch (Exception e) {
            System.err.println("Creating database structure and connection failed.");
        }

        try {
            TableContent.insertAboutComponents();
            TableContent.getTable();
        } catch (Exception e) {
            System.err.println("Database looks encrypted. Enter master password.");
            isWalletEncrypted = true;
            Db.connectToSettings();
            MenuItem.encryptedEnableMenu(false);
            decryptDatabaseFrame.setVisible(true);
            decryptDatabaseFrame.setLocationRelativeTo(null);
        }

    }

    @SuppressWarnings({"unchecked", "CallToPrintStackTrace"})
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        newAccountFrame = new javax.swing.JFrame();
        newAccountOKButton = new javax.swing.JButton();
        newAccountGeneratePasswordButton = new javax.swing.JButton();
        newAccountSeparator = new javax.swing.JSeparator();
        newAccountCancelButton = new javax.swing.JButton();
        newAccountBackgroundLabel = new javax.swing.JLabel();
        newAccountLengthLabel = new javax.swing.JLabel();
        newAccountEntropyLabel = new javax.swing.JLabel();
        newAccountPasswordStrengthLabel = new javax.swing.JLabel();
        newAccountlPasswordConfirmFieldLabel = new javax.swing.JLabel();
        newAccountlPasswordFieldLabel = new javax.swing.JLabel();
        newAccountPasswordField = new javax.swing.JPasswordField();
        newAccountPasswordConfirmField = new javax.swing.JPasswordField();
        newAccountShowPhraseCheckBox = new javax.swing.JCheckBox();
        newAccountjProgressBar = new javax.swing.JProgressBar();
        newAccountEntropyValue = new javax.swing.JLabel();
        newAccountLengthValue = new javax.swing.JLabel();
        confirmNewAccountFrame = new javax.swing.JFrame();
        confirmNewAccountPhraseField = new javax.swing.JPasswordField();
        confirmNewAccountPhraseLabel = new javax.swing.JLabel();
        confirmNewAccountOKButton = new javax.swing.JButton();
        confirmNewAccountShowPhraseCheckBox = new javax.swing.JCheckBox();
        confirmNewAccountEntropyLabel = new javax.swing.JLabel();
        confirmNewAccountEntropyValue = new javax.swing.JLabel();
        confirmNewAccountLengthLabel = new javax.swing.JLabel();
        confirmNewAccountLengthValue = new javax.swing.JLabel();
        confirmNewAccountGenerateNewPhraseButton = new javax.swing.JButton();
        confirmNewAccountSearchAddressToggleButton = new javax.swing.JToggleButton();
        confirmNewAccountIncludeLettersField = new javax.swing.JFormattedTextField();
        confirmNewAccountAddressLabel = new javax.swing.JLabel();
        confirmNewAccountShowAddressRsLabel = new javax.swing.JLabel();
        confirmNewAccountAttemptLabel = new javax.swing.JLabel();
        confirmNewAccountAttemptValueLabel = new javax.swing.JLabel();
        confirmNewAccountBackgroundLabel = new javax.swing.JLabel();
        confirmNewAccountCancelButton = new javax.swing.JButton();
        confirmAccountSeparator = new javax.swing.JSeparator();
        showDetailPopup = new javax.swing.JPopupMenu();
        showAccountDetailsItem = new javax.swing.JMenuItem();
        showGenerateTokenItem = new javax.swing.JMenuItem();
        showCopyAddressItem = new javax.swing.JMenuItem();
        enterPrimaryPasswordAccountDetailsFrame = new javax.swing.JFrame();
        enterPrimaryPasswordAccountDetailsPasswordField = new javax.swing.JPasswordField();
        enterPrimaryPasswordAccountDetailsPasswordFieldLabel = new javax.swing.JLabel();
        enterPrimaryPasswordAccountDetailsOKButton = new javax.swing.JButton();
        enterPrimaryPasswordAccountDetailsShowPhraseCheckBox = new javax.swing.JCheckBox();
        enterPrimaryPasswordAccountDetailsBackgroundLabel = new javax.swing.JLabel();
        enterPrimaryPasswordAccountDetailsCancelButton = new javax.swing.JButton();
        enterPrimaryPasswordAccountDetailsSeparator = new javax.swing.JSeparator();
        enterPrimaryPasswordGenerateTokenFrame = new javax.swing.JFrame();
        enterPrimaryPasswordGenerateTokenPasswordField = new javax.swing.JPasswordField();
        enterPrimaryPasswordGenerateTokenPasswordFieldLabel = new javax.swing.JLabel();
        enterPrimaryPasswordGenerateTokenOKButton = new javax.swing.JButton();
        enterPrimaryPasswordGenerateTokenShowPhraseCheckBox = new javax.swing.JCheckBox();
        enterPrimaryPasswordGenerateTokenBackgroundLabel = new javax.swing.JLabel();
        enterPrimaryPasswordGenerateTokenCancelButton = new javax.swing.JButton();
        enterPrimaryPasswordGenerateTokenSeparator = new javax.swing.JSeparator();
        accountDetailsFrame = new javax.swing.JFrame();
        accountDetailsPhraseField = new javax.swing.JPasswordField();
        accountDetailsPhraseLabel = new javax.swing.JLabel();
        accountDetailsShowPhraseCheckBox = new javax.swing.JCheckBox();
        accountDetailsPublicKeyLabel = new javax.swing.JLabel();
        accountDetailsPublicKeyField = new javax.swing.JTextField();
        accountDetailsCopyButton1 = new javax.swing.JButton();
        accountDetailsCopyButton2 = new javax.swing.JButton();
        accountDetailsClearLabel = new javax.swing.JLabel();
        accountDetailsjProgressBar = new javax.swing.JProgressBar();
        accountDetailsLabelLabel = new javax.swing.JLabel();
        accountDetailsBackgroundLabel = new javax.swing.JLabel();
        accountDetailsOKButton = new javax.swing.JButton();
        accountDetailsjSeparator = new javax.swing.JSeparator();
        accountDetailsLabelField = new javax.swing.JFormattedTextField();
        generateTokenFrame = new javax.swing.JFrame();
        generateTokenCopyButton = new javax.swing.JButton();
        generateTokenClearLabel = new javax.swing.JLabel();
        generateTokenTokenDataField = new javax.swing.JTextField();
        generateTokenTokenValueLabel = new javax.swing.JLabel();
        generateTokenTokenKeyField = new javax.swing.JTextField();
        generateTokenTokenKeyLabel = new javax.swing.JLabel();
        generateTokenGenerateTokenButton = new javax.swing.JButton();
        generateTokenBackgroundLabel = new javax.swing.JLabel();
        generateTokenOKButton = new javax.swing.JButton();
        generateTokenSeparator = new javax.swing.JSeparator();
        showPreferencesFrame = new javax.swing.JFrame();
        showPreferencesWarningsLabel = new javax.swing.JLabel();
        showPreferencesWarningsCheckbox = new javax.swing.JCheckBox();
        showPreferencesClearClipboardSpinner = new javax.swing.JSpinner();
        showPreferencesClearClipboardLabel = new javax.swing.JLabel();
        showPreferencesPhraseBlocksSpinner = new javax.swing.JSpinner();
        showPreferencesPhraseBlocksLabel = new javax.swing.JLabel();
        showPreferencesRandomGenerationLabel = new javax.swing.JLabel();
        showPreferencesRandomGenerationCheckbox = new javax.swing.JCheckBox();
        showPreferencesLengthMinimumLabel = new javax.swing.JLabel();
        showPreferencesLengthMinimumMinSpinner = new javax.swing.JSpinner();
        showPreferencesLengthMinimumMaxSpinner = new javax.swing.JSpinner();
        showPreferencesLengthMaximumLabel = new javax.swing.JLabel();
        showPreferencesLengthMaximumMaxSpinner = new javax.swing.JSpinner();
        showPreferencesLengthMaximumMinSpinner = new javax.swing.JSpinner();
        showPreferencesLowerCaseLabel = new javax.swing.JLabel();
        showPreferencesLowerCaseMinSpinner = new javax.swing.JSpinner();
        showPreferencesLowerCaseMaxSpinner = new javax.swing.JSpinner();
        showPreferencesUpperCaseLabel = new javax.swing.JLabel();
        showPreferencesUpperCaseMinSpinner = new javax.swing.JSpinner();
        showPreferencesUpperCaseMaxSpinner = new javax.swing.JSpinner();
        showPreferencesNumeraryLabel = new javax.swing.JLabel();
        showPreferencesNumeraryMinSpinner = new javax.swing.JSpinner();
        showPreferencesNumeraryMaxSpinner = new javax.swing.JSpinner();
        showPreferencesSpecialCharLabel = new javax.swing.JLabel();
        showPreferencesSpecialCharMinSpinner = new javax.swing.JSpinner();
        showPreferencesSpecialCharMaxSpinner = new javax.swing.JSpinner();
        showPreferencesResetSettingsButton = new javax.swing.JButton();
        showPreferencesWhitespaceLabel = new javax.swing.JLabel();
        showPreferencesWhitespaceCheckbox = new javax.swing.JCheckBox();
        showPreferencesIterationLabel = new javax.swing.JLabel();
        showPreferencesIterationSpinner = new javax.swing.JSpinner();
        showPreferenceKeySizesLabel = new javax.swing.JLabel();
        showPreferencesKeySizeComboBox = new javax.swing.JComboBox();
        showPreferecesBackgroundLabel = new javax.swing.JLabel();
        showPreferencesjSeparator = new javax.swing.JSeparator();
        showPreferencesOKButton = new javax.swing.JButton();
        showPreferencesANSILabel = new javax.swing.JLabel();
        showPreferencesANSICheckbox = new javax.swing.JCheckBox();
        aboutFrame = new javax.swing.JFrame();
        aboutBackgroundLabel = new javax.swing.JLabel();
        aboutScrollPane = new javax.swing.JScrollPane();
        aboutTable = new javax.swing.JTable();
        aboutjSeparator = new javax.swing.JSeparator();
        aboutOkButton = new javax.swing.JButton();
        aboutKeyStashDevelopersLabel = new javax.swing.JLabel();
        aboutKeyStashLicenseLabel = new javax.swing.JLabel();
        aboutKeyStashLicenseLinkLabel = new javax.swing.JLabel();
        aboutKeyStashExperimentelLabel = new javax.swing.JLabel();
        aboutKeyStashIncludesSoftwareLabel = new javax.swing.JLabel();
        aboutKeyStashIncludesSoftwareLinkLabel = new javax.swing.JLabel();
        encryptDatabaseFrame = new javax.swing.JFrame();
        encryptDatabasePasswordField = new javax.swing.JPasswordField();
        encryptDatabasePasswordFieldLabel = new javax.swing.JLabel();
        encryptDatabaseOKButton = new javax.swing.JButton();
        encryptDatabasePasswordConfirmField = new javax.swing.JPasswordField();
        encryptDatabasePasswordConfirmFieldLabel = new javax.swing.JLabel();
        encryptDatabaseShowPhraseCheckBox = new javax.swing.JCheckBox();
        encryptDatabasejProgressBar = new javax.swing.JProgressBar();
        encryptDatabasePasswordStrengthLabel = new javax.swing.JLabel();
        encryptDatabaseEntropyLabel = new javax.swing.JLabel();
        encryptDatabaseEntropyValue = new javax.swing.JLabel();
        encryptDatabaseLengthLabel = new javax.swing.JLabel();
        encryptDatabaseLengthValue = new javax.swing.JLabel();
        encryptDatabaseGeneratePasswordButton = new javax.swing.JButton();
        encryptDatabaseBackgroundLabel = new javax.swing.JLabel();
        encryptDatabaseSeparator = new javax.swing.JSeparator();
        encryptDatabaseCancelButton = new javax.swing.JButton();
        decryptDatabaseFrame = new javax.swing.JFrame();
        decryptDatabasePasswordField = new javax.swing.JPasswordField();
        decryptDatabasePasswordFieldLabel = new javax.swing.JLabel();
        decryptDatabaseOKButton = new javax.swing.JButton();
        decryptDatabaseShowPhraseCheckBox = new javax.swing.JCheckBox();
        decryptDatabaseBackgroundLabel = new javax.swing.JLabel();
        decryptDatabaseSeparator = new javax.swing.JSeparator();
        decryptDatabaseCancelButton = new javax.swing.JButton();
        accountScrollPane = new javax.swing.JScrollPane();
        accountTable = new javax.swing.JTable();
        mainMenuBar = new javax.swing.JMenuBar();
        fileMenu = new javax.swing.JMenu();
        accountMenuItem = new javax.swing.JMenuItem();
        backupMenuItem = new javax.swing.JMenuItem();
        fileMenuSeperator = new javax.swing.JPopupMenu.Separator();
        exitMenuItem = new javax.swing.JMenuItem();
        settingsMenu = new javax.swing.JMenu();
        enableApiMenuItem = new javax.swing.JCheckBoxMenuItem();
        encryptDatabaseMenuItem = new javax.swing.JMenuItem();
        preferencesMenuItem = new javax.swing.JMenuItem();
        helpMenu = new javax.swing.JMenu();
        aboutMenuItem = new javax.swing.JMenuItem();

        newAccountFrame.setTitle("New Account");
        newAccountFrame.setAlwaysOnTop(true);
        newAccountFrame.setBackground(new java.awt.Color(255, 255, 255));
        newAccountFrame.setBounds(new java.awt.Rectangle(0, 0, 0, 0));
        newAccountFrame.setCursor(new java.awt.Cursor(java.awt.Cursor.DEFAULT_CURSOR));
        newAccountFrame.setMinimumSize(new java.awt.Dimension(520, 320));
        newAccountFrame.setResizable(false);

        newAccountOKButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        newAccountOKButton.setMnemonic('O');
        newAccountOKButton.setText("OK");
        newAccountOKButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                newAccountOKButtonActionPerformed(evt);
            }
        });

        newAccountGeneratePasswordButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        newAccountGeneratePasswordButton.setMnemonic('G');
        newAccountGeneratePasswordButton.setText("Generate Memorable");
        newAccountGeneratePasswordButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                newAccountGeneratePasswordButtonActionPerformed(evt);
            }
        });

        newAccountSeparator.setMaximumSize(new java.awt.Dimension(520, 5));
        newAccountSeparator.setMinimumSize(new java.awt.Dimension(520, 5));

        newAccountCancelButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        newAccountCancelButton.setMnemonic('C');
        newAccountCancelButton.setText("Cancel");
        newAccountCancelButton.setFocusable(false);
        newAccountCancelButton.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        newAccountCancelButton.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        newAccountCancelButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                newAccountCancelButtonActionPerformed(evt);
            }
        });

        newAccountBackgroundLabel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/keystash/resources/newAccountBG.png"))); // NOI18N
        newAccountBackgroundLabel.setToolTipText(null);

        newAccountLengthLabel.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        newAccountLengthLabel.setText("Length:");
        newAccountLengthLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        newAccountLengthLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        newAccountLengthLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        newAccountEntropyLabel.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        newAccountEntropyLabel.setText("Entropy Bits:");
        newAccountEntropyLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        newAccountEntropyLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        newAccountEntropyLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        newAccountPasswordStrengthLabel.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        newAccountPasswordStrengthLabel.setText("Complexity: ");
        newAccountPasswordStrengthLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        newAccountPasswordStrengthLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        newAccountPasswordStrengthLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        newAccountlPasswordConfirmFieldLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        newAccountlPasswordConfirmFieldLabel.setText("Confirm Password:");
        newAccountlPasswordConfirmFieldLabel.setMaximumSize(new java.awt.Dimension(140, 18));
        newAccountlPasswordConfirmFieldLabel.setMinimumSize(new java.awt.Dimension(140, 18));
        newAccountlPasswordConfirmFieldLabel.setPreferredSize(new java.awt.Dimension(140, 18));

        newAccountlPasswordFieldLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        newAccountlPasswordFieldLabel.setText("Primary Password:");
        newAccountlPasswordFieldLabel.setMaximumSize(new java.awt.Dimension(140, 18));
        newAccountlPasswordFieldLabel.setMinimumSize(new java.awt.Dimension(140, 18));
        newAccountlPasswordFieldLabel.setPreferredSize(new java.awt.Dimension(140, 18));

        newAccountPasswordField.setColumns(50);
        newAccountPasswordField.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        newAccountPasswordField.setMaximumSize(new java.awt.Dimension(290, 30));
        newAccountPasswordField.setMinimumSize(new java.awt.Dimension(290, 30));
        newAccountPasswordField.setPreferredSize(new java.awt.Dimension(290, 30));
        newAccountPasswordField.addKeyListener(new java.awt.event.KeyAdapter() {
            public void keyReleased(java.awt.event.KeyEvent evt) {
                newAccountPasswordFieldKeyReleased(evt);
            }
            public void keyTyped(java.awt.event.KeyEvent evt) {
                newAccountPasswordFieldKeyTyped(evt);
            }
        });

        newAccountPasswordConfirmField.setColumns(50);
        newAccountPasswordConfirmField.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        newAccountPasswordConfirmField.setMaximumSize(new java.awt.Dimension(290, 30));
        newAccountPasswordConfirmField.setMinimumSize(new java.awt.Dimension(290, 30));
        newAccountPasswordConfirmField.setPreferredSize(new java.awt.Dimension(290, 30));

        newAccountShowPhraseCheckBox.setFont(new java.awt.Font("Open Sans", 1, 9)); // NOI18N
        newAccountShowPhraseCheckBox.setText("Show");
        newAccountShowPhraseCheckBox.setFocusable(false);
        newAccountShowPhraseCheckBox.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        newAccountShowPhraseCheckBox.setMaximumSize(new java.awt.Dimension(37, 30));
        newAccountShowPhraseCheckBox.setMinimumSize(new java.awt.Dimension(37, 30));
        newAccountShowPhraseCheckBox.setPreferredSize(new java.awt.Dimension(37, 30));
        newAccountShowPhraseCheckBox.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        newAccountShowPhraseCheckBox.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                newAccountShowPhraseCheckBoxActionPerformed(evt);
            }
        });

        newAccountjProgressBar.setBorderPainted(true);
        newAccountjProgressBar.setDebugGraphicsOptions(javax.swing.DebugGraphics.NONE_OPTION);
        newAccountjProgressBar.setMaximumSize(new java.awt.Dimension(290, 20));
        newAccountjProgressBar.setMinimumSize(new java.awt.Dimension(290, 20));
        newAccountjProgressBar.setPreferredSize(new java.awt.Dimension(290, 20));

        newAccountEntropyValue.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        newAccountEntropyValue.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        newAccountEntropyValue.setText("0.0");
        newAccountEntropyValue.setToolTipText(null);
        newAccountEntropyValue.setMaximumSize(new java.awt.Dimension(290, 18));
        newAccountEntropyValue.setMinimumSize(new java.awt.Dimension(290, 18));
        newAccountEntropyValue.setPreferredSize(new java.awt.Dimension(290, 18));
        newAccountEntropyValue.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);

        newAccountLengthValue.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        newAccountLengthValue.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        newAccountLengthValue.setText("0");
        newAccountLengthValue.setMaximumSize(new java.awt.Dimension(290, 18));
        newAccountLengthValue.setMinimumSize(new java.awt.Dimension(290, 18));
        newAccountLengthValue.setPreferredSize(new java.awt.Dimension(290, 18));

        javax.swing.GroupLayout newAccountFrameLayout = new javax.swing.GroupLayout(newAccountFrame.getContentPane());
        newAccountFrame.getContentPane().setLayout(newAccountFrameLayout);
        newAccountFrameLayout.setHorizontalGroup(
            newAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(newAccountFrameLayout.createSequentialGroup()
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addComponent(newAccountGeneratePasswordButton)
                .addGap(5, 5, 5)
                .addComponent(newAccountOKButton)
                .addGap(5, 5, 5)
                .addComponent(newAccountCancelButton)
                .addGap(32, 32, 32))
            .addGroup(newAccountFrameLayout.createSequentialGroup()
                .addGroup(newAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(newAccountSeparator, javax.swing.GroupLayout.PREFERRED_SIZE, 520, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(newAccountBackgroundLabel))
                .addGap(0, 0, Short.MAX_VALUE))
            .addGroup(newAccountFrameLayout.createSequentialGroup()
                .addGap(10, 10, 10)
                .addGroup(newAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(newAccountlPasswordFieldLabel, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addGroup(javax.swing.GroupLayout.Alignment.LEADING, newAccountFrameLayout.createSequentialGroup()
                        .addGroup(newAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(newAccountEntropyLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(newAccountLengthLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                        .addGroup(newAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(newAccountLengthValue, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.PREFERRED_SIZE, 290, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(newAccountEntropyValue, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)))
                    .addGroup(javax.swing.GroupLayout.Alignment.LEADING, newAccountFrameLayout.createSequentialGroup()
                        .addGroup(newAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(newAccountlPasswordConfirmFieldLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(newAccountPasswordStrengthLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addGap(3, 3, 3)
                        .addGroup(newAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, newAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                                .addComponent(newAccountPasswordConfirmField, javax.swing.GroupLayout.PREFERRED_SIZE, 290, javax.swing.GroupLayout.PREFERRED_SIZE)
                                .addComponent(newAccountPasswordField, javax.swing.GroupLayout.PREFERRED_SIZE, 290, javax.swing.GroupLayout.PREFERRED_SIZE))
                            .addComponent(newAccountjProgressBar, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.PREFERRED_SIZE, 290, javax.swing.GroupLayout.PREFERRED_SIZE))))
                .addGap(10, 10, 10)
                .addComponent(newAccountShowPhraseCheckBox, javax.swing.GroupLayout.PREFERRED_SIZE, 37, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(30, 30, 30))
        );
        newAccountFrameLayout.setVerticalGroup(
            newAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, newAccountFrameLayout.createSequentialGroup()
                .addComponent(newAccountBackgroundLabel)
                .addGap(10, 10, 10)
                .addGroup(newAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(newAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                        .addComponent(newAccountPasswordField, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addComponent(newAccountlPasswordFieldLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addComponent(newAccountShowPhraseCheckBox, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(12, 12, 12)
                .addGroup(newAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(newAccountPasswordConfirmField, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(newAccountlPasswordConfirmFieldLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(12, 12, 12)
                .addGroup(newAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(newAccountPasswordStrengthLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(newAccountjProgressBar, javax.swing.GroupLayout.PREFERRED_SIZE, 20, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(12, 12, 12)
                .addGroup(newAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(newAccountEntropyLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(newAccountEntropyValue, javax.swing.GroupLayout.PREFERRED_SIZE, 15, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(12, 12, 12)
                .addGroup(newAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(newAccountLengthLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(newAccountLengthValue, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(10, 10, 10)
                .addComponent(newAccountSeparator, javax.swing.GroupLayout.PREFERRED_SIZE, 5, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addGroup(newAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(newAccountCancelButton)
                    .addGroup(newAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                        .addComponent(newAccountOKButton)
                        .addComponent(newAccountGeneratePasswordButton)))
                .addGap(10, 10, 10))
        );

        newAccountjProgressBar.setBackground(Color.red);
        newAccountjProgressBar.setForeground(Color.red);

        confirmNewAccountFrame.setTitle("Confirm Account");
        confirmNewAccountFrame.setAlwaysOnTop(true);
        confirmNewAccountFrame.setBounds(new java.awt.Rectangle(0, 0, 0, 0));
        confirmNewAccountFrame.setMinimumSize(new java.awt.Dimension(520, 320));
        confirmNewAccountFrame.setResizable(false);

        confirmNewAccountPhraseField.setEditable(false);
        confirmNewAccountPhraseField.setColumns(50);
        confirmNewAccountPhraseField.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        confirmNewAccountPhraseField.setMaximumSize(new java.awt.Dimension(290, 30));
        confirmNewAccountPhraseField.setMinimumSize(new java.awt.Dimension(290, 30));
        confirmNewAccountPhraseField.setPreferredSize(new java.awt.Dimension(290, 30));
        confirmNewAccountPhraseField.setVerifyInputWhenFocusTarget(false);

        confirmNewAccountPhraseLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        confirmNewAccountPhraseLabel.setText("Private Phrase:");
        confirmNewAccountPhraseLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        confirmNewAccountPhraseLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        confirmNewAccountPhraseLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        confirmNewAccountOKButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        confirmNewAccountOKButton.setMnemonic('O');
        confirmNewAccountOKButton.setText("OK");
        confirmNewAccountOKButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                confirmNewAccountOKButtonActionPerformed(evt);
            }
        });

        confirmNewAccountShowPhraseCheckBox.setFont(new java.awt.Font("Open Sans", 1, 9)); // NOI18N
        confirmNewAccountShowPhraseCheckBox.setText("Show");
        confirmNewAccountShowPhraseCheckBox.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        confirmNewAccountShowPhraseCheckBox.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        confirmNewAccountShowPhraseCheckBox.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        confirmNewAccountShowPhraseCheckBox.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                confirmNewAccountShowPhraseCheckBoxActionPerformed(evt);
            }
        });

        confirmNewAccountEntropyLabel.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        confirmNewAccountEntropyLabel.setText("Entropy Bits:");
        confirmNewAccountEntropyLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        confirmNewAccountEntropyLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        confirmNewAccountEntropyLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        confirmNewAccountEntropyValue.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        confirmNewAccountEntropyValue.setText("0.0");
        confirmNewAccountEntropyValue.setToolTipText(null);
        confirmNewAccountEntropyValue.setMaximumSize(new java.awt.Dimension(290, 18));
        confirmNewAccountEntropyValue.setMinimumSize(new java.awt.Dimension(290, 18));
        confirmNewAccountEntropyValue.setPreferredSize(new java.awt.Dimension(290, 18));

        confirmNewAccountLengthLabel.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        confirmNewAccountLengthLabel.setText("Length:");
        confirmNewAccountLengthLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        confirmNewAccountLengthLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        confirmNewAccountLengthLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        confirmNewAccountLengthValue.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        confirmNewAccountLengthValue.setText("0");
        confirmNewAccountLengthValue.setMaximumSize(new java.awt.Dimension(290, 18));
        confirmNewAccountLengthValue.setMinimumSize(new java.awt.Dimension(290, 18));
        confirmNewAccountLengthValue.setPreferredSize(new java.awt.Dimension(290, 18));

        confirmNewAccountGenerateNewPhraseButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        confirmNewAccountGenerateNewPhraseButton.setMnemonic('G');
        confirmNewAccountGenerateNewPhraseButton.setText("Generate new phrase");
        confirmNewAccountGenerateNewPhraseButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                confirmNewAccountGenerateNewPhraseButtonActionPerformed(evt);
            }
        });

        confirmNewAccountSearchAddressToggleButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        confirmNewAccountSearchAddressToggleButton.setMnemonic('S');
        confirmNewAccountSearchAddressToggleButton.setText("Search");
        confirmNewAccountSearchAddressToggleButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                confirmNewAccountSearchAddressToggleButtonActionPerformed(evt);
            }
        });

        try {
            confirmNewAccountIncludeLettersField.setFormatterFactory(new javax.swing.text.DefaultFormatterFactory(new javax.swing.text.MaskFormatter("NXT-*****")));
        } catch (java.text.ParseException ex) {
            ex.printStackTrace();
        }
        confirmNewAccountIncludeLettersField.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        confirmNewAccountIncludeLettersField.setMaximumSize(new java.awt.Dimension(90, 30));
        confirmNewAccountIncludeLettersField.setMinimumSize(new java.awt.Dimension(90, 30));
        confirmNewAccountIncludeLettersField.setName(""); // NOI18N
        confirmNewAccountIncludeLettersField.setPreferredSize(new java.awt.Dimension(90, 30));

        confirmNewAccountAddressLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        confirmNewAccountAddressLabel.setText("NXT Address:");
        confirmNewAccountAddressLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        confirmNewAccountAddressLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        confirmNewAccountAddressLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        confirmNewAccountShowAddressRsLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        confirmNewAccountShowAddressRsLabel.setMaximumSize(new java.awt.Dimension(290, 30));
        confirmNewAccountShowAddressRsLabel.setMinimumSize(new java.awt.Dimension(290, 30));

        confirmNewAccountAttemptLabel.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        confirmNewAccountAttemptLabel.setText("Attempt:");
        confirmNewAccountAttemptLabel.setEnabled(false);
        confirmNewAccountAttemptLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        confirmNewAccountAttemptLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        confirmNewAccountAttemptLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        confirmNewAccountAttemptValueLabel.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        confirmNewAccountAttemptValueLabel.setText("0");
        confirmNewAccountAttemptValueLabel.setEnabled(false);
        confirmNewAccountAttemptValueLabel.setMaximumSize(new java.awt.Dimension(290, 18));
        confirmNewAccountAttemptValueLabel.setMinimumSize(new java.awt.Dimension(290, 18));
        confirmNewAccountAttemptValueLabel.setPreferredSize(new java.awt.Dimension(290, 18));

        confirmNewAccountBackgroundLabel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/keystash/resources/confirmAccountBG.png"))); // NOI18N
        confirmNewAccountBackgroundLabel.setToolTipText(null);

        confirmNewAccountCancelButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        confirmNewAccountCancelButton.setMnemonic('C');
        confirmNewAccountCancelButton.setText("Cancel");
        confirmNewAccountCancelButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                confirmNewAccountCancelButtonActionPerformed(evt);
            }
        });

        confirmAccountSeparator.setMaximumSize(new java.awt.Dimension(520, 5));
        confirmAccountSeparator.setMinimumSize(new java.awt.Dimension(520, 5));
        confirmAccountSeparator.setName(""); // NOI18N
        confirmAccountSeparator.setPreferredSize(new java.awt.Dimension(520, 5));

        javax.swing.GroupLayout confirmNewAccountFrameLayout = new javax.swing.GroupLayout(confirmNewAccountFrame.getContentPane());
        confirmNewAccountFrame.getContentPane().setLayout(confirmNewAccountFrameLayout);
        confirmNewAccountFrameLayout.setHorizontalGroup(
            confirmNewAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(confirmNewAccountFrameLayout.createSequentialGroup()
                .addGroup(confirmNewAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addComponent(confirmNewAccountBackgroundLabel)
                    .addComponent(confirmAccountSeparator, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                .addGap(0, 0, Short.MAX_VALUE))
            .addGroup(confirmNewAccountFrameLayout.createSequentialGroup()
                .addGap(10, 10, 10)
                .addGroup(confirmNewAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(confirmNewAccountFrameLayout.createSequentialGroup()
                        .addComponent(confirmNewAccountIncludeLettersField, javax.swing.GroupLayout.PREFERRED_SIZE, 90, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addGap(5, 5, 5)
                        .addComponent(confirmNewAccountSearchAddressToggleButton)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                        .addComponent(confirmNewAccountGenerateNewPhraseButton)
                        .addGap(5, 5, 5)
                        .addComponent(confirmNewAccountOKButton)
                        .addGap(5, 5, 5)
                        .addComponent(confirmNewAccountCancelButton))
                    .addGroup(confirmNewAccountFrameLayout.createSequentialGroup()
                        .addGroup(confirmNewAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(confirmNewAccountPhraseLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(confirmNewAccountEntropyLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(confirmNewAccountLengthLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(confirmNewAccountAttemptLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(confirmNewAccountAddressLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addGap(23, 23, 23)
                        .addGroup(confirmNewAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(confirmNewAccountLengthValue, javax.swing.GroupLayout.PREFERRED_SIZE, 290, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(confirmNewAccountAttemptValueLabel, javax.swing.GroupLayout.PREFERRED_SIZE, 290, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addGroup(confirmNewAccountFrameLayout.createSequentialGroup()
                                .addGroup(confirmNewAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
                                    .addComponent(confirmNewAccountShowAddressRsLabel, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                    .addComponent(confirmNewAccountPhraseField, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.PREFERRED_SIZE, 1, Short.MAX_VALUE)
                                    .addComponent(confirmNewAccountEntropyValue, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                                .addGap(10, 10, 10)
                                .addComponent(confirmNewAccountShowPhraseCheckBox)))))
                .addGap(32, 32, 32))
        );

        confirmNewAccountFrameLayout.linkSize(javax.swing.SwingConstants.HORIZONTAL, new java.awt.Component[] {confirmNewAccountAttemptValueLabel, confirmNewAccountLengthValue});

        confirmNewAccountFrameLayout.setVerticalGroup(
            confirmNewAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, confirmNewAccountFrameLayout.createSequentialGroup()
                .addComponent(confirmNewAccountBackgroundLabel)
                .addGroup(confirmNewAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(confirmNewAccountFrameLayout.createSequentialGroup()
                        .addGap(10, 10, 10)
                        .addComponent(confirmNewAccountShowAddressRsLabel, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addGroup(confirmNewAccountFrameLayout.createSequentialGroup()
                        .addGap(18, 18, 18)
                        .addComponent(confirmNewAccountAddressLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)))
                .addGap(12, 12, 12)
                .addGroup(confirmNewAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(confirmNewAccountFrameLayout.createSequentialGroup()
                        .addGroup(confirmNewAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(confirmNewAccountPhraseLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(confirmNewAccountPhraseField, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addGap(12, 12, 12)
                        .addGroup(confirmNewAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addGroup(confirmNewAccountFrameLayout.createSequentialGroup()
                                .addComponent(confirmNewAccountEntropyLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                                .addComponent(confirmNewAccountLengthLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                                .addComponent(confirmNewAccountAttemptLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                            .addGroup(confirmNewAccountFrameLayout.createSequentialGroup()
                                .addComponent(confirmNewAccountEntropyValue, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                                .addGap(12, 12, 12)
                                .addComponent(confirmNewAccountLengthValue, javax.swing.GroupLayout.PREFERRED_SIZE, 18, javax.swing.GroupLayout.PREFERRED_SIZE)
                                .addGap(12, 12, 12)
                                .addComponent(confirmNewAccountAttemptValueLabel, javax.swing.GroupLayout.PREFERRED_SIZE, 18, javax.swing.GroupLayout.PREFERRED_SIZE))))
                    .addComponent(confirmNewAccountShowPhraseCheckBox))
                .addGap(10, 10, 10)
                .addComponent(confirmAccountSeparator, javax.swing.GroupLayout.PREFERRED_SIZE, 5, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addGroup(confirmNewAccountFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(confirmNewAccountOKButton)
                    .addComponent(confirmNewAccountGenerateNewPhraseButton)
                    .addComponent(confirmNewAccountCancelButton)
                    .addComponent(confirmNewAccountSearchAddressToggleButton)
                    .addComponent(confirmNewAccountIncludeLettersField, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(10, 10, 10))
        );

        showDetailPopup.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N

        showAccountDetailsItem.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showAccountDetailsItem.setText("Account Details");
        showAccountDetailsItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                showAccountDetailsItemActionPerformed(evt);
            }
        });
        showDetailPopup.add(showAccountDetailsItem);

        showGenerateTokenItem.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showGenerateTokenItem.setText("Generate Token");
        showGenerateTokenItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                showGenerateTokenItemActionPerformed(evt);
            }
        });
        showDetailPopup.add(showGenerateTokenItem);

        showCopyAddressItem.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showCopyAddressItem.setText("Copy To Clipboard");
        showCopyAddressItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                showCopyAddressItemActionPerformed(evt);
            }
        });
        showDetailPopup.add(showCopyAddressItem);

        enterPrimaryPasswordAccountDetailsFrame.setTitle("Open Account Details");
        enterPrimaryPasswordAccountDetailsFrame.setAlwaysOnTop(true);
        enterPrimaryPasswordAccountDetailsFrame.setBounds(new java.awt.Rectangle(0, 0, 0, 0));
        enterPrimaryPasswordAccountDetailsFrame.setMinimumSize(new java.awt.Dimension(520, 190));
        enterPrimaryPasswordAccountDetailsFrame.setResizable(false);

        enterPrimaryPasswordAccountDetailsPasswordField.setColumns(50);
        enterPrimaryPasswordAccountDetailsPasswordField.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        enterPrimaryPasswordAccountDetailsPasswordField.setPreferredSize(new java.awt.Dimension(290, 30));

        enterPrimaryPasswordAccountDetailsPasswordFieldLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        enterPrimaryPasswordAccountDetailsPasswordFieldLabel.setText("Primary Password:");
        enterPrimaryPasswordAccountDetailsPasswordFieldLabel.setMaximumSize(new java.awt.Dimension(140, 18));
        enterPrimaryPasswordAccountDetailsPasswordFieldLabel.setMinimumSize(new java.awt.Dimension(140, 18));
        enterPrimaryPasswordAccountDetailsPasswordFieldLabel.setPreferredSize(new java.awt.Dimension(140, 18));

        enterPrimaryPasswordAccountDetailsOKButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        enterPrimaryPasswordAccountDetailsOKButton.setMnemonic('O');
        enterPrimaryPasswordAccountDetailsOKButton.setText("OK");
        enterPrimaryPasswordAccountDetailsOKButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                enterPrimaryPasswordAccountDetailsOKButtonActionPerformed(evt);
            }
        });

        enterPrimaryPasswordAccountDetailsShowPhraseCheckBox.setFont(new java.awt.Font("Open Sans", 1, 9)); // NOI18N
        enterPrimaryPasswordAccountDetailsShowPhraseCheckBox.setText("Show");
        enterPrimaryPasswordAccountDetailsShowPhraseCheckBox.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        enterPrimaryPasswordAccountDetailsShowPhraseCheckBox.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        enterPrimaryPasswordAccountDetailsShowPhraseCheckBox.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                enterPrimaryPasswordAccountDetailsShowPhraseCheckBoxActionPerformed(evt);
            }
        });

        enterPrimaryPasswordAccountDetailsBackgroundLabel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/keystash/resources/primaryPasswordAccountDetailsBG.png"))); // NOI18N
        enterPrimaryPasswordAccountDetailsBackgroundLabel.setToolTipText(null);

        enterPrimaryPasswordAccountDetailsCancelButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        enterPrimaryPasswordAccountDetailsCancelButton.setMnemonic('C');
        enterPrimaryPasswordAccountDetailsCancelButton.setText("Cancel");
        enterPrimaryPasswordAccountDetailsCancelButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                enterPrimaryPasswordAccountDetailsCancelButtonActionPerformed(evt);
            }
        });

        enterPrimaryPasswordAccountDetailsSeparator.setPreferredSize(new java.awt.Dimension(520, 5));

        javax.swing.GroupLayout enterPrimaryPasswordAccountDetailsFrameLayout = new javax.swing.GroupLayout(enterPrimaryPasswordAccountDetailsFrame.getContentPane());
        enterPrimaryPasswordAccountDetailsFrame.getContentPane().setLayout(enterPrimaryPasswordAccountDetailsFrameLayout);
        enterPrimaryPasswordAccountDetailsFrameLayout.setHorizontalGroup(
            enterPrimaryPasswordAccountDetailsFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(enterPrimaryPasswordAccountDetailsFrameLayout.createSequentialGroup()
                .addGap(10, 10, 10)
                .addComponent(enterPrimaryPasswordAccountDetailsPasswordFieldLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(3, 3, 3)
                .addComponent(enterPrimaryPasswordAccountDetailsPasswordField, javax.swing.GroupLayout.PREFERRED_SIZE, 290, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addComponent(enterPrimaryPasswordAccountDetailsShowPhraseCheckBox)
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
            .addGroup(enterPrimaryPasswordAccountDetailsFrameLayout.createSequentialGroup()
                .addGroup(enterPrimaryPasswordAccountDetailsFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
                    .addComponent(enterPrimaryPasswordAccountDetailsSeparator, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(enterPrimaryPasswordAccountDetailsBackgroundLabel))
                .addGap(0, 0, Short.MAX_VALUE))
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, enterPrimaryPasswordAccountDetailsFrameLayout.createSequentialGroup()
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addComponent(enterPrimaryPasswordAccountDetailsOKButton)
                .addGap(5, 5, 5)
                .addComponent(enterPrimaryPasswordAccountDetailsCancelButton)
                .addGap(32, 32, 32))
        );
        enterPrimaryPasswordAccountDetailsFrameLayout.setVerticalGroup(
            enterPrimaryPasswordAccountDetailsFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, enterPrimaryPasswordAccountDetailsFrameLayout.createSequentialGroup()
                .addComponent(enterPrimaryPasswordAccountDetailsBackgroundLabel, javax.swing.GroupLayout.PREFERRED_SIZE, 60, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addGroup(enterPrimaryPasswordAccountDetailsFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(enterPrimaryPasswordAccountDetailsFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                        .addComponent(enterPrimaryPasswordAccountDetailsPasswordFieldLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addComponent(enterPrimaryPasswordAccountDetailsPasswordField, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addComponent(enterPrimaryPasswordAccountDetailsShowPhraseCheckBox))
                .addGap(10, 10, 10)
                .addComponent(enterPrimaryPasswordAccountDetailsSeparator, javax.swing.GroupLayout.PREFERRED_SIZE, 5, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addGroup(enterPrimaryPasswordAccountDetailsFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(enterPrimaryPasswordAccountDetailsOKButton)
                    .addComponent(enterPrimaryPasswordAccountDetailsCancelButton))
                .addGap(10, 10, 10))
        );

        enterPrimaryPasswordGenerateTokenFrame.setTitle("Open Generate Token");
        enterPrimaryPasswordGenerateTokenFrame.setAlwaysOnTop(true);
        enterPrimaryPasswordGenerateTokenFrame.setBounds(new java.awt.Rectangle(0, 0, 0, 0));
        enterPrimaryPasswordGenerateTokenFrame.setMinimumSize(new java.awt.Dimension(520, 190));
        enterPrimaryPasswordGenerateTokenFrame.setResizable(false);

        enterPrimaryPasswordGenerateTokenPasswordField.setColumns(50);
        enterPrimaryPasswordGenerateTokenPasswordField.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        enterPrimaryPasswordGenerateTokenPasswordField.setMaximumSize(new java.awt.Dimension(290, 30));
        enterPrimaryPasswordGenerateTokenPasswordField.setMinimumSize(new java.awt.Dimension(290, 30));
        enterPrimaryPasswordGenerateTokenPasswordField.setPreferredSize(new java.awt.Dimension(290, 30));

        enterPrimaryPasswordGenerateTokenPasswordFieldLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        enterPrimaryPasswordGenerateTokenPasswordFieldLabel.setText("Primary Password:");
        enterPrimaryPasswordGenerateTokenPasswordFieldLabel.setMaximumSize(new java.awt.Dimension(140, 18));
        enterPrimaryPasswordGenerateTokenPasswordFieldLabel.setMinimumSize(new java.awt.Dimension(140, 18));
        enterPrimaryPasswordGenerateTokenPasswordFieldLabel.setPreferredSize(new java.awt.Dimension(140, 18));

        enterPrimaryPasswordGenerateTokenOKButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        enterPrimaryPasswordGenerateTokenOKButton.setMnemonic('O');
        enterPrimaryPasswordGenerateTokenOKButton.setText("OK");
        enterPrimaryPasswordGenerateTokenOKButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                enterPrimaryPasswordGenerateTokenOKButtonActionPerformed(evt);
            }
        });

        enterPrimaryPasswordGenerateTokenShowPhraseCheckBox.setFont(new java.awt.Font("Open Sans", 1, 9)); // NOI18N
        enterPrimaryPasswordGenerateTokenShowPhraseCheckBox.setText("Show");
        enterPrimaryPasswordGenerateTokenShowPhraseCheckBox.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        enterPrimaryPasswordGenerateTokenShowPhraseCheckBox.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        enterPrimaryPasswordGenerateTokenShowPhraseCheckBox.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                enterPrimaryPasswordGenerateTokenShowPhraseCheckBoxActionPerformed(evt);
            }
        });

        enterPrimaryPasswordGenerateTokenBackgroundLabel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/keystash/resources/primaryPasswordTokenBG.png"))); // NOI18N
        enterPrimaryPasswordGenerateTokenBackgroundLabel.setToolTipText(null);

        enterPrimaryPasswordGenerateTokenCancelButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        enterPrimaryPasswordGenerateTokenCancelButton.setMnemonic('C');
        enterPrimaryPasswordGenerateTokenCancelButton.setText("Cancel");
        enterPrimaryPasswordGenerateTokenCancelButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                enterPrimaryPasswordGenerateTokenCancelButtonActionPerformed(evt);
            }
        });

        enterPrimaryPasswordGenerateTokenSeparator.setPreferredSize(new java.awt.Dimension(520, 5));

        javax.swing.GroupLayout enterPrimaryPasswordGenerateTokenFrameLayout = new javax.swing.GroupLayout(enterPrimaryPasswordGenerateTokenFrame.getContentPane());
        enterPrimaryPasswordGenerateTokenFrame.getContentPane().setLayout(enterPrimaryPasswordGenerateTokenFrameLayout);
        enterPrimaryPasswordGenerateTokenFrameLayout.setHorizontalGroup(
            enterPrimaryPasswordGenerateTokenFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(enterPrimaryPasswordGenerateTokenFrameLayout.createSequentialGroup()
                .addGroup(enterPrimaryPasswordGenerateTokenFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
                    .addComponent(enterPrimaryPasswordGenerateTokenSeparator, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(enterPrimaryPasswordGenerateTokenBackgroundLabel))
                .addGap(0, 0, Short.MAX_VALUE))
            .addGroup(enterPrimaryPasswordGenerateTokenFrameLayout.createSequentialGroup()
                .addGroup(enterPrimaryPasswordGenerateTokenFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(enterPrimaryPasswordGenerateTokenFrameLayout.createSequentialGroup()
                        .addGap(367, 367, 367)
                        .addComponent(enterPrimaryPasswordGenerateTokenOKButton)
                        .addGap(5, 5, 5)
                        .addComponent(enterPrimaryPasswordGenerateTokenCancelButton))
                    .addGroup(enterPrimaryPasswordGenerateTokenFrameLayout.createSequentialGroup()
                        .addGap(10, 10, 10)
                        .addComponent(enterPrimaryPasswordGenerateTokenPasswordFieldLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addGap(3, 3, 3)
                        .addComponent(enterPrimaryPasswordGenerateTokenPasswordField, javax.swing.GroupLayout.PREFERRED_SIZE, 290, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addGap(10, 10, 10)
                        .addComponent(enterPrimaryPasswordGenerateTokenShowPhraseCheckBox)))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );
        enterPrimaryPasswordGenerateTokenFrameLayout.setVerticalGroup(
            enterPrimaryPasswordGenerateTokenFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, enterPrimaryPasswordGenerateTokenFrameLayout.createSequentialGroup()
                .addComponent(enterPrimaryPasswordGenerateTokenBackgroundLabel, javax.swing.GroupLayout.PREFERRED_SIZE, 60, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addGroup(enterPrimaryPasswordGenerateTokenFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(enterPrimaryPasswordGenerateTokenFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                        .addComponent(enterPrimaryPasswordGenerateTokenPasswordFieldLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addComponent(enterPrimaryPasswordGenerateTokenPasswordField, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addComponent(enterPrimaryPasswordGenerateTokenShowPhraseCheckBox))
                .addGap(10, 10, 10)
                .addComponent(enterPrimaryPasswordGenerateTokenSeparator, javax.swing.GroupLayout.PREFERRED_SIZE, 5, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addGroup(enterPrimaryPasswordGenerateTokenFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(enterPrimaryPasswordGenerateTokenOKButton)
                    .addComponent(enterPrimaryPasswordGenerateTokenCancelButton))
                .addGap(10, 10, 10))
        );

        accountDetailsFrame.setTitle("Account Details");
        accountDetailsFrame.setAlwaysOnTop(true);
        accountDetailsFrame.setBounds(new java.awt.Rectangle(0, 0, 0, 0));
        accountDetailsFrame.setMinimumSize(new java.awt.Dimension(520, 295));
        accountDetailsFrame.setResizable(false);

        accountDetailsPhraseField.setEditable(false);
        accountDetailsPhraseField.setColumns(30);
        accountDetailsPhraseField.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        accountDetailsPhraseField.setMaximumSize(new java.awt.Dimension(290, 30));
        accountDetailsPhraseField.setMinimumSize(new java.awt.Dimension(290, 30));
        accountDetailsPhraseField.setPreferredSize(new java.awt.Dimension(290, 30));
        accountDetailsPhraseField.setVerifyInputWhenFocusTarget(false);

        accountDetailsPhraseLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        accountDetailsPhraseLabel.setText("Private Phrase:");
        accountDetailsPhraseLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        accountDetailsPhraseLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        accountDetailsPhraseLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        accountDetailsShowPhraseCheckBox.setFont(new java.awt.Font("Open Sans", 1, 9)); // NOI18N
        accountDetailsShowPhraseCheckBox.setText("Show");
        accountDetailsShowPhraseCheckBox.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        accountDetailsShowPhraseCheckBox.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        accountDetailsShowPhraseCheckBox.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                accountDetailsShowPhraseCheckBoxActionPerformed(evt);
            }
        });

        accountDetailsPublicKeyLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        accountDetailsPublicKeyLabel.setText("Public Key:");
        accountDetailsPublicKeyLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        accountDetailsPublicKeyLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        accountDetailsPublicKeyLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        accountDetailsPublicKeyField.setEditable(false);
        accountDetailsPublicKeyField.setColumns(12);
        accountDetailsPublicKeyField.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        accountDetailsPublicKeyField.setMaximumSize(new java.awt.Dimension(290, 30));
        accountDetailsPublicKeyField.setMinimumSize(new java.awt.Dimension(290, 30));
        accountDetailsPublicKeyField.setPreferredSize(new java.awt.Dimension(290, 30));

        accountDetailsCopyButton1.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        accountDetailsCopyButton1.setForeground(new java.awt.Color(0, 102, 204));
        accountDetailsCopyButton1.setText("Copy Private Phrase");
        accountDetailsCopyButton1.setToolTipText(null);
        accountDetailsCopyButton1.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                accountDetailsCopyButton1ActionPerformed(evt);
            }
        });

        accountDetailsCopyButton2.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        accountDetailsCopyButton2.setText("Copy Public Key");
        accountDetailsCopyButton2.setToolTipText(null);
        accountDetailsCopyButton2.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                accountDetailsCopyButton2ActionPerformed(evt);
            }
        });

        accountDetailsjProgressBar.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        accountDetailsjProgressBar.setMaximumSize(new java.awt.Dimension(515, 20));
        accountDetailsjProgressBar.setMinimumSize(new java.awt.Dimension(515, 20));
        accountDetailsjProgressBar.setPreferredSize(new java.awt.Dimension(515, 20));
        accountDetailsjProgressBar.setString("");
        accountDetailsjProgressBar.setStringPainted(true);
        accountDetailsjProgressBar.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                accountDetailsjProgressBarStateChanged(evt);
            }
        });

        accountDetailsLabelLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        accountDetailsLabelLabel.setText("Label:");
        accountDetailsLabelLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        accountDetailsLabelLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        accountDetailsLabelLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        accountDetailsBackgroundLabel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/keystash/resources/accountDetailBG.png"))); // NOI18N
        accountDetailsBackgroundLabel.setToolTipText(null);

        accountDetailsOKButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        accountDetailsOKButton.setMnemonic('O');
        accountDetailsOKButton.setText("OK");
        accountDetailsOKButton.setToolTipText(null);
        accountDetailsOKButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                accountDetailsOKButtonActionPerformed(evt);
            }
        });

        accountDetailsjSeparator.setMaximumSize(new java.awt.Dimension(520, 5));
        accountDetailsjSeparator.setMinimumSize(new java.awt.Dimension(520, 5));
        accountDetailsjSeparator.setPreferredSize(new java.awt.Dimension(520, 5));

        try {
            accountDetailsLabelField.setFormatterFactory(new javax.swing.text.DefaultFormatterFactory(new javax.swing.text.MaskFormatter("***************")));
        } catch (java.text.ParseException ex) {
            ex.printStackTrace();
        }
        accountDetailsLabelField.setMaximumSize(new java.awt.Dimension(290, 30));
        accountDetailsLabelField.setMinimumSize(new java.awt.Dimension(290, 30));
        accountDetailsLabelField.setPreferredSize(new java.awt.Dimension(290, 30));

        javax.swing.GroupLayout accountDetailsFrameLayout = new javax.swing.GroupLayout(accountDetailsFrame.getContentPane());
        accountDetailsFrame.getContentPane().setLayout(accountDetailsFrameLayout);
        accountDetailsFrameLayout.setHorizontalGroup(
            accountDetailsFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(accountDetailsFrameLayout.createSequentialGroup()
                .addGroup(accountDetailsFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
                    .addGroup(javax.swing.GroupLayout.Alignment.LEADING, accountDetailsFrameLayout.createSequentialGroup()
                        .addContainerGap()
                        .addGroup(accountDetailsFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(accountDetailsPhraseLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(accountDetailsPublicKeyLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(accountDetailsLabelLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addGap(23, 23, 23)
                        .addGroup(accountDetailsFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addGroup(accountDetailsFrameLayout.createSequentialGroup()
                                .addComponent(accountDetailsPhraseField, javax.swing.GroupLayout.PREFERRED_SIZE, 290, javax.swing.GroupLayout.PREFERRED_SIZE)
                                .addGap(10, 10, 10)
                                .addComponent(accountDetailsShowPhraseCheckBox))
                            .addComponent(accountDetailsPublicKeyField, javax.swing.GroupLayout.PREFERRED_SIZE, 290, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(accountDetailsLabelField, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)))
                    .addComponent(accountDetailsBackgroundLabel, javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(accountDetailsjSeparator, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(accountDetailsjProgressBar, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(0, 0, Short.MAX_VALUE))
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, accountDetailsFrameLayout.createSequentialGroup()
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addGroup(accountDetailsFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, accountDetailsFrameLayout.createSequentialGroup()
                        .addComponent(accountDetailsClearLabel)
                        .addContainerGap())
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, accountDetailsFrameLayout.createSequentialGroup()
                        .addComponent(accountDetailsCopyButton1)
                        .addGap(5, 5, 5)
                        .addComponent(accountDetailsCopyButton2)
                        .addGap(5, 5, 5)
                        .addComponent(accountDetailsOKButton)
                        .addGap(32, 32, 32))))
        );
        accountDetailsFrameLayout.setVerticalGroup(
            accountDetailsFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(accountDetailsFrameLayout.createSequentialGroup()
                .addComponent(accountDetailsBackgroundLabel, javax.swing.GroupLayout.PREFERRED_SIZE, 60, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addGroup(accountDetailsFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(accountDetailsShowPhraseCheckBox)
                    .addGroup(accountDetailsFrameLayout.createSequentialGroup()
                        .addGroup(accountDetailsFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(accountDetailsPhraseField, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(accountDetailsPhraseLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addGap(12, 12, 12)
                        .addGroup(accountDetailsFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(accountDetailsPublicKeyField, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(accountDetailsPublicKeyLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))))
                .addGap(12, 12, 12)
                .addGroup(accountDetailsFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(accountDetailsLabelField, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(accountDetailsLabelLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(10, 10, 10)
                .addComponent(accountDetailsjSeparator, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addGroup(accountDetailsFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(accountDetailsOKButton)
                    .addComponent(accountDetailsCopyButton1)
                    .addComponent(accountDetailsCopyButton2))
                .addGap(10, 10, 10)
                .addComponent(accountDetailsjProgressBar, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addComponent(accountDetailsClearLabel)
                .addGap(63, 63, 63))
        );

        generateTokenFrame.setTitle("Account Details");
        generateTokenFrame.setAlwaysOnTop(true);
        generateTokenFrame.setBounds(new java.awt.Rectangle(0, 0, 0, 0));
        generateTokenFrame.setMinimumSize(new java.awt.Dimension(520, 230));
        generateTokenFrame.setResizable(false);

        generateTokenCopyButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        generateTokenCopyButton.setText("Copy Token");
        generateTokenCopyButton.setToolTipText(null);
        generateTokenCopyButton.setActionCommand("Copy To Clipboard");
        generateTokenCopyButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                generateTokenCopyButtonActionPerformed(evt);
            }
        });

        generateTokenTokenDataField.setColumns(12);
        generateTokenTokenDataField.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        generateTokenTokenDataField.setText("Text Or Website");
        generateTokenTokenDataField.setPreferredSize(new java.awt.Dimension(290, 30));

        generateTokenTokenValueLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        generateTokenTokenValueLabel.setText("Token Data:");
        generateTokenTokenValueLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        generateTokenTokenValueLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        generateTokenTokenValueLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        generateTokenTokenKeyField.setEditable(false);
        generateTokenTokenKeyField.setColumns(12);
        generateTokenTokenKeyField.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        generateTokenTokenKeyField.setText("No Token Generated Yet");
        generateTokenTokenKeyField.setPreferredSize(new java.awt.Dimension(290, 30));

        generateTokenTokenKeyLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        generateTokenTokenKeyLabel.setText("Token:");
        generateTokenTokenKeyLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        generateTokenTokenKeyLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        generateTokenTokenKeyLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        generateTokenGenerateTokenButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        generateTokenGenerateTokenButton.setMnemonic('G');
        generateTokenGenerateTokenButton.setText("Generate Token");
        generateTokenGenerateTokenButton.setToolTipText(null);
        generateTokenGenerateTokenButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                generateTokenGenerateTokenButtonActionPerformed(evt);
            }
        });

        generateTokenBackgroundLabel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/keystash/resources/generateTokenBG.png"))); // NOI18N
        generateTokenBackgroundLabel.setToolTipText(null);

        generateTokenOKButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        generateTokenOKButton.setMnemonic('O');
        generateTokenOKButton.setText("OK");
        generateTokenOKButton.setToolTipText(null);
        generateTokenOKButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                generateTokenOKButtonActionPerformed(evt);
            }
        });

        generateTokenSeparator.setMaximumSize(new java.awt.Dimension(520, 5));
        generateTokenSeparator.setMinimumSize(new java.awt.Dimension(520, 5));
        generateTokenSeparator.setPreferredSize(new java.awt.Dimension(520, 5));

        javax.swing.GroupLayout generateTokenFrameLayout = new javax.swing.GroupLayout(generateTokenFrame.getContentPane());
        generateTokenFrame.getContentPane().setLayout(generateTokenFrameLayout);
        generateTokenFrameLayout.setHorizontalGroup(
            generateTokenFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(generateTokenFrameLayout.createSequentialGroup()
                .addGap(10, 10, 10)
                .addGroup(generateTokenFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, generateTokenFrameLayout.createSequentialGroup()
                        .addGap(0, 0, Short.MAX_VALUE)
                        .addComponent(generateTokenClearLabel))
                    .addGroup(generateTokenFrameLayout.createSequentialGroup()
                        .addGroup(generateTokenFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                            .addGroup(generateTokenFrameLayout.createSequentialGroup()
                                .addComponent(generateTokenTokenKeyLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                .addComponent(generateTokenTokenKeyField, javax.swing.GroupLayout.PREFERRED_SIZE, 290, javax.swing.GroupLayout.PREFERRED_SIZE))
                            .addGroup(generateTokenFrameLayout.createSequentialGroup()
                                .addComponent(generateTokenTokenValueLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                                .addGap(23, 23, 23)
                                .addComponent(generateTokenTokenDataField, javax.swing.GroupLayout.PREFERRED_SIZE, 290, javax.swing.GroupLayout.PREFERRED_SIZE)))
                        .addGap(0, 0, Short.MAX_VALUE)))
                .addContainerGap())
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, generateTokenFrameLayout.createSequentialGroup()
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addComponent(generateTokenCopyButton)
                .addGap(5, 5, 5)
                .addComponent(generateTokenGenerateTokenButton)
                .addGap(5, 5, 5)
                .addComponent(generateTokenOKButton)
                .addGap(32, 32, 32))
            .addGroup(generateTokenFrameLayout.createSequentialGroup()
                .addGroup(generateTokenFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(generateTokenBackgroundLabel)
                    .addComponent(generateTokenSeparator, javax.swing.GroupLayout.PREFERRED_SIZE, 520, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(0, 0, Short.MAX_VALUE))
        );
        generateTokenFrameLayout.setVerticalGroup(
            generateTokenFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(generateTokenFrameLayout.createSequentialGroup()
                .addComponent(generateTokenBackgroundLabel, javax.swing.GroupLayout.PREFERRED_SIZE, 60, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addGroup(generateTokenFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(generateTokenTokenValueLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(generateTokenTokenDataField, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(12, 12, 12)
                .addGroup(generateTokenFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(generateTokenTokenKeyField, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(generateTokenTokenKeyLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(10, 10, 10)
                .addComponent(generateTokenSeparator, javax.swing.GroupLayout.PREFERRED_SIZE, 5, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addGroup(generateTokenFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(generateTokenGenerateTokenButton)
                    .addComponent(generateTokenOKButton)
                    .addComponent(generateTokenCopyButton))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 10, Short.MAX_VALUE)
                .addComponent(generateTokenClearLabel)
                .addGap(37, 37, 37))
        );

        showPreferencesFrame.setTitle("Preferences");
        showPreferencesFrame.setAlwaysOnTop(true);
        showPreferencesFrame.setBounds(new java.awt.Rectangle(0, 0, 0, 0));
        showPreferencesFrame.setMinimumSize(new java.awt.Dimension(520, 370));
        showPreferencesFrame.setResizable(false);

        showPreferencesWarningsLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        showPreferencesWarningsLabel.setText("Show Warnings:");
        showPreferencesWarningsLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        showPreferencesWarningsLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        showPreferencesWarningsLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        showPreferencesWarningsCheckbox.setSelected(true);
        showPreferencesWarningsCheckbox.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                showPreferencesWarningsCheckboxActionPerformed(evt);
            }
        });

        showPreferencesClearClipboardSpinner.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showPreferencesClearClipboardSpinner.setModel(new javax.swing.SpinnerNumberModel(1, 1, 20, 1));
        showPreferencesClearClipboardSpinner.setMaximumSize(new java.awt.Dimension(50, 20));
        showPreferencesClearClipboardSpinner.setMinimumSize(new java.awt.Dimension(50, 20));
        showPreferencesClearClipboardSpinner.setPreferredSize(new java.awt.Dimension(50, 20));
        showPreferencesClearClipboardSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                showPreferencesClearClipboardSpinnerStateChanged(evt);
            }
        });

        showPreferencesClearClipboardLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        showPreferencesClearClipboardLabel.setText("Clear Clipboard:");
        showPreferencesClearClipboardLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        showPreferencesClearClipboardLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        showPreferencesClearClipboardLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        showPreferencesPhraseBlocksSpinner.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showPreferencesPhraseBlocksSpinner.setModel(new javax.swing.SpinnerNumberModel(1, 1, 99, 1));
        showPreferencesPhraseBlocksSpinner.setMaximumSize(new java.awt.Dimension(50, 20));
        showPreferencesPhraseBlocksSpinner.setMinimumSize(new java.awt.Dimension(50, 20));
        showPreferencesPhraseBlocksSpinner.setPreferredSize(new java.awt.Dimension(50, 20));
        showPreferencesPhraseBlocksSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                showPreferencesPhraseBlocksSpinnerStateChanged(evt);
            }
        });

        showPreferencesPhraseBlocksLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        showPreferencesPhraseBlocksLabel.setText("Phrase Blocks:");
        showPreferencesPhraseBlocksLabel.setMaximumSize(new java.awt.Dimension(110, 18));
        showPreferencesPhraseBlocksLabel.setMinimumSize(new java.awt.Dimension(110, 18));
        showPreferencesPhraseBlocksLabel.setPreferredSize(new java.awt.Dimension(110, 18));

        showPreferencesRandomGenerationLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        showPreferencesRandomGenerationLabel.setText("Expert Phrase Generation:");
        showPreferencesRandomGenerationLabel.setMaximumSize(new java.awt.Dimension(190, 18));
        showPreferencesRandomGenerationLabel.setMinimumSize(new java.awt.Dimension(190, 18));
        showPreferencesRandomGenerationLabel.setPreferredSize(new java.awt.Dimension(190, 18));

        showPreferencesRandomGenerationCheckbox.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                showPreferencesRandomGenerationCheckboxActionPerformed(evt);
            }
        });

        showPreferencesLengthMinimumLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        showPreferencesLengthMinimumLabel.setText("Length Min:");
        showPreferencesLengthMinimumLabel.setMaximumSize(new java.awt.Dimension(100, 18));
        showPreferencesLengthMinimumLabel.setMinimumSize(new java.awt.Dimension(100, 18));
        showPreferencesLengthMinimumLabel.setPreferredSize(new java.awt.Dimension(100, 18));

        showPreferencesLengthMinimumMinSpinner.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showPreferencesLengthMinimumMinSpinner.setModel(new javax.swing.SpinnerNumberModel(1, 1, 99, 1));
        showPreferencesLengthMinimumMinSpinner.setMaximumSize(new java.awt.Dimension(50, 20));
        showPreferencesLengthMinimumMinSpinner.setMinimumSize(new java.awt.Dimension(50, 20));
        showPreferencesLengthMinimumMinSpinner.setPreferredSize(new java.awt.Dimension(50, 20));
        showPreferencesLengthMinimumMinSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                showPreferencesLengthMinimumMinSpinnerStateChanged(evt);
            }
        });

        showPreferencesLengthMinimumMaxSpinner.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showPreferencesLengthMinimumMaxSpinner.setModel(new javax.swing.SpinnerNumberModel(1, 1, 99, 1));
        showPreferencesLengthMinimumMaxSpinner.setMaximumSize(new java.awt.Dimension(50, 20));
        showPreferencesLengthMinimumMaxSpinner.setMinimumSize(new java.awt.Dimension(50, 20));
        showPreferencesLengthMinimumMaxSpinner.setPreferredSize(new java.awt.Dimension(50, 20));
        showPreferencesLengthMinimumMaxSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                showPreferencesLengthMinimumMaxSpinnerStateChanged(evt);
            }
        });

        showPreferencesLengthMaximumLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        showPreferencesLengthMaximumLabel.setText("Length Max:");
        showPreferencesLengthMaximumLabel.setMaximumSize(new java.awt.Dimension(100, 18));
        showPreferencesLengthMaximumLabel.setMinimumSize(new java.awt.Dimension(100, 18));
        showPreferencesLengthMaximumLabel.setName(""); // NOI18N
        showPreferencesLengthMaximumLabel.setPreferredSize(new java.awt.Dimension(100, 18));

        showPreferencesLengthMaximumMaxSpinner.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showPreferencesLengthMaximumMaxSpinner.setModel(new javax.swing.SpinnerNumberModel(1, 1, 99, 1));
        showPreferencesLengthMaximumMaxSpinner.setMaximumSize(new java.awt.Dimension(50, 20));
        showPreferencesLengthMaximumMaxSpinner.setMinimumSize(new java.awt.Dimension(50, 20));
        showPreferencesLengthMaximumMaxSpinner.setPreferredSize(new java.awt.Dimension(50, 20));
        showPreferencesLengthMaximumMaxSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                showPreferencesLengthMaximumMaxSpinnerStateChanged(evt);
            }
        });

        showPreferencesLengthMaximumMinSpinner.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showPreferencesLengthMaximumMinSpinner.setModel(new javax.swing.SpinnerNumberModel(1, 1, 99, 1));
        showPreferencesLengthMaximumMinSpinner.setMaximumSize(new java.awt.Dimension(50, 20));
        showPreferencesLengthMaximumMinSpinner.setMinimumSize(new java.awt.Dimension(50, 20));
        showPreferencesLengthMaximumMinSpinner.setPreferredSize(new java.awt.Dimension(50, 20));
        showPreferencesLengthMaximumMinSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                showPreferencesLengthMaximumMinSpinnerStateChanged(evt);
            }
        });

        showPreferencesLowerCaseLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        showPreferencesLowerCaseLabel.setText("Lower Case:");
        showPreferencesLowerCaseLabel.setMaximumSize(new java.awt.Dimension(100, 18));
        showPreferencesLowerCaseLabel.setMinimumSize(new java.awt.Dimension(100, 18));
        showPreferencesLowerCaseLabel.setPreferredSize(new java.awt.Dimension(100, 18));

        showPreferencesLowerCaseMinSpinner.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showPreferencesLowerCaseMinSpinner.setModel(new javax.swing.SpinnerNumberModel(0, 0, 99, 1));
        showPreferencesLowerCaseMinSpinner.setMaximumSize(new java.awt.Dimension(50, 20));
        showPreferencesLowerCaseMinSpinner.setMinimumSize(new java.awt.Dimension(50, 20));
        showPreferencesLowerCaseMinSpinner.setPreferredSize(new java.awt.Dimension(50, 20));
        showPreferencesLowerCaseMinSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                showPreferencesLowerCaseMinSpinnerStateChanged(evt);
            }
        });

        showPreferencesLowerCaseMaxSpinner.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showPreferencesLowerCaseMaxSpinner.setModel(new javax.swing.SpinnerNumberModel(0, 0, 99, 1));
        showPreferencesLowerCaseMaxSpinner.setMaximumSize(new java.awt.Dimension(50, 20));
        showPreferencesLowerCaseMaxSpinner.setMinimumSize(new java.awt.Dimension(50, 20));
        showPreferencesLowerCaseMaxSpinner.setPreferredSize(new java.awt.Dimension(50, 20));
        showPreferencesLowerCaseMaxSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                showPreferencesLowerCaseMaxSpinnerStateChanged(evt);
            }
        });

        showPreferencesUpperCaseLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        showPreferencesUpperCaseLabel.setText("Upper Case:");
        showPreferencesUpperCaseLabel.setMaximumSize(new java.awt.Dimension(100, 18));
        showPreferencesUpperCaseLabel.setMinimumSize(new java.awt.Dimension(100, 18));
        showPreferencesUpperCaseLabel.setPreferredSize(new java.awt.Dimension(100, 18));

        showPreferencesUpperCaseMinSpinner.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showPreferencesUpperCaseMinSpinner.setModel(new javax.swing.SpinnerNumberModel(0, 0, 99, 1));
        showPreferencesUpperCaseMinSpinner.setMaximumSize(new java.awt.Dimension(50, 20));
        showPreferencesUpperCaseMinSpinner.setMinimumSize(new java.awt.Dimension(50, 20));
        showPreferencesUpperCaseMinSpinner.setPreferredSize(new java.awt.Dimension(50, 20));
        showPreferencesUpperCaseMinSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                showPreferencesUpperCaseMinSpinnerStateChanged(evt);
            }
        });

        showPreferencesUpperCaseMaxSpinner.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showPreferencesUpperCaseMaxSpinner.setModel(new javax.swing.SpinnerNumberModel(0, 0, 99, 1));
        showPreferencesUpperCaseMaxSpinner.setMaximumSize(new java.awt.Dimension(50, 20));
        showPreferencesUpperCaseMaxSpinner.setMinimumSize(new java.awt.Dimension(50, 20));
        showPreferencesUpperCaseMaxSpinner.setPreferredSize(new java.awt.Dimension(50, 20));
        showPreferencesUpperCaseMaxSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                showPreferencesUpperCaseMaxSpinnerStateChanged(evt);
            }
        });

        showPreferencesNumeraryLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        showPreferencesNumeraryLabel.setText("Numerary:");
        showPreferencesNumeraryLabel.setMaximumSize(new java.awt.Dimension(100, 18));
        showPreferencesNumeraryLabel.setMinimumSize(new java.awt.Dimension(100, 18));
        showPreferencesNumeraryLabel.setPreferredSize(new java.awt.Dimension(100, 18));

        showPreferencesNumeraryMinSpinner.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showPreferencesNumeraryMinSpinner.setModel(new javax.swing.SpinnerNumberModel(0, 0, 99, 1));
        showPreferencesNumeraryMinSpinner.setMaximumSize(new java.awt.Dimension(50, 20));
        showPreferencesNumeraryMinSpinner.setMinimumSize(new java.awt.Dimension(50, 20));
        showPreferencesNumeraryMinSpinner.setPreferredSize(new java.awt.Dimension(50, 20));
        showPreferencesNumeraryMinSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                showPreferencesNumeraryMinSpinnerStateChanged(evt);
            }
        });

        showPreferencesNumeraryMaxSpinner.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showPreferencesNumeraryMaxSpinner.setModel(new javax.swing.SpinnerNumberModel(0, 0, 99, 1));
        showPreferencesNumeraryMaxSpinner.setMaximumSize(new java.awt.Dimension(50, 20));
        showPreferencesNumeraryMaxSpinner.setMinimumSize(new java.awt.Dimension(50, 20));
        showPreferencesNumeraryMaxSpinner.setPreferredSize(new java.awt.Dimension(50, 20));
        showPreferencesNumeraryMaxSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                showPreferencesNumeraryMaxSpinnerStateChanged(evt);
            }
        });

        showPreferencesSpecialCharLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        showPreferencesSpecialCharLabel.setText("Special/ ANSI:");
        showPreferencesSpecialCharLabel.setMaximumSize(new java.awt.Dimension(100, 18));
        showPreferencesSpecialCharLabel.setMinimumSize(new java.awt.Dimension(100, 18));
        showPreferencesSpecialCharLabel.setPreferredSize(new java.awt.Dimension(100, 18));

        showPreferencesSpecialCharMinSpinner.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showPreferencesSpecialCharMinSpinner.setModel(new javax.swing.SpinnerNumberModel(0, 0, 99, 1));
        showPreferencesSpecialCharMinSpinner.setMaximumSize(new java.awt.Dimension(50, 20));
        showPreferencesSpecialCharMinSpinner.setMinimumSize(new java.awt.Dimension(50, 20));
        showPreferencesSpecialCharMinSpinner.setPreferredSize(new java.awt.Dimension(50, 20));
        showPreferencesSpecialCharMinSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                showPreferencesSpecialCharMinSpinnerStateChanged(evt);
            }
        });

        showPreferencesSpecialCharMaxSpinner.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showPreferencesSpecialCharMaxSpinner.setModel(new javax.swing.SpinnerNumberModel(0, 0, 99, 1));
        showPreferencesSpecialCharMaxSpinner.setMaximumSize(new java.awt.Dimension(50, 20));
        showPreferencesSpecialCharMaxSpinner.setMinimumSize(new java.awt.Dimension(50, 20));
        showPreferencesSpecialCharMaxSpinner.setPreferredSize(new java.awt.Dimension(50, 20));
        showPreferencesSpecialCharMaxSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                showPreferencesSpecialCharMaxSpinnerStateChanged(evt);
            }
        });

        showPreferencesResetSettingsButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        showPreferencesResetSettingsButton.setMnemonic('D');
        showPreferencesResetSettingsButton.setText("Default Settings");
        showPreferencesResetSettingsButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                showPreferencesResetSettingsButtonActionPerformed(evt);
            }
        });

        showPreferencesWhitespaceLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        showPreferencesWhitespaceLabel.setText("Whitespaces:");
        showPreferencesWhitespaceLabel.setMaximumSize(new java.awt.Dimension(100, 18));
        showPreferencesWhitespaceLabel.setMinimumSize(new java.awt.Dimension(100, 18));
        showPreferencesWhitespaceLabel.setPreferredSize(new java.awt.Dimension(100, 18));

        showPreferencesWhitespaceCheckbox.setSelected(true);
        showPreferencesWhitespaceCheckbox.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                showPreferencesWhitespaceCheckboxActionPerformed(evt);
            }
        });

        showPreferencesIterationLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        showPreferencesIterationLabel.setText("Iteration");
        showPreferencesIterationLabel.setMaximumSize(new java.awt.Dimension(100, 18));
        showPreferencesIterationLabel.setMinimumSize(new java.awt.Dimension(100, 18));
        showPreferencesIterationLabel.setPreferredSize(new java.awt.Dimension(100, 18));

        showPreferencesIterationSpinner.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showPreferencesIterationSpinner.setModel(new javax.swing.SpinnerNumberModel(1000, 10, 200000, 100));
        showPreferencesIterationSpinner.setMaximumSize(new java.awt.Dimension(110, 20));
        showPreferencesIterationSpinner.setMinimumSize(new java.awt.Dimension(110, 20));
        showPreferencesIterationSpinner.setPreferredSize(new java.awt.Dimension(110, 20));
        showPreferencesIterationSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                showPreferencesIterationSpinnerStateChanged(evt);
            }
        });

        showPreferenceKeySizesLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        showPreferenceKeySizesLabel.setText("Encryption Bit:");
        showPreferenceKeySizesLabel.setMaximumSize(new java.awt.Dimension(110, 18));
        showPreferenceKeySizesLabel.setMinimumSize(new java.awt.Dimension(110, 18));
        showPreferenceKeySizesLabel.setPreferredSize(new java.awt.Dimension(110, 18));

        showPreferencesKeySizeComboBox.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        showPreferencesKeySizeComboBox.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "128", "256" }));
        showPreferencesKeySizeComboBox.setMaximumSize(new java.awt.Dimension(60, 20));
        showPreferencesKeySizeComboBox.setMinimumSize(new java.awt.Dimension(60, 20));
        showPreferencesKeySizeComboBox.setPreferredSize(new java.awt.Dimension(60, 20));
        showPreferencesKeySizeComboBox.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                showPreferencesKeySizeComboBoxActionPerformed(evt);
            }
        });

        showPreferecesBackgroundLabel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/keystash/resources/preferencesBG.png"))); // NOI18N
        showPreferecesBackgroundLabel.setToolTipText(null);

        showPreferencesjSeparator.setMaximumSize(new java.awt.Dimension(520, 5));
        showPreferencesjSeparator.setMinimumSize(new java.awt.Dimension(520, 5));
        showPreferencesjSeparator.setPreferredSize(new java.awt.Dimension(520, 5));

        showPreferencesOKButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        showPreferencesOKButton.setMnemonic('O');
        showPreferencesOKButton.setText("OK");
        showPreferencesOKButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                showPreferencesOKButtonActionPerformed(evt);
            }
        });

        showPreferencesANSILabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        showPreferencesANSILabel.setText("High ANSI Chars:");
        showPreferencesANSILabel.setMaximumSize(new java.awt.Dimension(120, 18));
        showPreferencesANSILabel.setMinimumSize(new java.awt.Dimension(120, 18));
        showPreferencesANSILabel.setPreferredSize(new java.awt.Dimension(120, 18));

        showPreferencesANSICheckbox.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                showPreferencesANSICheckboxActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout showPreferencesFrameLayout = new javax.swing.GroupLayout(showPreferencesFrame.getContentPane());
        showPreferencesFrame.getContentPane().setLayout(showPreferencesFrameLayout);
        showPreferencesFrameLayout.setHorizontalGroup(
            showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(showPreferencesFrameLayout.createSequentialGroup()
                .addComponent(showPreferecesBackgroundLabel)
                .addGap(0, 1, Short.MAX_VALUE))
            .addComponent(showPreferencesjSeparator, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, showPreferencesFrameLayout.createSequentialGroup()
                .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, showPreferencesFrameLayout.createSequentialGroup()
                        .addGap(10, 10, 10)
                        .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addGroup(showPreferencesFrameLayout.createSequentialGroup()
                                .addComponent(showPreferencesRandomGenerationLabel, javax.swing.GroupLayout.PREFERRED_SIZE, 190, javax.swing.GroupLayout.PREFERRED_SIZE)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                .addComponent(showPreferencesRandomGenerationCheckbox))
                            .addGroup(showPreferencesFrameLayout.createSequentialGroup()
                                .addComponent(showPreferencesWarningsLabel, javax.swing.GroupLayout.PREFERRED_SIZE, 120, javax.swing.GroupLayout.PREFERRED_SIZE)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                .addComponent(showPreferencesWarningsCheckbox))
                            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, showPreferencesFrameLayout.createSequentialGroup()
                                .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                                    .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                                        .addComponent(showPreferencesNumeraryLabel, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                        .addComponent(showPreferencesLengthMinimumLabel, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                        .addComponent(showPreferencesLowerCaseLabel, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                        .addComponent(showPreferencesPhraseBlocksLabel, javax.swing.GroupLayout.DEFAULT_SIZE, 118, Short.MAX_VALUE))
                                    .addComponent(showPreferencesIterationLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                                        .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, showPreferencesFrameLayout.createSequentialGroup()
                                            .addComponent(showPreferencesLowerCaseMinSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE)
                                            .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                                            .addComponent(showPreferencesLowerCaseMaxSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE))
                                        .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, showPreferencesFrameLayout.createSequentialGroup()
                                            .addComponent(showPreferencesLengthMinimumMinSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                                            .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                                            .addComponent(showPreferencesLengthMinimumMaxSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE))
                                        .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, showPreferencesFrameLayout.createSequentialGroup()
                                            .addComponent(showPreferencesNumeraryMinSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE)
                                            .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                                            .addComponent(showPreferencesNumeraryMaxSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE))
                                        .addComponent(showPreferencesIterationSpinner, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                                    .addComponent(showPreferencesPhraseBlocksSpinner, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE))))
                        .addGap(23, 23, 23)
                        .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(showPreferenceKeySizesLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
                                .addGroup(showPreferencesFrameLayout.createSequentialGroup()
                                    .addComponent(showPreferencesANSILabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                                    .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                    .addComponent(showPreferencesANSICheckbox))
                                .addGroup(javax.swing.GroupLayout.Alignment.LEADING, showPreferencesFrameLayout.createSequentialGroup()
                                    .addComponent(showPreferencesClearClipboardLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                                    .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                    .addComponent(showPreferencesClearClipboardSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE))
                                .addGroup(javax.swing.GroupLayout.Alignment.LEADING, showPreferencesFrameLayout.createSequentialGroup()
                                    .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                                        .addComponent(showPreferencesSpecialCharLabel, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                        .addComponent(showPreferencesLengthMaximumLabel, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                        .addComponent(showPreferencesUpperCaseLabel, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                        .addComponent(showPreferencesWhitespaceLabel, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                                    .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                                        .addGroup(showPreferencesFrameLayout.createSequentialGroup()
                                            .addGap(18, 18, 18)
                                            .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                                                .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, showPreferencesFrameLayout.createSequentialGroup()
                                                    .addComponent(showPreferencesUpperCaseMinSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE)
                                                    .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                                    .addComponent(showPreferencesUpperCaseMaxSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE))
                                                .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, showPreferencesFrameLayout.createSequentialGroup()
                                                    .addComponent(showPreferencesSpecialCharMinSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE)
                                                    .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                                    .addComponent(showPreferencesSpecialCharMaxSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE))))
                                        .addGroup(showPreferencesFrameLayout.createSequentialGroup()
                                            .addGap(18, 18, 18)
                                            .addComponent(showPreferencesLengthMaximumMinSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE)
                                            .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                            .addComponent(showPreferencesLengthMaximumMaxSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE))
                                        .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, showPreferencesFrameLayout.createSequentialGroup()
                                            .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                            .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                                                .addComponent(showPreferencesWhitespaceCheckbox, javax.swing.GroupLayout.Alignment.TRAILING)
                                                .addComponent(showPreferencesKeySizeComboBox, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.PREFERRED_SIZE, 60, javax.swing.GroupLayout.PREFERRED_SIZE))))))))
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, showPreferencesFrameLayout.createSequentialGroup()
                        .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                        .addComponent(showPreferencesResetSettingsButton)
                        .addGap(5, 5, 5)
                        .addComponent(showPreferencesOKButton)))
                .addGap(32, 32, 32))
        );
        showPreferencesFrameLayout.setVerticalGroup(
            showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, showPreferencesFrameLayout.createSequentialGroup()
                .addComponent(showPreferecesBackgroundLabel, javax.swing.GroupLayout.PREFERRED_SIZE, 60, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                        .addComponent(showPreferencesClearClipboardLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addComponent(showPreferencesClearClipboardSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, 20, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addComponent(showPreferencesWarningsCheckbox)
                    .addComponent(showPreferencesWarningsLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(12, 12, 12)
                .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(showPreferencesRandomGenerationLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(showPreferencesRandomGenerationCheckbox)
                    .addComponent(showPreferencesANSILabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(showPreferencesANSICheckbox))
                .addGap(12, 12, 12)
                .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(showPreferencesFrameLayout.createSequentialGroup()
                        .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(showPreferencesPhraseBlocksSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesPhraseBlocksLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesWhitespaceLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addGap(10, 10, 10)
                        .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(showPreferencesLengthMinimumMinSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesLengthMinimumLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesLengthMinimumMaxSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesLengthMaximumLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesLengthMaximumMinSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, 20, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesLengthMaximumMaxSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addGap(12, 12, 12)
                        .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(showPreferencesLowerCaseMaxSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesLowerCaseMinSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesLowerCaseLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesUpperCaseLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesUpperCaseMinSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesUpperCaseMaxSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addGap(12, 12, 12)
                        .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(showPreferencesNumeraryMaxSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesNumeraryLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesNumeraryMinSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesSpecialCharMinSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesSpecialCharMaxSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesSpecialCharLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)))
                    .addComponent(showPreferencesWhitespaceCheckbox))
                .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(showPreferencesFrameLayout.createSequentialGroup()
                        .addGap(12, 12, 12)
                        .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(showPreferencesIterationSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, 20, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferencesIterationLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(showPreferenceKeySizesLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)))
                    .addGroup(showPreferencesFrameLayout.createSequentialGroup()
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                        .addComponent(showPreferencesKeySizeComboBox, javax.swing.GroupLayout.PREFERRED_SIZE, 20, javax.swing.GroupLayout.PREFERRED_SIZE)))
                .addGap(10, 10, 10)
                .addComponent(showPreferencesjSeparator, javax.swing.GroupLayout.PREFERRED_SIZE, 5, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addGroup(showPreferencesFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(showPreferencesResetSettingsButton)
                    .addComponent(showPreferencesOKButton))
                .addGap(10, 10, 10))
        );

        aboutFrame.setTitle("About KeyStash");
        aboutFrame.setAlwaysOnTop(true);
        aboutFrame.setBounds(new java.awt.Rectangle(0, 0, 0, 0));
        aboutFrame.setMinimumSize(new java.awt.Dimension(520, 405));
        aboutFrame.setResizable(false);

        aboutBackgroundLabel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/keystash/resources/aboutBG.png"))); // NOI18N
        aboutBackgroundLabel.setToolTipText(null);

        aboutScrollPane.setHorizontalScrollBarPolicy(javax.swing.ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
        aboutScrollPane.setVerticalScrollBarPolicy(javax.swing.ScrollPaneConstants.VERTICAL_SCROLLBAR_NEVER);
        aboutScrollPane.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        aboutScrollPane.setMaximumSize(new java.awt.Dimension(470, 92));
        aboutScrollPane.setMinimumSize(new java.awt.Dimension(470, 92));
        aboutScrollPane.setPreferredSize(new java.awt.Dimension(470, 92));

        aboutTable.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        aboutTable.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {

            },
            new String [] {
                "Component", "Directory, Status, Version"
            }
        ) {
            Class[] types = new Class [] {
                java.lang.String.class, java.lang.Object.class
            };
            boolean[] canEdit = new boolean [] {
                false, false
            };

            public Class getColumnClass(int columnIndex) {
                return types [columnIndex];
            }

            public boolean isCellEditable(int rowIndex, int columnIndex) {
                return canEdit [columnIndex];
            }
        });
        aboutTable.setMaximumSize(new java.awt.Dimension(470, 92));
        aboutTable.setMinimumSize(new java.awt.Dimension(470, 92));
        aboutTable.setPreferredSize(new java.awt.Dimension(470, 92));
        aboutTable.setRowSelectionAllowed(false);
        aboutScrollPane.setViewportView(aboutTable);

        aboutjSeparator.setMaximumSize(new java.awt.Dimension(520, 5));
        aboutjSeparator.setMinimumSize(new java.awt.Dimension(520, 5));
        aboutjSeparator.setPreferredSize(new java.awt.Dimension(520, 5));

        aboutOkButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        aboutOkButton.setMnemonic('O');
        aboutOkButton.setText("OK");
        aboutOkButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                aboutOkButtonActionPerformed(evt);
            }
        });

        aboutKeyStashDevelopersLabel.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        aboutKeyStashDevelopersLabel.setText("Copyright © 2014 The KeyStash developers");
        aboutKeyStashDevelopersLabel.setToolTipText(null);

        aboutKeyStashLicenseLabel.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        aboutKeyStashLicenseLabel.setText("This is experimental software. ");
        aboutKeyStashLicenseLabel.setToolTipText(null);

        aboutKeyStashLicenseLinkLabel.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        aboutKeyStashLicenseLinkLabel.setText("file COPYING or http://www.opensource.org/licenses/MIT.");
        aboutKeyStashLicenseLinkLabel.setToolTipText(null);

        aboutKeyStashExperimentelLabel.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        aboutKeyStashExperimentelLabel.setText("Distributed under the MIT/X11 software license, see the accompanying ");
        aboutKeyStashExperimentelLabel.setToolTipText(null);

        aboutKeyStashIncludesSoftwareLabel.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        aboutKeyStashIncludesSoftwareLabel.setText("This product contains software developed by the NXT cryptocurrency project.");
        aboutKeyStashIncludesSoftwareLabel.setToolTipText(null);

        aboutKeyStashIncludesSoftwareLinkLabel.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        aboutKeyStashIncludesSoftwareLinkLabel.setText("http://www.bitbucket.org/JeanLucPicard/nxt/src");
        aboutKeyStashIncludesSoftwareLinkLabel.setToolTipText(null);

        javax.swing.GroupLayout aboutFrameLayout = new javax.swing.GroupLayout(aboutFrame.getContentPane());
        aboutFrame.getContentPane().setLayout(aboutFrameLayout);
        aboutFrameLayout.setHorizontalGroup(
            aboutFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(aboutFrameLayout.createSequentialGroup()
                .addGroup(aboutFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addComponent(aboutBackgroundLabel)
                    .addComponent(aboutjSeparator, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                .addGap(0, 0, Short.MAX_VALUE))
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, aboutFrameLayout.createSequentialGroup()
                .addGap(437, 437, 437)
                .addComponent(aboutOkButton)
                .addGap(32, 32, 32))
            .addGroup(aboutFrameLayout.createSequentialGroup()
                .addGap(21, 21, 21)
                .addGroup(aboutFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(aboutScrollPane, javax.swing.GroupLayout.PREFERRED_SIZE, 470, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(aboutKeyStashDevelopersLabel)
                    .addComponent(aboutKeyStashLicenseLabel)
                    .addComponent(aboutKeyStashLicenseLinkLabel)
                    .addComponent(aboutKeyStashExperimentelLabel)
                    .addComponent(aboutKeyStashIncludesSoftwareLabel)
                    .addComponent(aboutKeyStashIncludesSoftwareLinkLabel))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );
        aboutFrameLayout.setVerticalGroup(
            aboutFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(aboutFrameLayout.createSequentialGroup()
                .addComponent(aboutBackgroundLabel, javax.swing.GroupLayout.PREFERRED_SIZE, 60, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addComponent(aboutKeyStashDevelopersLabel)
                .addGap(12, 12, 12)
                .addComponent(aboutKeyStashLicenseLabel)
                .addGap(12, 12, 12)
                .addComponent(aboutKeyStashExperimentelLabel)
                .addGap(6, 6, 6)
                .addComponent(aboutKeyStashLicenseLinkLabel)
                .addGap(12, 12, 12)
                .addComponent(aboutKeyStashIncludesSoftwareLabel)
                .addGap(6, 6, 6)
                .addComponent(aboutKeyStashIncludesSoftwareLinkLabel)
                .addGap(10, 10, 10)
                .addComponent(aboutScrollPane, javax.swing.GroupLayout.PREFERRED_SIZE, 92, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addComponent(aboutjSeparator, javax.swing.GroupLayout.PREFERRED_SIZE, 5, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addComponent(aboutOkButton)
                .addGap(10, 10, 10))
        );

        encryptDatabaseFrame.setTitle("Encrypt Database");
        encryptDatabaseFrame.setAlwaysOnTop(true);
        encryptDatabaseFrame.setBounds(new java.awt.Rectangle(0, 0, 0, 0));
        encryptDatabaseFrame.setMinimumSize(new java.awt.Dimension(520, 318));
        encryptDatabaseFrame.setResizable(false);

        encryptDatabasePasswordField.setColumns(50);
        encryptDatabasePasswordField.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        encryptDatabasePasswordField.setMaximumSize(new java.awt.Dimension(290, 30));
        encryptDatabasePasswordField.setMinimumSize(new java.awt.Dimension(290, 30));
        encryptDatabasePasswordField.setPreferredSize(new java.awt.Dimension(290, 30));
        encryptDatabasePasswordField.addKeyListener(new java.awt.event.KeyAdapter() {
            public void keyReleased(java.awt.event.KeyEvent evt) {
                encryptDatabasePasswordFieldKeyReleased(evt);
            }
            public void keyTyped(java.awt.event.KeyEvent evt) {
                encryptDatabasePasswordFieldKeyTyped(evt);
            }
        });

        encryptDatabasePasswordFieldLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        encryptDatabasePasswordFieldLabel.setText("Master Password:");
        encryptDatabasePasswordFieldLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        encryptDatabasePasswordFieldLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        encryptDatabasePasswordFieldLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        encryptDatabaseOKButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        encryptDatabaseOKButton.setMnemonic('O');
        encryptDatabaseOKButton.setText("OK");
        encryptDatabaseOKButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                encryptDatabaseOKButtonActionPerformed(evt);
            }
        });

        encryptDatabasePasswordConfirmField.setColumns(50);
        encryptDatabasePasswordConfirmField.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        encryptDatabasePasswordConfirmField.setMaximumSize(new java.awt.Dimension(290, 30));
        encryptDatabasePasswordConfirmField.setMinimumSize(new java.awt.Dimension(290, 30));
        encryptDatabasePasswordConfirmField.setPreferredSize(new java.awt.Dimension(290, 30));

        encryptDatabasePasswordConfirmFieldLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        encryptDatabasePasswordConfirmFieldLabel.setText("Confirm Password:");
        encryptDatabasePasswordConfirmFieldLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        encryptDatabasePasswordConfirmFieldLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        encryptDatabasePasswordConfirmFieldLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        encryptDatabaseShowPhraseCheckBox.setFont(new java.awt.Font("Open Sans", 1, 9)); // NOI18N
        encryptDatabaseShowPhraseCheckBox.setText("Show");
        encryptDatabaseShowPhraseCheckBox.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        encryptDatabaseShowPhraseCheckBox.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        encryptDatabaseShowPhraseCheckBox.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                encryptDatabaseShowPhraseCheckBoxActionPerformed(evt);
            }
        });

        encryptDatabasejProgressBar.setBorderPainted(true);
        encryptDatabasejProgressBar.setDebugGraphicsOptions(javax.swing.DebugGraphics.NONE_OPTION);
        encryptDatabasejProgressBar.setMaximumSize(new java.awt.Dimension(290, 20));
        encryptDatabasejProgressBar.setMinimumSize(new java.awt.Dimension(290, 20));
        encryptDatabasejProgressBar.setPreferredSize(new java.awt.Dimension(290, 20));

        encryptDatabasePasswordStrengthLabel.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        encryptDatabasePasswordStrengthLabel.setText("Complexity:");
        encryptDatabasePasswordStrengthLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        encryptDatabasePasswordStrengthLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        encryptDatabasePasswordStrengthLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        encryptDatabaseEntropyLabel.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        encryptDatabaseEntropyLabel.setText("Entropy Bits:");
        encryptDatabaseEntropyLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        encryptDatabaseEntropyLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        encryptDatabaseEntropyLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        encryptDatabaseEntropyValue.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        encryptDatabaseEntropyValue.setText("0.0");
        encryptDatabaseEntropyValue.setToolTipText(null);
        encryptDatabaseEntropyValue.setMaximumSize(new java.awt.Dimension(290, 18));
        encryptDatabaseEntropyValue.setMinimumSize(new java.awt.Dimension(290, 18));
        encryptDatabaseEntropyValue.setPreferredSize(new java.awt.Dimension(290, 18));

        encryptDatabaseLengthLabel.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        encryptDatabaseLengthLabel.setText("Length:");
        encryptDatabaseLengthLabel.setMaximumSize(new java.awt.Dimension(120, 18));
        encryptDatabaseLengthLabel.setMinimumSize(new java.awt.Dimension(120, 18));
        encryptDatabaseLengthLabel.setPreferredSize(new java.awt.Dimension(120, 18));

        encryptDatabaseLengthValue.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        encryptDatabaseLengthValue.setText("0");
        encryptDatabaseLengthValue.setMaximumSize(new java.awt.Dimension(290, 18));
        encryptDatabaseLengthValue.setMinimumSize(new java.awt.Dimension(290, 18));
        encryptDatabaseLengthValue.setPreferredSize(new java.awt.Dimension(290, 18));

        encryptDatabaseGeneratePasswordButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        encryptDatabaseGeneratePasswordButton.setMnemonic('G');
        encryptDatabaseGeneratePasswordButton.setText("Generate Memorable");
        encryptDatabaseGeneratePasswordButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                encryptDatabaseGeneratePasswordButtonActionPerformed(evt);
            }
        });

        encryptDatabaseBackgroundLabel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/keystash/resources/encryptWalletBG.png"))); // NOI18N
        encryptDatabaseBackgroundLabel.setToolTipText(null);

        encryptDatabaseSeparator.setMaximumSize(new java.awt.Dimension(520, 5));
        encryptDatabaseSeparator.setMinimumSize(new java.awt.Dimension(520, 5));
        encryptDatabaseSeparator.setPreferredSize(new java.awt.Dimension(520, 5));

        encryptDatabaseCancelButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        encryptDatabaseCancelButton.setMnemonic('C');
        encryptDatabaseCancelButton.setText("Cancel");
        encryptDatabaseCancelButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                encryptDatabaseCancelButtonActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout encryptDatabaseFrameLayout = new javax.swing.GroupLayout(encryptDatabaseFrame.getContentPane());
        encryptDatabaseFrame.getContentPane().setLayout(encryptDatabaseFrameLayout);
        encryptDatabaseFrameLayout.setHorizontalGroup(
            encryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(encryptDatabaseBackgroundLabel, javax.swing.GroupLayout.PREFERRED_SIZE, 520, javax.swing.GroupLayout.PREFERRED_SIZE)
            .addComponent(encryptDatabaseSeparator, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
            .addGroup(encryptDatabaseFrameLayout.createSequentialGroup()
                .addGap(10, 10, 10)
                .addGroup(encryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addGroup(encryptDatabaseFrameLayout.createSequentialGroup()
                        .addComponent(encryptDatabasePasswordConfirmFieldLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                        .addComponent(encryptDatabasePasswordConfirmField, javax.swing.GroupLayout.PREFERRED_SIZE, 290, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, encryptDatabaseFrameLayout.createSequentialGroup()
                        .addGroup(encryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                            .addGroup(encryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                                .addComponent(encryptDatabaseEntropyLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                                .addComponent(encryptDatabaseLengthLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                            .addComponent(encryptDatabasePasswordFieldLabel, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addGap(23, 23, 23)
                        .addGroup(encryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(encryptDatabasePasswordField, javax.swing.GroupLayout.PREFERRED_SIZE, 290, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(encryptDatabaseLengthValue, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(encryptDatabaseEntropyValue, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)))
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, encryptDatabaseFrameLayout.createSequentialGroup()
                        .addComponent(encryptDatabasePasswordStrengthLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                        .addComponent(encryptDatabasejProgressBar, javax.swing.GroupLayout.PREFERRED_SIZE, 290, javax.swing.GroupLayout.PREFERRED_SIZE)))
                .addGap(10, 10, 10)
                .addComponent(encryptDatabaseShowPhraseCheckBox)
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, encryptDatabaseFrameLayout.createSequentialGroup()
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addComponent(encryptDatabaseGeneratePasswordButton)
                .addGap(5, 5, 5)
                .addComponent(encryptDatabaseOKButton)
                .addGap(5, 5, 5)
                .addComponent(encryptDatabaseCancelButton)
                .addGap(32, 32, 32))
        );
        encryptDatabaseFrameLayout.setVerticalGroup(
            encryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(encryptDatabaseFrameLayout.createSequentialGroup()
                .addComponent(encryptDatabaseBackgroundLabel, javax.swing.GroupLayout.PREFERRED_SIZE, 60, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addGroup(encryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(encryptDatabaseShowPhraseCheckBox)
                    .addGroup(encryptDatabaseFrameLayout.createSequentialGroup()
                        .addGroup(encryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(encryptDatabasePasswordField, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(encryptDatabasePasswordFieldLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addGap(12, 12, 12)
                        .addGroup(encryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(encryptDatabasePasswordConfirmField, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(encryptDatabasePasswordConfirmFieldLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))))
                .addGap(12, 12, 12)
                .addGroup(encryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(encryptDatabasejProgressBar, javax.swing.GroupLayout.PREFERRED_SIZE, 20, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(encryptDatabasePasswordStrengthLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(12, 12, 12)
                .addGroup(encryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(encryptDatabaseEntropyValue, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(encryptDatabaseEntropyLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(12, 12, 12)
                .addGroup(encryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(encryptDatabaseLengthValue, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(encryptDatabaseLengthLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(10, 10, 10)
                .addComponent(encryptDatabaseSeparator, javax.swing.GroupLayout.PREFERRED_SIZE, 5, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addGroup(encryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(encryptDatabaseGeneratePasswordButton)
                    .addComponent(encryptDatabaseOKButton)
                    .addComponent(encryptDatabaseCancelButton))
                .addGap(10, 10, 10))
        );

        newAccountjProgressBar.setBackground(Color.red);
        newAccountjProgressBar.setForeground(Color.red);

        decryptDatabaseFrame.setTitle("Open Database");
        decryptDatabaseFrame.setAlwaysOnTop(true);
        decryptDatabaseFrame.setBackground(new java.awt.Color(255, 255, 255));
        decryptDatabaseFrame.setBounds(new java.awt.Rectangle(0, 0, 0, 0));
        decryptDatabaseFrame.setMinimumSize(new java.awt.Dimension(520, 190));
        decryptDatabaseFrame.setResizable(false);

        decryptDatabasePasswordField.setColumns(50);
        decryptDatabasePasswordField.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        decryptDatabasePasswordField.setFocusCycleRoot(true);
        decryptDatabasePasswordField.setMaximumSize(new java.awt.Dimension(290, 30));
        decryptDatabasePasswordField.setMinimumSize(new java.awt.Dimension(290, 30));
        decryptDatabasePasswordField.setPreferredSize(new java.awt.Dimension(290, 30));

        decryptDatabasePasswordFieldLabel.setFont(new java.awt.Font("Open Sans", 1, 12)); // NOI18N
        decryptDatabasePasswordFieldLabel.setText("Master Password:");
        decryptDatabasePasswordFieldLabel.setMaximumSize(new java.awt.Dimension(140, 18));
        decryptDatabasePasswordFieldLabel.setMinimumSize(new java.awt.Dimension(140, 18));
        decryptDatabasePasswordFieldLabel.setPreferredSize(new java.awt.Dimension(140, 18));

        decryptDatabaseOKButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        decryptDatabaseOKButton.setMnemonic('O');
        decryptDatabaseOKButton.setText("OK");
        decryptDatabaseOKButton.setFocusable(false);
        decryptDatabaseOKButton.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        decryptDatabaseOKButton.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        decryptDatabaseOKButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                decryptDatabaseOKButtonActionPerformed(evt);
            }
        });

        decryptDatabaseShowPhraseCheckBox.setFont(new java.awt.Font("Open Sans", 1, 9)); // NOI18N
        decryptDatabaseShowPhraseCheckBox.setText("Show");
        decryptDatabaseShowPhraseCheckBox.setFocusable(false);
        decryptDatabaseShowPhraseCheckBox.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        decryptDatabaseShowPhraseCheckBox.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        decryptDatabaseShowPhraseCheckBox.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                decryptDatabaseShowPhraseCheckBoxActionPerformed(evt);
            }
        });

        decryptDatabaseBackgroundLabel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/keystash/resources/decryptWalletBG.png"))); // NOI18N
        decryptDatabaseBackgroundLabel.setToolTipText(null);

        decryptDatabaseSeparator.setBackground(new java.awt.Color(204, 204, 204));
        decryptDatabaseSeparator.setForeground(new java.awt.Color(204, 204, 204));
        decryptDatabaseSeparator.setMaximumSize(new java.awt.Dimension(520, 5));
        decryptDatabaseSeparator.setMinimumSize(new java.awt.Dimension(520, 5));
        decryptDatabaseSeparator.setPreferredSize(new java.awt.Dimension(520, 5));

        decryptDatabaseCancelButton.setFont(new java.awt.Font("Open Sans", 0, 11)); // NOI18N
        decryptDatabaseCancelButton.setMnemonic('C');
        decryptDatabaseCancelButton.setText("Cancel");
        decryptDatabaseCancelButton.setFocusable(false);
        decryptDatabaseCancelButton.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        decryptDatabaseCancelButton.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        decryptDatabaseCancelButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                decryptDatabaseCancelButtonActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout decryptDatabaseFrameLayout = new javax.swing.GroupLayout(decryptDatabaseFrame.getContentPane());
        decryptDatabaseFrame.getContentPane().setLayout(decryptDatabaseFrameLayout);
        decryptDatabaseFrameLayout.setHorizontalGroup(
            decryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(decryptDatabaseBackgroundLabel, javax.swing.GroupLayout.PREFERRED_SIZE, 520, javax.swing.GroupLayout.PREFERRED_SIZE)
            .addComponent(decryptDatabaseSeparator, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
            .addGroup(decryptDatabaseFrameLayout.createSequentialGroup()
                .addGroup(decryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(decryptDatabaseFrameLayout.createSequentialGroup()
                        .addGap(10, 10, 10)
                        .addComponent(decryptDatabasePasswordFieldLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addGap(3, 3, 3)
                        .addComponent(decryptDatabasePasswordField, javax.swing.GroupLayout.PREFERRED_SIZE, 290, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addGap(10, 10, 10)
                        .addComponent(decryptDatabaseShowPhraseCheckBox))
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, decryptDatabaseFrameLayout.createSequentialGroup()
                        .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                        .addComponent(decryptDatabaseOKButton)
                        .addGap(5, 5, 5)
                        .addComponent(decryptDatabaseCancelButton)))
                .addGap(32, 32, 32))
        );
        decryptDatabaseFrameLayout.setVerticalGroup(
            decryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(decryptDatabaseFrameLayout.createSequentialGroup()
                .addComponent(decryptDatabaseBackgroundLabel, javax.swing.GroupLayout.PREFERRED_SIZE, 60, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addGroup(decryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(decryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                        .addComponent(decryptDatabasePasswordField, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addComponent(decryptDatabasePasswordFieldLabel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addComponent(decryptDatabaseShowPhraseCheckBox))
                .addGap(10, 10, 10)
                .addComponent(decryptDatabaseSeparator, javax.swing.GroupLayout.PREFERRED_SIZE, 5, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(10, 10, 10)
                .addGroup(decryptDatabaseFrameLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(decryptDatabaseOKButton)
                    .addComponent(decryptDatabaseCancelButton))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
        setTitle("KeyStash");
        setBounds(new java.awt.Rectangle(0, 0, 0, 0));
        setResizable(false);

        accountTable.setAutoCreateRowSorter(true);
        accountTable.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        accountTable.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {

            },
            new String [] {
                "#", "Account Address", "Label", "Created"
            }
        ) {
            Class[] types = new Class [] {
                java.lang.Integer.class, java.lang.String.class, java.lang.String.class, java.lang.String.class
            };
            boolean[] canEdit = new boolean [] {
                false, false, false, false
            };

            public Class getColumnClass(int columnIndex) {
                return types [columnIndex];
            }

            public boolean isCellEditable(int rowIndex, int columnIndex) {
                return canEdit [columnIndex];
            }
        });
        accountTable.setAutoscrolls(false);
        accountTable.setRowSelectionAllowed(false);
        accountTable.getTableHeader().setReorderingAllowed(false);
        accountTable.setUpdateSelectionOnSort(false);
        accountTable.setVerifyInputWhenFocusTarget(false);
        accountTable.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseClicked(java.awt.event.MouseEvent evt) {
                accountTableMouseClicked(evt);
            }
            public void mousePressed(java.awt.event.MouseEvent evt) {
                accountTableMousePressed(evt);
            }
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                accountTableMouseReleased(evt);
            }
        });
        accountScrollPane.setViewportView(accountTable);
        if (accountTable.getColumnModel().getColumnCount() > 0) {
            accountTable.getColumnModel().getColumn(0).setMinWidth(35);
            accountTable.getColumnModel().getColumn(0).setMaxWidth(35);
            accountTable.getColumnModel().getColumn(1).setMinWidth(190);
            accountTable.getColumnModel().getColumn(1).setMaxWidth(200);
            accountTable.getColumnModel().getColumn(2).setMinWidth(90);
            accountTable.getColumnModel().getColumn(2).setMaxWidth(90);
            accountTable.getColumnModel().getColumn(3).setMinWidth(220);
            accountTable.getColumnModel().getColumn(3).setMaxWidth(220);
        }

        mainMenuBar.setBorder(null);

        fileMenu.setMnemonic('F');
        fileMenu.setText("File");
        fileMenu.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N

        accountMenuItem.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        accountMenuItem.setMnemonic('N');
        accountMenuItem.setText("New Account");
        accountMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                accountMenuItemActionPerformed(evt);
            }
        });
        fileMenu.add(accountMenuItem);

        backupMenuItem.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        backupMenuItem.setMnemonic('B');
        backupMenuItem.setText("Backup");
        backupMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                backupMenuItemActionPerformed(evt);
            }
        });
        fileMenu.add(backupMenuItem);
        fileMenu.add(fileMenuSeperator);

        exitMenuItem.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        exitMenuItem.setMnemonic('E');
        exitMenuItem.setText("Exit");
        exitMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                exitMenuItemActionPerformed(evt);
            }
        });
        fileMenu.add(exitMenuItem);

        mainMenuBar.add(fileMenu);

        settingsMenu.setMnemonic('S');
        settingsMenu.setText("Settings");
        settingsMenu.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N

        enableApiMenuItem.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        enableApiMenuItem.setMnemonic('E');
        enableApiMenuItem.setText("Enable Api");
        enableApiMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                enableApiMenuItemActionPerformed(evt);
            }
        });
        settingsMenu.add(enableApiMenuItem);

        encryptDatabaseMenuItem.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        encryptDatabaseMenuItem.setText("Encrypt Database");
        encryptDatabaseMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                encryptDatabaseMenuItemActionPerformed(evt);
            }
        });
        settingsMenu.add(encryptDatabaseMenuItem);

        preferencesMenuItem.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        preferencesMenuItem.setMnemonic('P');
        preferencesMenuItem.setText("Preferences");
        preferencesMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                preferencesMenuItemActionPerformed(evt);
            }
        });
        settingsMenu.add(preferencesMenuItem);

        mainMenuBar.add(settingsMenu);

        helpMenu.setMnemonic('H');
        helpMenu.setText("Help");
        helpMenu.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N

        aboutMenuItem.setFont(new java.awt.Font("Open Sans", 0, 12)); // NOI18N
        aboutMenuItem.setMnemonic('A');
        aboutMenuItem.setText("About KeyStash");
        aboutMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                aboutMenuItemActionPerformed(evt);
            }
        });
        helpMenu.add(aboutMenuItem);

        mainMenuBar.add(helpMenu);

        setJMenuBar(mainMenuBar);

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(accountScrollPane, javax.swing.GroupLayout.DEFAULT_SIZE, 531, Short.MAX_VALUE)
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(accountScrollPane, javax.swing.GroupLayout.DEFAULT_SIZE, 408, Short.MAX_VALUE)
                .addContainerGap())
        );

        pack();
        setLocationRelativeTo(null);
    }// </editor-fold>//GEN-END:initComponents

    private void accountMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_accountMenuItemActionPerformed

        newAccountFrame.setVisible(true);
        newAccountFrame.setLocationRelativeTo(null);
        newAccountShowPhraseCheckBox.setSelected(false);
        accountMenuItem.setEnabled(false);
        newAccountPasswordField.setEchoChar('*');
        newAccountPasswordConfirmField.setEchoChar('*');
        newAccountPasswordField.setText("");
        newAccountPasswordConfirmField.setText("");
        newAccountjProgressBar.setValue(0);
        newAccountEntropyValue.setText("0.0");
        newAccountLengthValue.setText("0");
        newAccountPasswordField.requestFocus();
        newAccountPasswordStrengthLabel.setText("Complexity:");
        newAccountPasswordField.putClientProperty("JPasswordField.cutCopyAllowed", true);
        newAccountPasswordConfirmField.putClientProperty("JPasswordField.cutCopyAllowed", true);
        MenuItem.enableMenu(false);
        newAccountFrame.addWindowListener(new WindowAdapter() {
            @Override
            public void windowClosing(WindowEvent we) {
                MenuItem.enableMenu(true);
                accountMenuItem.setEnabled(true);
            }
        });
        guiShowWarnings = Convert.stringToBoolean(Db.selectFromSettings("show_warnings", "keystash_settings", "settings_id", 1));
        if (guiShowWarnings) {
            Dialog.showDialog("You will lose all access if you forget the primary password!", "Note");
        }

    }//GEN-LAST:event_accountMenuItemActionPerformed

    private void newAccountOKButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_newAccountOKButtonActionPerformed

        char[] checkPassword1 = newAccountPasswordField.getPassword();
        char[] checkPassword2 = newAccountPasswordConfirmField.getPassword();

        if (!Arrays.equals(checkPassword1, checkPassword2)) {
            Dialog.showDialog("Passwords do not match!", "Note");
        }
        else {
            if (checkPassword1.length < Constants.minPasswordChars) {
                Dialog.showDialog("Password must contain at least " + Constants.minPasswordChars + " characters!", "Note");
            }
            else {

                globalPassword = checkPassword1;

                char[] myPhrase = null;
                try {
                    myPhrase = PhraseGenerator.generatePhrase();
                } catch (NoSuchAlgorithmException | NoSuchProviderException ex) {
                    Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
                }

                secret = myPhrase;

                byte[] secretPhrase = Crypto.getPublicKey(new String(secret));
                Long secretPhraseConvert = Convert.getId(secretPhrase);

                String addressRs = Convert.rsAccount(secretPhraseConvert);
                confirmNewAccountShowAddressRsLabel.setText(addressRs);
                confirmNewAccountPhraseField.setText(new String(myPhrase));
                int passLength = secret.length;
                String passLengthString = String.valueOf(passLength);
                double shannonEntropy = PasswordStrength.getShannonEntropy(new String(secret));
                String shannonEntropyString = String.valueOf(shannonEntropy);
                confirmNewAccountEntropyValue.setText(shannonEntropyString);
                confirmNewAccountLengthValue.setText(passLengthString);
                newAccountFrame.setVisible(false);
                confirmNewAccountFrame.setVisible(true);

                confirmNewAccountFrame.setLocationRelativeTo(null);
                confirmNewAccountShowPhraseCheckBox.setSelected(false);
                confirmNewAccountPhraseField.setEchoChar('*');
                confirmNewAccountPhraseField.putClientProperty("JPasswordField.cutCopyAllowed", true);
                confirmNewAccountAttemptValueLabel.setText("0");
                confirmNewAccountIncludeLettersField.setText("NXT-     ");
                confirmNewAccountAttemptLabel.setEnabled(false);
                confirmNewAccountAttemptValueLabel.setEnabled(false);
                confirmNewAccountGenerateNewPhraseButton.setEnabled(true);
                confirmNewAccountOKButton.setEnabled(true);
                confirmNewAccountIncludeLettersField.setEnabled(true);
                confirmNewAccountOKButton.requestFocus();
                confirmNewAccountFrame.addWindowListener(new WindowAdapter() {
                    @Override
                    public void windowClosing(WindowEvent we) {
                        confirmNewAccountAttemptLabel.setEnabled(false);
                        confirmNewAccountAttemptValueLabel.setEnabled(false);
                        confirmNewAccountGenerateNewPhraseButton.setEnabled(true);
                        confirmNewAccountOKButton.setEnabled(true);
                        confirmNewAccountIncludeLettersField.setEnabled(true);
                        confirmNewAccountSearchAddressToggleButton.setSelected(false);
                        backgroundMenu = 0;
                        accountMenuItem.setEnabled(true);
                        MenuItem.enableMenu(true);
                    }
                });

            }
        }

    }//GEN-LAST:event_newAccountOKButtonActionPerformed

    private void newAccountShowPhraseCheckBoxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_newAccountShowPhraseCheckBoxActionPerformed

        boolean showPhrase = newAccountShowPhraseCheckBox.isSelected();

        if (showPhrase) {
            newAccountPasswordField.setEchoChar((char) 0);
            newAccountPasswordConfirmField.setEchoChar((char) 0);
        }
        else {
            newAccountPasswordField.setEchoChar('*');
            newAccountPasswordConfirmField.setEchoChar('*');
        }

    }//GEN-LAST:event_newAccountShowPhraseCheckBoxActionPerformed

    private void accountTableMouseClicked(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_accountTableMouseClicked

        row = accountTable.rowAtPoint(evt.getPoint());
        int col = accountTable.columnAtPoint(evt.getPoint());
        Object rowValue;
        Object rowValueChanged;
        int realRow = row;

        if (row >= 0 && col >= 0) {
            list.add(row);
            rowValue = accountTable.getValueAt(row, col);

            if (list.size() > 1) {
                tmpList = list.get(list.size() - 2);
            }
        }

    }//GEN-LAST:event_accountTableMouseClicked

    private void accountTableMousePressed(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_accountTableMousePressed

        if (row != null) {
            if (evt.isPopupTrigger()) {
                showDetailPopup.show(evt.getComponent(), evt.getX(), evt.getY());
            }
        }

    }//GEN-LAST:event_accountTableMousePressed

    private void accountTableMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_accountTableMouseReleased

        row = accountTable.rowAtPoint(evt.getPoint());
        int col = accountTable.columnAtPoint(evt.getPoint());
        Object rowValue;
        Object rowValueChanged;
        int realRow = row;

        if (row >= 0 && col >= 0) {
            list.add(row);
            rowValue = accountTable.getValueAt(row, col);

            if (list.size() > 1) {
                tmpList = list.get(list.size() - 2);
            }

        }
        if (row != null) {
            if (evt.isPopupTrigger()) {
                showDetailPopup.show(evt.getComponent(), evt.getX(), evt.getY());
            }
        }

    }//GEN-LAST:event_accountTableMouseReleased

    private void enterPrimaryPasswordAccountDetailsShowPhraseCheckBoxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_enterPrimaryPasswordAccountDetailsShowPhraseCheckBoxActionPerformed

        boolean showPhrase = enterPrimaryPasswordAccountDetailsShowPhraseCheckBox.isSelected();

        if (showPhrase) {
            enterPrimaryPasswordAccountDetailsPasswordField.setEchoChar((char) 0);
        }
        else {
            enterPrimaryPasswordAccountDetailsPasswordField.setEchoChar('*');
        }

    }//GEN-LAST:event_enterPrimaryPasswordAccountDetailsShowPhraseCheckBoxActionPerformed

    private void accountDetailsShowPhraseCheckBoxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_accountDetailsShowPhraseCheckBoxActionPerformed

        boolean showPhrase = accountDetailsShowPhraseCheckBox.isSelected();

        if (showPhrase) {
            accountDetailsPhraseField.setEchoChar((char) 0);
        }
        else {
            accountDetailsPhraseField.setEchoChar('*');
        }

    }//GEN-LAST:event_accountDetailsShowPhraseCheckBoxActionPerformed

    private void newAccountPasswordFieldKeyTyped(java.awt.event.KeyEvent evt) {//GEN-FIRST:event_newAccountPasswordFieldKeyTyped

        char[] checkPassword = newAccountPasswordField.getPassword();
        newAccountLengthValue.setText(Convert.intToString(checkPassword.length));
        double shannonEntropy = PasswordStrength.getShannonEntropy(new String(checkPassword));
        newAccountEntropyValue.setText(String.valueOf(shannonEntropy));
        int showPasswordStrenght = PasswordStrength.checkPasswordStrength(new String(checkPassword));
        long shannonLong = (long) shannonEntropy;

        if (showPasswordStrenght == 0 && shannonLong <= 1) {
            newAccountjProgressBar.setValue(0);
            newAccountPasswordStrengthLabel.setText("Complexity:");
        }

        if (showPasswordStrenght >= 25 && shannonLong == 2) {
            newAccountjProgressBar.setValue(25);
            newAccountPasswordStrengthLabel.setText("Complexity: Weak");
        }

        if (showPasswordStrenght >= 50 && shannonLong == 3) {
            newAccountjProgressBar.setValue(50);
            newAccountPasswordStrengthLabel.setText("Complexity: Good");
        }

        if (showPasswordStrenght >= 75 && shannonLong == 4) {
            newAccountjProgressBar.setValue(75);
            newAccountPasswordStrengthLabel.setText("Complexity: Very good");
        }

        if (showPasswordStrenght == 100 && shannonLong == 5) {
            newAccountjProgressBar.setValue(100);
            newAccountPasswordStrengthLabel.setText("Complexity: Strong");
        }

        if (checkPassword.length <= 5) {
            newAccountjProgressBar.setValue(0);
            newAccountPasswordStrengthLabel.setText("Complexity: Very weak");
        }

        if (checkPassword.length == 0) {
            newAccountjProgressBar.setValue(0);
            newAccountPasswordStrengthLabel.setText("Complexity:");
        }

        Memory.clearPasswordMemory(checkPassword);

    }//GEN-LAST:event_newAccountPasswordFieldKeyTyped

    private void exitMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_exitMenuItemActionPerformed

        System.exit(0);

    }//GEN-LAST:event_exitMenuItemActionPerformed

    private void accountDetailsCopyButton1ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_accountDetailsCopyButton1ActionPerformed

        if (!lockClearClipboardButton) {
            lockClearClipboardButton = true;
            accountDetailsjProgressBar.setValue(100);
            accountDetailsCopyButton2.setEnabled(false);
            char[] copyValue = accountDetailsPhraseField.getPassword();
            String passwordString = new String(copyValue);
            StringSelection stringSelection = new StringSelection(passwordString);
            Clipboard clpbrd = Toolkit.getDefaultToolkit().getSystemClipboard();
            clpbrd.setContents(stringSelection, null);
            backgroundMenu = 1;
            accountDetailsjProgressBar.setString("Clear Private Phrase From Clipboard");
        }

    }//GEN-LAST:event_accountDetailsCopyButton1ActionPerformed

    private void accountDetailsCopyButton2ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_accountDetailsCopyButton2ActionPerformed

        StringSelection stringSelection = new StringSelection(accountDetailsPublicKeyField.getText());
        Clipboard clpbrd = Toolkit.getDefaultToolkit().getSystemClipboard();
        clpbrd.setContents(stringSelection, null);

    }//GEN-LAST:event_accountDetailsCopyButton2ActionPerformed

    private void showAccountDetailsItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_showAccountDetailsItemActionPerformed

        enterPrimaryPasswordAccountDetailsFrame.setVisible(true);
        enterPrimaryPasswordAccountDetailsFrame.setLocationRelativeTo(null);
        enterPrimaryPasswordAccountDetailsPasswordField.setText("");
        enterPrimaryPasswordAccountDetailsShowPhraseCheckBox.setSelected(false);
        enterPrimaryPasswordAccountDetailsPasswordField.setEchoChar('*');
        enterPrimaryPasswordAccountDetailsPasswordField.requestFocus();
        MenuItem.enableMenu(false);
        enterPrimaryPasswordAccountDetailsFrame.addWindowListener(new WindowAdapter() {
            @Override
            public void windowClosing(WindowEvent we) {
                MenuItem.enableMenu(true);
            }
        });

    }//GEN-LAST:event_showAccountDetailsItemActionPerformed

    private void accountDetailsjProgressBarStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_accountDetailsjProgressBarStateChanged


    }//GEN-LAST:event_accountDetailsjProgressBarStateChanged

    @SuppressWarnings("null")
    private void backupMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_backupMenuItemActionPerformed

        this.setLocationRelativeTo(null);

        Db.walletClose();

        String f = Constants.walletPath;

        JFileChooser chooser = new JFileChooser();
        chooser.setSelectedFile(new File("wallet.h2.db"));
        chooser.setDialogTitle("Specify a directory to save");

        int userSelection = chooser.showSaveDialog(this);
        if (userSelection == JFileChooser.APPROVE_OPTION) {

            DataInputStream dis = null;
            try {
                dis = new DataInputStream(new FileInputStream(f));
            } catch (FileNotFoundException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }
            ByteArrayOutputStream buffer = new ByteArrayOutputStream();

            int nRead;
            byte[] data = null;
            try {
                data = new byte[dis.available()];
            } catch (IOException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }

            try {
                while ((nRead = dis.read(data, 0, data.length)) != -1) {
                    buffer.write(data, 0, nRead);
                }
            } catch (IOException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }

            try {
                buffer.flush();
            } catch (IOException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }

            ByteArrayOutputStream baos = new ByteArrayOutputStream();
            DataOutputStream dataOutStream = new DataOutputStream(baos);
            try {
                dataOutStream.write(data);
            } catch (IOException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }

            OutputStream outputStream = null;
            try {
                outputStream = new FileOutputStream(chooser.getSelectedFile());
            } catch (FileNotFoundException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }
            try {
                baos.writeTo(outputStream);
            } catch (IOException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }
            try {
                baos.close(); //Lets close some streams 
            } catch (IOException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }
            try {
                dataOutStream.close();
            } catch (IOException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }
            try {
                outputStream.close();
            } catch (IOException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }
            try {
                buffer.close();
            } catch (IOException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }
            try {
                dis.close();
            } catch (IOException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }

        }

    }//GEN-LAST:event_backupMenuItemActionPerformed

    private void newAccountPasswordFieldKeyReleased(java.awt.event.KeyEvent evt) {//GEN-FIRST:event_newAccountPasswordFieldKeyReleased

        char[] checkPassword = newAccountPasswordField.getPassword();
        newAccountLengthValue.setText(Convert.intToString(checkPassword.length));

    }//GEN-LAST:event_newAccountPasswordFieldKeyReleased

    private void preferencesMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_preferencesMenuItemActionPerformed

        preferencesMenuItem.setEnabled(false);
        try {

            int getKeySize = Convert.stringToInt(Db.selectFromSettings("secret_key_size", "keystash_settings", "settings_id", 1));
            int keySizeComboBox = 0;
            boolean isMaxKeyLength = false;
            try {
                isMaxKeyLength = KeyLength.isUnlimitedKeyStrength();
            } catch (NoSuchAlgorithmException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }

            if (getKeySize == 128) {
                keySizeComboBox = 0;
            }
            else if (getKeySize == 256 && isMaxKeyLength) {
                keySizeComboBox = 1;
            }

            if (!isMaxKeyLength) {
                Db.walletUpdateSettings(1, "secret_key_size", Convert.intToString(Constants.secretKeySize[0]));
            }

            showPreferencesFrame.setVisible(true);
            showPreferencesFrame.setLocationRelativeTo(null);
            showPreferencesOKButton.requestFocus();

            MenuItem.enableMenu(false);
            showPreferencesFrame.addWindowListener(new WindowAdapter() {
                @Override
                public void windowClosing(WindowEvent we) {
                    MenuItem.enableMenu(true);
                }
            });

            showPreferencesWarningsCheckbox.setSelected(Convert.stringToBoolean(Db.selectFromSettings("show_warnings", "keystash_settings", "settings_id", 1)));
            showPreferencesClearClipboardSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("clear_clipboard", "keystash_settings", "settings_id", 1)));
            showPreferencesRandomGenerationCheckbox.setSelected(Convert.stringToBoolean(Db.selectFromSettings("random_generation", "keystash_settings", "settings_id", 1)));
            if (Convert.stringToBoolean(Db.selectFromSettings("random_generation", "keystash_settings", "settings_id", 1))) {
                showPreferencesPhraseBlocksSpinner.setEnabled(true);
                showPreferencesIterationSpinner.setEnabled(true);
                showPreferencesWhitespaceCheckbox.setEnabled(true);
                showPreferencesANSICheckbox.setEnabled(true);
                showPreferencesLengthMinimumMinSpinner.setEnabled(true);
                showPreferencesLengthMinimumMaxSpinner.setEnabled(true);
                showPreferencesLengthMaximumMinSpinner.setEnabled(true);
                showPreferencesLengthMaximumMaxSpinner.setEnabled(true);
                showPreferencesLowerCaseMinSpinner.setEnabled(true);
                showPreferencesLowerCaseMaxSpinner.setEnabled(true);
                showPreferencesUpperCaseMinSpinner.setEnabled(true);
                showPreferencesUpperCaseMaxSpinner.setEnabled(true);
                showPreferencesNumeraryMinSpinner.setEnabled(true);
                showPreferencesNumeraryMaxSpinner.setEnabled(true);
                showPreferencesSpecialCharMinSpinner.setEnabled(true);
                showPreferencesSpecialCharMaxSpinner.setEnabled(true);
                showPreferencesResetSettingsButton.setEnabled(true);
                showPreferencesKeySizeComboBox.setEnabled(true);
            }
            else {
                showPreferencesPhraseBlocksSpinner.setEnabled(false);
                showPreferencesWhitespaceCheckbox.setEnabled(false);
                showPreferencesANSICheckbox.setEnabled(false);
                showPreferencesIterationSpinner.setEnabled(false);
                showPreferencesLengthMinimumMinSpinner.setEnabled(false);
                showPreferencesLengthMinimumMaxSpinner.setEnabled(false);
                showPreferencesLengthMaximumMinSpinner.setEnabled(false);
                showPreferencesLengthMaximumMaxSpinner.setEnabled(false);
                showPreferencesLowerCaseMinSpinner.setEnabled(false);
                showPreferencesLowerCaseMaxSpinner.setEnabled(false);
                showPreferencesUpperCaseMinSpinner.setEnabled(false);
                showPreferencesUpperCaseMaxSpinner.setEnabled(false);
                showPreferencesNumeraryMinSpinner.setEnabled(false);
                showPreferencesNumeraryMaxSpinner.setEnabled(false);
                showPreferencesSpecialCharMinSpinner.setEnabled(false);
                showPreferencesSpecialCharMaxSpinner.setEnabled(false);
                showPreferencesResetSettingsButton.setEnabled(false);
                showPreferencesKeySizeComboBox.setEnabled(false);
            }

            showPreferencesWhitespaceCheckbox.setSelected(Convert.stringToBoolean(Db.selectFromSettings("enable_whitespace", "keystash_settings", "settings_id", 1)));
            showPreferencesANSICheckbox.setSelected(Convert.stringToBoolean(Db.selectFromSettings("enable_ansi", "keystash_settings", "settings_id", 1)));
            showPreferencesPhraseBlocksSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("phrase_blocks", "keystash_settings", "settings_id", 1)));
            showPreferencesIterationSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("secret_iteration", "keystash_settings", "settings_id", 1)));
            showPreferencesLengthMinimumMinSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("Length_minimum_min", "keystash_settings", "settings_id", 1)));
            showPreferencesLengthMinimumMaxSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("Length_minimum_max", "keystash_settings", "settings_id", 1)));
            showPreferencesLengthMaximumMinSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("Length_maximum_min", "keystash_settings", "settings_id", 1)));
            showPreferencesLengthMaximumMaxSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("Length_maximum_max", "keystash_settings", "settings_id", 1)));
            showPreferencesLowerCaseMinSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("lower_case_min", "keystash_settings", "settings_id", 1)));
            showPreferencesLowerCaseMaxSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("lower_case_max", "keystash_settings", "settings_id", 1)));
            showPreferencesUpperCaseMinSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("upper_case_min", "keystash_settings", "settings_id", 1)));
            showPreferencesUpperCaseMaxSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("upper_case_max", "keystash_settings", "settings_id", 1)));
            showPreferencesNumeraryMinSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("numerary_min", "keystash_settings", "settings_id", 1)));
            showPreferencesNumeraryMaxSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("numerary_max", "keystash_settings", "settings_id", 1)));
            showPreferencesSpecialCharMinSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("special_char_min", "keystash_settings", "settings_id", 1)));
            showPreferencesSpecialCharMaxSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("special_char_max", "keystash_settings", "settings_id", 1)));
            showPreferencesKeySizeComboBox.setSelectedIndex(keySizeComboBox);

        } catch (Exception e) {
            System.err.println("Database Settings already in use or corrupted.");
        }
    }//GEN-LAST:event_preferencesMenuItemActionPerformed

    private void showPreferencesWarningsCheckboxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_showPreferencesWarningsCheckboxActionPerformed

        boolean checkBox = showPreferencesWarningsCheckbox.isSelected();
        String checkBoxString = Boolean.toString(checkBox);
        int tableId = 1;
        String where = "show_warnings";

        if (checkBox) {
            Db.walletUpdateSettings(tableId, where, checkBoxString);
        }
        else {
            Db.walletUpdateSettings(tableId, where, checkBoxString);
        }

    }//GEN-LAST:event_showPreferencesWarningsCheckboxActionPerformed

    private void showPreferencesRandomGenerationCheckboxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_showPreferencesRandomGenerationCheckboxActionPerformed

        boolean checkBox = showPreferencesRandomGenerationCheckbox.isSelected();
        String checkBoxString = Boolean.toString(checkBox);
        int tableId = 1;
        String where = "random_generation";
        int getKeySize = Convert.stringToInt(Db.selectFromSettings("secret_key_size", "keystash_settings", "settings_id", 1));
        int keySizeComboBox = 0;

        if (getKeySize == 128) {
            keySizeComboBox = 0;
        }
        else if (getKeySize == 256) {
            keySizeComboBox = 1;
        }

        if (checkBox) {
            Db.walletUpdateSettings(tableId, where, checkBoxString);
            showPreferencesPhraseBlocksSpinner.setEnabled(true);
            showPreferencesWhitespaceCheckbox.setEnabled(true);
            showPreferencesANSICheckbox.setEnabled(true);
            showPreferencesIterationSpinner.setEnabled(true);
            showPreferencesLengthMinimumMinSpinner.setEnabled(true);
            showPreferencesLengthMinimumMaxSpinner.setEnabled(true);
            showPreferencesLengthMaximumMinSpinner.setEnabled(true);
            showPreferencesLengthMaximumMaxSpinner.setEnabled(true);
            showPreferencesLowerCaseMinSpinner.setEnabled(true);
            showPreferencesLowerCaseMaxSpinner.setEnabled(true);
            showPreferencesUpperCaseMinSpinner.setEnabled(true);
            showPreferencesUpperCaseMaxSpinner.setEnabled(true);
            showPreferencesNumeraryMinSpinner.setEnabled(true);
            showPreferencesNumeraryMaxSpinner.setEnabled(true);
            showPreferencesSpecialCharMinSpinner.setEnabled(true);
            showPreferencesSpecialCharMaxSpinner.setEnabled(true);
            showPreferencesResetSettingsButton.setEnabled(true);
            showPreferencesKeySizeComboBox.setEnabled(true);
            showPreferencesPhraseBlocksSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("phrase_blocks", "keystash_settings", "settings_id", 1)));
            showPreferencesIterationSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("secret_iteration", "keystash_settings", "settings_id", 1)));
            showPreferencesWhitespaceCheckbox.setSelected(Convert.stringToBoolean(Db.selectFromSettings("enable_whitespace", "keystash_settings", "settings_id", 1)));
            showPreferencesANSICheckbox.setSelected(Convert.stringToBoolean(Db.selectFromSettings("enable_ansi", "keystash_settings", "settings_id", 1)));
            showPreferencesLengthMinimumMinSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("Length_minimum_min", "keystash_settings", "settings_id", 1)));
            showPreferencesLengthMinimumMaxSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("Length_minimum_max", "keystash_settings", "settings_id", 1)));
            showPreferencesLengthMaximumMinSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("Length_maximum_min", "keystash_settings", "settings_id", 1)));
            showPreferencesLengthMaximumMaxSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("Length_maximum_max", "keystash_settings", "settings_id", 1)));
            showPreferencesLowerCaseMinSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("lower_case_min", "keystash_settings", "settings_id", 1)));
            showPreferencesLowerCaseMaxSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("lower_case_max", "keystash_settings", "settings_id", 1)));
            showPreferencesUpperCaseMinSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("upper_case_min", "keystash_settings", "settings_id", 1)));
            showPreferencesUpperCaseMaxSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("upper_case_max", "keystash_settings", "settings_id", 1)));
            showPreferencesNumeraryMinSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("numerary_min", "keystash_settings", "settings_id", 1)));
            showPreferencesNumeraryMaxSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("numerary_max", "keystash_settings", "settings_id", 1)));
            showPreferencesSpecialCharMinSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("special_char_min", "keystash_settings", "settings_id", 1)));
            showPreferencesSpecialCharMaxSpinner.setValue(Convert.stringToInt(Db.selectFromSettings("special_char_max", "keystash_settings", "settings_id", 1)));
            showPreferencesKeySizeComboBox.setSelectedIndex(keySizeComboBox);
        }
        else {
            Db.walletUpdateSettings(tableId, where, checkBoxString);
            showPreferencesPhraseBlocksSpinner.setEnabled(false);
            showPreferencesIterationSpinner.setEnabled(false);
            showPreferencesWhitespaceCheckbox.setEnabled(false);
            showPreferencesANSICheckbox.setEnabled(false);
            showPreferencesLengthMinimumMinSpinner.setEnabled(false);
            showPreferencesLengthMinimumMaxSpinner.setEnabled(false);
            showPreferencesLengthMaximumMinSpinner.setEnabled(false);
            showPreferencesLengthMaximumMaxSpinner.setEnabled(false);
            showPreferencesLowerCaseMinSpinner.setEnabled(false);
            showPreferencesLowerCaseMaxSpinner.setEnabled(false);
            showPreferencesUpperCaseMinSpinner.setEnabled(false);
            showPreferencesUpperCaseMaxSpinner.setEnabled(false);
            showPreferencesNumeraryMinSpinner.setEnabled(false);
            showPreferencesNumeraryMaxSpinner.setEnabled(false);
            showPreferencesSpecialCharMinSpinner.setEnabled(false);
            showPreferencesSpecialCharMaxSpinner.setEnabled(false);
            showPreferencesResetSettingsButton.setEnabled(false);
            showPreferencesKeySizeComboBox.setEnabled(false);
        }

    }//GEN-LAST:event_showPreferencesRandomGenerationCheckboxActionPerformed

    private void showPreferencesClearClipboardSpinnerStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_showPreferencesClearClipboardSpinnerStateChanged

        Object spinner = showPreferencesClearClipboardSpinner.getValue();
        String spinnerString = String.valueOf(spinner);
        int tableId = 1;
        String where = "clear_clipboard";

        Db.walletUpdateSettings(tableId, where, spinnerString);

    }//GEN-LAST:event_showPreferencesClearClipboardSpinnerStateChanged

    private void showPreferencesPhraseBlocksSpinnerStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_showPreferencesPhraseBlocksSpinnerStateChanged

        Object spinner = showPreferencesPhraseBlocksSpinner.getValue();
        String spinnerString = String.valueOf(spinner);
        int tableId = 1;
        String where = "phrase_blocks";
        Db.walletUpdateSettings(tableId, where, spinnerString);

    }//GEN-LAST:event_showPreferencesPhraseBlocksSpinnerStateChanged

    private void showPreferencesLengthMinimumMinSpinnerStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_showPreferencesLengthMinimumMinSpinnerStateChanged

        Object spinner = showPreferencesLengthMinimumMinSpinner.getValue();
        String spinnerString = String.valueOf(spinner);
        int spinnerInt = Convert.stringToInt(spinnerString);
        int spinnerIntNeighbour = Convert.stringToInt(Db.selectFromSettings("Length_minimum_max", "keystash_settings", "settings_id", 1));
        int tableId = 1;
        String where = "Length_minimum_min";

        if (spinnerInt > spinnerIntNeighbour) {
            Dialog.showDialog("Minimum cant be above maximum value.", "Note");
            showPreferencesLengthMinimumMinSpinner.setValue(spinnerIntNeighbour);
            Db.walletUpdateSettings(tableId, where, Convert.intToString(spinnerIntNeighbour));
        }
        else {
            Db.walletUpdateSettings(tableId, where, spinnerString);
        }

    }//GEN-LAST:event_showPreferencesLengthMinimumMinSpinnerStateChanged

    private void showPreferencesLengthMinimumMaxSpinnerStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_showPreferencesLengthMinimumMaxSpinnerStateChanged

        Object spinner = showPreferencesLengthMinimumMaxSpinner.getValue();
        String spinnerString = String.valueOf(spinner);
        int spinnerInt = Convert.stringToInt(spinnerString);
        int spinnerIntNeighbour = Convert.stringToInt(Db.selectFromSettings("Length_minimum_min", "keystash_settings", "settings_id", 1));
        int tableId = 1;
        String where = "Length_minimum_max";

        if (spinnerInt < spinnerIntNeighbour) {
            Dialog.showDialog("Maximum cant be below minimum value.", "Note");
            showPreferencesLengthMinimumMaxSpinner.setValue(spinnerIntNeighbour);
            Db.walletUpdateSettings(tableId, where, Convert.intToString(spinnerIntNeighbour));
        }
        else {
            Db.walletUpdateSettings(tableId, where, spinnerString);
        }

    }//GEN-LAST:event_showPreferencesLengthMinimumMaxSpinnerStateChanged

    private void showPreferencesLengthMaximumMinSpinnerStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_showPreferencesLengthMaximumMinSpinnerStateChanged

        Object spinner = showPreferencesLengthMaximumMinSpinner.getValue();
        String spinnerString = String.valueOf(spinner);
        int spinnerInt = Convert.stringToInt(spinnerString);
        int spinnerIntNeighbour = Convert.stringToInt(Db.selectFromSettings("Length_maximum_max", "keystash_settings", "settings_id", 1));
        int tableId = 1;
        String where = "Length_maximum_min";

        if (spinnerInt > spinnerIntNeighbour) {
            Dialog.showDialog("Minimum cant be above maximum value.", "Note");
            showPreferencesLengthMaximumMinSpinner.setValue(spinnerIntNeighbour);
            Db.walletUpdateSettings(tableId, where, Convert.intToString(spinnerIntNeighbour));
        }
        else {
            Db.walletUpdateSettings(tableId, where, spinnerString);
        }

    }//GEN-LAST:event_showPreferencesLengthMaximumMinSpinnerStateChanged

    private void showPreferencesLengthMaximumMaxSpinnerStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_showPreferencesLengthMaximumMaxSpinnerStateChanged

        Object spinner = showPreferencesLengthMaximumMaxSpinner.getValue();
        String spinnerString = String.valueOf(spinner);
        int spinnerInt = Convert.stringToInt(spinnerString);
        int spinnerIntNeighbour = Convert.stringToInt(Db.selectFromSettings("Length_maximum_min", "keystash_settings", "settings_id", 1));
        int tableId = 1;
        String where = "Length_maximum_max";

        if (spinnerInt < spinnerIntNeighbour) {
            Dialog.showDialog("Maximum cant be below minimum value.", "Note");
            showPreferencesLengthMaximumMaxSpinner.setValue(spinnerIntNeighbour);
            Db.walletUpdateSettings(tableId, where, Convert.intToString(spinnerIntNeighbour));
        }
        else {
            Db.walletUpdateSettings(tableId, where, spinnerString);
        }

    }//GEN-LAST:event_showPreferencesLengthMaximumMaxSpinnerStateChanged

    private void showPreferencesLowerCaseMinSpinnerStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_showPreferencesLowerCaseMinSpinnerStateChanged

        Object spinner = showPreferencesLowerCaseMinSpinner.getValue();
        String spinnerString = String.valueOf(spinner);
        int spinnerInt = Convert.stringToInt(spinnerString);
        int spinnerIntNeighbour = Convert.stringToInt(Db.selectFromSettings("lower_case_max", "keystash_settings", "settings_id", 1));
        int tableId = 1;
        String where = "lower_case_min";

        if (spinnerInt > spinnerIntNeighbour) {
            Dialog.showDialog("Minimum cant be above maximum value.", "Note");
            showPreferencesLowerCaseMinSpinner.setValue(spinnerIntNeighbour);
            Db.walletUpdateSettings(tableId, where, Convert.intToString(spinnerIntNeighbour));
        }
        else {
            Db.walletUpdateSettings(tableId, where, spinnerString);
        }

    }//GEN-LAST:event_showPreferencesLowerCaseMinSpinnerStateChanged

    private void showPreferencesLowerCaseMaxSpinnerStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_showPreferencesLowerCaseMaxSpinnerStateChanged

        Object spinner = showPreferencesLowerCaseMaxSpinner.getValue();
        String spinnerString = String.valueOf(spinner);
        int spinnerInt = Convert.stringToInt(spinnerString);
        int spinnerIntNeighbour = Convert.stringToInt(Db.selectFromSettings("lower_case_min", "keystash_settings", "settings_id", 1));
        int tableId = 1;
        String where = "lower_case_max";

        if (spinnerInt < spinnerIntNeighbour) {
            Dialog.showDialog("Maximum cant be below minimum value.", "Note");
            showPreferencesLowerCaseMaxSpinner.setValue(spinnerIntNeighbour);
            Db.walletUpdateSettings(tableId, where, Convert.intToString(spinnerIntNeighbour));
        }
        else {
            Db.walletUpdateSettings(tableId, where, spinnerString);
        }

    }//GEN-LAST:event_showPreferencesLowerCaseMaxSpinnerStateChanged

    private void showPreferencesUpperCaseMinSpinnerStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_showPreferencesUpperCaseMinSpinnerStateChanged

        Object spinner = showPreferencesUpperCaseMinSpinner.getValue();
        String spinnerString = String.valueOf(spinner);
        int spinnerInt = Convert.stringToInt(spinnerString);
        int spinnerIntNeighbour = Convert.stringToInt(Db.selectFromSettings("upper_case_max", "keystash_settings", "settings_id", 1));
        int tableId = 1;
        String where = "upper_case_min";

        if (spinnerInt > spinnerIntNeighbour) {
            Dialog.showDialog("Minimum cant be above maximum value.", "Note");
            showPreferencesUpperCaseMinSpinner.setValue(spinnerIntNeighbour);
            Db.walletUpdateSettings(tableId, where, Convert.intToString(spinnerIntNeighbour));
        }
        else {
            Db.walletUpdateSettings(tableId, where, spinnerString);
        }

    }//GEN-LAST:event_showPreferencesUpperCaseMinSpinnerStateChanged

    private void showPreferencesUpperCaseMaxSpinnerStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_showPreferencesUpperCaseMaxSpinnerStateChanged

        Object spinner = showPreferencesUpperCaseMaxSpinner.getValue();
        String spinnerString = String.valueOf(spinner);
        int spinnerInt = Convert.stringToInt(spinnerString);

        int spinnerIntNeighbour = Convert.stringToInt(Db.selectFromSettings("upper_case_min", "keystash_settings", "settings_id", 1));

        int tableId = 1;
        String where = "upper_case_max";

        if (spinnerInt < spinnerIntNeighbour) {
            Dialog.showDialog("Maximum cant be below minimum value.", "Note");
            showPreferencesUpperCaseMaxSpinner.setValue(spinnerIntNeighbour);
            Db.walletUpdateSettings(tableId, where, Convert.intToString(spinnerIntNeighbour));
        }
        else {
            Db.walletUpdateSettings(tableId, where, spinnerString);
        }

    }//GEN-LAST:event_showPreferencesUpperCaseMaxSpinnerStateChanged

    private void showPreferencesNumeraryMinSpinnerStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_showPreferencesNumeraryMinSpinnerStateChanged

        Object spinner = showPreferencesNumeraryMinSpinner.getValue();
        String spinnerString = String.valueOf(spinner);
        int spinnerInt = Convert.stringToInt(spinnerString);

        int spinnerIntNeighbour = Convert.stringToInt(Db.selectFromSettings("numerary_max", "keystash_settings", "settings_id", 1));

        int tableId = 1;
        String where = "numerary_min";

        if (spinnerInt > spinnerIntNeighbour) {
            Dialog.showDialog("Minimum cant be above maximum value.", "Note");
            showPreferencesNumeraryMinSpinner.setValue(spinnerIntNeighbour);
            Db.walletUpdateSettings(tableId, where, Convert.intToString(spinnerIntNeighbour));

        }
        else {
            Db.walletUpdateSettings(tableId, where, spinnerString);
        }

    }//GEN-LAST:event_showPreferencesNumeraryMinSpinnerStateChanged

    private void showPreferencesNumeraryMaxSpinnerStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_showPreferencesNumeraryMaxSpinnerStateChanged

        Object spinner = showPreferencesNumeraryMaxSpinner.getValue();
        String spinnerString = String.valueOf(spinner);
        int spinnerInt = Convert.stringToInt(spinnerString);

        int spinnerIntNeighbour = Convert.stringToInt(Db.selectFromSettings("numerary_min", "keystash_settings", "settings_id", 1));

        int tableId = 1;
        String where = "numerary_max";

        if (spinnerInt < spinnerIntNeighbour) {
            Dialog.showDialog("Maximum cant be below minimum value.", "Note");
            showPreferencesNumeraryMaxSpinner.setValue(spinnerIntNeighbour);
            Db.walletUpdateSettings(tableId, where, Convert.intToString(spinnerIntNeighbour));
        }
        else {
            Db.walletUpdateSettings(tableId, where, spinnerString);
        }

    }//GEN-LAST:event_showPreferencesNumeraryMaxSpinnerStateChanged

    private void showPreferencesSpecialCharMinSpinnerStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_showPreferencesSpecialCharMinSpinnerStateChanged

        Object spinner = showPreferencesSpecialCharMinSpinner.getValue();
        String spinnerString = String.valueOf(spinner);
        int spinnerInt = Convert.stringToInt(spinnerString);

        int spinnerIntNeighbour = Convert.stringToInt(Db.selectFromSettings("special_char_max", "keystash_settings", "settings_id", 1));

        int tableId = 1;
        String where = "special_char_min";

        if (spinnerInt > spinnerIntNeighbour) {
            Dialog.showDialog("Minimum cant be above maximum value.", "Note");
            showPreferencesSpecialCharMinSpinner.setValue(spinnerIntNeighbour);
            Db.walletUpdateSettings(tableId, where, Convert.intToString(spinnerIntNeighbour));
        }
        else {
            Db.walletUpdateSettings(tableId, where, spinnerString);
        }

    }//GEN-LAST:event_showPreferencesSpecialCharMinSpinnerStateChanged

    private void showPreferencesSpecialCharMaxSpinnerStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_showPreferencesSpecialCharMaxSpinnerStateChanged

        Object spinner = showPreferencesSpecialCharMaxSpinner.getValue();
        String spinnerString = String.valueOf(spinner);
        int spinnerInt = Convert.stringToInt(spinnerString);

        int spinnerIntNeighbour = Convert.stringToInt(Db.selectFromSettings("special_char_min", "keystash_settings", "settings_id", 1));

        int tableId = 1;
        String where = "special_char_max";

        if (spinnerInt < spinnerIntNeighbour) {
            Dialog.showDialog("Maximum cant be below minimum value.", "Note");
            showPreferencesSpecialCharMaxSpinner.setValue(spinnerIntNeighbour);
            Db.walletUpdateSettings(tableId, where, Convert.intToString(spinnerIntNeighbour));
        }
        else {
            Db.walletUpdateSettings(tableId, where, spinnerString);
        }

    }//GEN-LAST:event_showPreferencesSpecialCharMaxSpinnerStateChanged

    private void showPreferencesResetSettingsButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_showPreferencesResetSettingsButtonActionPerformed

        Db.walletUpdateSettings(1, "phrase_blocks", Convert.intToString(Constants.phraseBlocks));
        Db.walletUpdateSettings(1, "secret_iteration", Convert.intToString(Constants.secretIteration));
        Db.walletUpdateSettings(1, "enable_whitespace", Convert.booleanToString(Constants.enableWhitespace));
        Db.walletUpdateSettings(1, "enable_ansi", Convert.booleanToString(Constants.enableAnsi));
        Db.walletUpdateSettings(1, "Length_minimum_min", Convert.intToString(Constants.lengthMinimumMin));
        Db.walletUpdateSettings(1, "Length_minimum_max", Convert.intToString(Constants.lengthMinimumMax));
        Db.walletUpdateSettings(1, "Length_maximum_min", Convert.intToString(Constants.lengthMaximumMin));
        Db.walletUpdateSettings(1, "Length_maximum_max", Convert.intToString(Constants.lengthMaximumMax));
        Db.walletUpdateSettings(1, "lower_case_min", Convert.intToString(Constants.lowerCaseMin));
        Db.walletUpdateSettings(1, "lower_case_max", Convert.intToString(Constants.lowerCaseMax));
        Db.walletUpdateSettings(1, "upper_case_min", Convert.intToString(Constants.upperCaseMin));
        Db.walletUpdateSettings(1, "upper_case_max", Convert.intToString(Constants.upperCaseMax));
        Db.walletUpdateSettings(1, "numerary_min", Convert.intToString(Constants.numeraryMin));
        Db.walletUpdateSettings(1, "numerary_max", Convert.intToString(Constants.numeraryMax));
        Db.walletUpdateSettings(1, "special_char_min", Convert.intToString(Constants.specialCharMin));
        Db.walletUpdateSettings(1, "special_char_max", Convert.intToString(Constants.specialCharMax));
        Db.walletUpdateSettings(1, "secret_key_size", Convert.intToString(Constants.secretKeySize[0]));

        showPreferencesPhraseBlocksSpinner.setValue(Constants.phraseBlocks);
        showPreferencesIterationSpinner.setValue(Constants.secretIteration);
        showPreferencesWhitespaceCheckbox.setSelected(Constants.enableWhitespace);
        showPreferencesANSICheckbox.setSelected(Constants.enableAnsi);
        showPreferencesLengthMinimumMinSpinner.setValue(Constants.lengthMinimumMin);
        showPreferencesLengthMinimumMaxSpinner.setValue(Constants.lengthMinimumMax);
        showPreferencesLengthMaximumMinSpinner.setValue(Constants.lengthMaximumMin);
        showPreferencesLengthMaximumMaxSpinner.setValue(Constants.lengthMaximumMax);
        showPreferencesLowerCaseMinSpinner.setValue(Constants.lowerCaseMin);
        showPreferencesLowerCaseMaxSpinner.setValue(Constants.lowerCaseMax);
        showPreferencesUpperCaseMinSpinner.setValue(Constants.upperCaseMin);
        showPreferencesUpperCaseMaxSpinner.setValue(Constants.upperCaseMax);
        showPreferencesNumeraryMinSpinner.setValue(Constants.numeraryMin);
        showPreferencesNumeraryMaxSpinner.setValue(Constants.numeraryMax);
        showPreferencesSpecialCharMinSpinner.setValue(Constants.specialCharMin);
        showPreferencesSpecialCharMaxSpinner.setValue(Constants.specialCharMax);
        showPreferencesKeySizeComboBox.setSelectedIndex(0);

    }//GEN-LAST:event_showPreferencesResetSettingsButtonActionPerformed

    private void showPreferencesWhitespaceCheckboxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_showPreferencesWhitespaceCheckboxActionPerformed

        boolean checkBox = showPreferencesWhitespaceCheckbox.isSelected();
        String checkBoxString = Boolean.toString(checkBox);
        int tableId = 1;
        String where = "enable_whitespace";

        if (checkBox) {
            Db.walletUpdateSettings(tableId, where, checkBoxString);
        }
        else {
            Db.walletUpdateSettings(tableId, where, checkBoxString);
        }

    }//GEN-LAST:event_showPreferencesWhitespaceCheckboxActionPerformed

    private void enableApiMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_enableApiMenuItemActionPerformed

        boolean checkBox = enableApiMenuItem.isSelected();

        if (checkBox) {
            enableApi = true;
            backgroundMenu = 2;
        }
        else {
            enableApi = false;
            backgroundMenu = 3;
        }

    }//GEN-LAST:event_enableApiMenuItemActionPerformed

    private void showCopyAddressItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_showCopyAddressItemActionPerformed

        int getRow = accountTable.getSelectedRow();
        int column = accountTable.getSelectedColumn();
        Object rowValue;

        rowValue = accountTable.getValueAt(getRow, column);

        StringSelection stringSelection = new StringSelection(rowValue.toString());
        Clipboard clpbrd = Toolkit.getDefaultToolkit().getSystemClipboard();
        clpbrd.setContents(stringSelection, null);

    }//GEN-LAST:event_showCopyAddressItemActionPerformed

    private void aboutMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_aboutMenuItemActionPerformed

        aboutFrame.setLocationRelativeTo(null);
        aboutOkButton.requestFocus();
        aboutScrollPane.putClientProperty("JTable.cutCopyAllowed", true);
        aboutFrame.setVisible(true);

    }//GEN-LAST:event_aboutMenuItemActionPerformed

    private void showPreferencesIterationSpinnerStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_showPreferencesIterationSpinnerStateChanged

        Component c = showPreferencesIterationSpinner.getEditor().getComponent(0);
        Object spinner = showPreferencesIterationSpinner.getValue();
        String spinnerString = String.valueOf(spinner);
        int spinnerInt = Convert.stringToInt(spinnerString);
        int tableId = 1;
        String where = "secret_iteration";

        Db.walletUpdateSettings(tableId, where, spinnerString);

        if (spinnerInt > 5000) {
            c.setForeground(Color.BLUE.darker());
        }
        else {
            c.setForeground(Color.BLACK);
        }

    }//GEN-LAST:event_showPreferencesIterationSpinnerStateChanged

    private void encryptDatabasePasswordFieldKeyReleased(java.awt.event.KeyEvent evt) {//GEN-FIRST:event_encryptDatabasePasswordFieldKeyReleased

        char[] checkPassword = newAccountPasswordField.getPassword();
        newAccountLengthValue.setText(Convert.intToString(checkPassword.length));

    }//GEN-LAST:event_encryptDatabasePasswordFieldKeyReleased

    private void encryptDatabasePasswordFieldKeyTyped(java.awt.event.KeyEvent evt) {//GEN-FIRST:event_encryptDatabasePasswordFieldKeyTyped

        char[] checkPassword = encryptDatabasePasswordField.getPassword();
        encryptDatabaseLengthValue.setText(Convert.intToString(checkPassword.length));
        double shannonEntropy = PasswordStrength.getShannonEntropy(new String(checkPassword));
        encryptDatabaseEntropyValue.setText(String.valueOf(shannonEntropy));
        int showPasswordStrenght = PasswordStrength.checkPasswordStrength(new String(checkPassword));
        long shannonLong = (long) shannonEntropy;

        if (showPasswordStrenght == 0 && shannonLong <= 1) {
            encryptDatabasejProgressBar.setValue(0);
            encryptDatabasePasswordStrengthLabel.setText("Complexity:");
        }

        if (showPasswordStrenght >= 25 && shannonLong == 2) {
            encryptDatabasejProgressBar.setValue(25);
            encryptDatabasePasswordStrengthLabel.setText("Complexity: Weak");
        }

        if (showPasswordStrenght >= 50 && shannonLong == 3) {
            encryptDatabasejProgressBar.setValue(50);
            encryptDatabasePasswordStrengthLabel.setText("Complexity: Good");
        }

        if (showPasswordStrenght >= 75 && shannonLong == 4) {
            encryptDatabasejProgressBar.setValue(75);
            encryptDatabasePasswordStrengthLabel.setText("Complexity: Very good");
        }

        if (showPasswordStrenght == 100 && shannonLong == 5) {
            encryptDatabasejProgressBar.setValue(100);
            encryptDatabasePasswordStrengthLabel.setText("Complexity: Strong");
        }

        if (checkPassword.length <= 5) {
            encryptDatabasejProgressBar.setValue(0);
            encryptDatabasePasswordStrengthLabel.setText("Complexity: Very weak");
        }

        if (checkPassword.length == 0) {
            encryptDatabasejProgressBar.setValue(0);
            encryptDatabasePasswordStrengthLabel.setText("Complexity:");
        }

        Memory.clearPasswordMemory(checkPassword);

    }//GEN-LAST:event_encryptDatabasePasswordFieldKeyTyped

    private void encryptDatabaseOKButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_encryptDatabaseOKButtonActionPerformed

        char[] checkPassword1 = encryptDatabasePasswordField.getPassword();
        char[] checkPassword2 = encryptDatabasePasswordConfirmField.getPassword();

        char c = '¡';

        if (!Arrays.equals(checkPassword1, checkPassword2)) {
            Dialog.showDialog("Passwords do not match!", "Note");
        }
        else if (checkPassword1.length < Constants.minPasswordChars) {
            Dialog.showDialog("Password must contain at least " + Constants.minPasswordChars + " characters!", "Note");
        }
        else if (new String(checkPassword1).contains(Character.toString(c))) {
            Dialog.showDialog("No ¡ charactere allowed in password.", "Note");
        }
        else {
            try {

                Db.walletClose();
                ChangeFileEncryption.main("-dir", Constants.walletPathOnly, "-db", "wallet", "-cipher", "AES", "-encrypt", new String(checkPassword1).replace(' ', c));
                isWalletEncrypted = true;
                encryptDatabaseFrame.setVisible(false);
                encryptDatabaseMenuItem.setEnabled(false);
                Db.connectToEncryptedWallet(String.valueOf(checkPassword1).replace(' ', c));
                Dialog.showDialog("Database encryption successful.", "Note");
            } catch (SQLException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
                Db.connectToWallet();
                encryptDatabaseFrame.setVisible(false);
                Dialog.showDialog("Database encryption failed.", "Note");
            }
            accountMenuItem.setEnabled(true);
            MenuItem.enableMenu(true);
            encryptDatabaseMenuItem.setEnabled(false);
            Memory.clearPasswordMemory(checkPassword1);
            Memory.clearPasswordMemory(checkPassword2);
        }


    }//GEN-LAST:event_encryptDatabaseOKButtonActionPerformed

    private void encryptDatabaseShowPhraseCheckBoxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_encryptDatabaseShowPhraseCheckBoxActionPerformed

        boolean showPhrase = encryptDatabaseShowPhraseCheckBox.isSelected();

        if (showPhrase) {
            encryptDatabasePasswordField.setEchoChar((char) 0);
            encryptDatabasePasswordConfirmField.setEchoChar((char) 0);
        }
        else {
            encryptDatabasePasswordField.setEchoChar('*');
            encryptDatabasePasswordConfirmField.setEchoChar('*');
        }

    }//GEN-LAST:event_encryptDatabaseShowPhraseCheckBoxActionPerformed

    private void encryptDatabaseMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_encryptDatabaseMenuItemActionPerformed

        encryptDatabaseFrame.setVisible(true);
        encryptDatabaseFrame.setLocationRelativeTo(null);
        encryptDatabaseShowPhraseCheckBox.setSelected(false);
        encryptDatabasePasswordField.requestFocus();
        encryptDatabasePasswordField.setEchoChar('*');
        encryptDatabasePasswordConfirmField.setEchoChar('*');
        encryptDatabasePasswordField.setText("");
        encryptDatabasePasswordConfirmField.setText("");
        encryptDatabasejProgressBar.setValue(0);
        encryptDatabaseEntropyValue.setText("0.0");
        encryptDatabaseLengthValue.setText("0");
        encryptDatabasePasswordField.putClientProperty("JPasswordField.cutCopyAllowed", true);
        encryptDatabasePasswordConfirmField.putClientProperty("JPasswordField.cutCopyAllowed", true);
        accountMenuItem.setEnabled(false);
        MenuItem.enableMenu(false);

        encryptDatabaseFrame.addWindowListener(new WindowAdapter() {
            @Override
            public void windowClosing(WindowEvent we) {
                accountMenuItem.setEnabled(true);
                MenuItem.enableMenu(true);
            }
        });

        guiShowWarnings = Convert.stringToBoolean(Db.selectFromSettings("show_warnings", "keystash_settings", "settings_id", 1));

        if (guiShowWarnings) {
            Dialog.showDialog("You will lose all access if you forget the master password!", "Note");
        }

    }//GEN-LAST:event_encryptDatabaseMenuItemActionPerformed

    private void showPreferencesKeySizeComboBoxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_showPreferencesKeySizeComboBoxActionPerformed

        int getKeySize = showPreferencesKeySizeComboBox.getSelectedIndex();
        int keySizeComboBox;

        if (getKeySize == 0) {
            keySizeComboBox = 128;
            Db.walletUpdateSettings(1, "secret_key_size", Convert.intToString(keySizeComboBox));
        }
        else if (getKeySize == 1) {
            keySizeComboBox = 256;
            Db.walletUpdateSettings(1, "secret_key_size", Convert.intToString(keySizeComboBox));
        }

    }//GEN-LAST:event_showPreferencesKeySizeComboBoxActionPerformed

    private void newAccountGeneratePasswordButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_newAccountGeneratePasswordButtonActionPerformed

        try {
            newAccountPasswordField.setText(WordBook.generateRememberWordPhrase());
        } catch (NoSuchAlgorithmException | NoSuchProviderException ex) {
            Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
        }
        newAccountPasswordField.setEchoChar((char) 0);
        newAccountPasswordConfirmField.setEchoChar((char) 0);
        newAccountShowPhraseCheckBox.setSelected(true);
        newAccountPasswordConfirmField.setText("");
        newAccountjProgressBar.setValue(50);
        newAccountPasswordStrengthLabel.setText("Complexity: Good");
        char[] getPassword = newAccountPasswordField.getPassword();
        String checkPasswordString = new String(getPassword);
        int passLength = checkPasswordString.length();
        String passLengthString = String.valueOf(passLength);
        newAccountLengthValue.setText(passLengthString);
        double shannonEntropy = PasswordStrength.getShannonEntropy(checkPasswordString);
        String shannonEntropyString = String.valueOf(shannonEntropy);
        newAccountEntropyValue.setText(shannonEntropyString);

    }//GEN-LAST:event_newAccountGeneratePasswordButtonActionPerformed

    private void encryptDatabaseGeneratePasswordButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_encryptDatabaseGeneratePasswordButtonActionPerformed

        try {
            encryptDatabasePasswordField.setText(WordBook.generateRememberWordPhrase());
        } catch (NoSuchAlgorithmException | NoSuchProviderException ex) {
            Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
        }

        encryptDatabasePasswordField.setEchoChar((char) 0);
        encryptDatabasePasswordConfirmField.setEchoChar((char) 0);
        encryptDatabaseShowPhraseCheckBox.setSelected(true);
        encryptDatabasejProgressBar.setValue(50);
        encryptDatabasePasswordStrengthLabel.setText("Complexity: Good");
        char[] getPassword = encryptDatabasePasswordField.getPassword();
        String checkPasswordString = new String(getPassword);
        int passLength = checkPasswordString.length();
        String passLengthString = String.valueOf(passLength);
        encryptDatabaseLengthValue.setText(passLengthString);
        double shannonEntropy = PasswordStrength.getShannonEntropy(checkPasswordString);
        String shannonEntropyString = String.valueOf(shannonEntropy);
        encryptDatabaseEntropyValue.setText(shannonEntropyString);

    }//GEN-LAST:event_encryptDatabaseGeneratePasswordButtonActionPerformed

    private void decryptDatabaseShowPhraseCheckBoxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_decryptDatabaseShowPhraseCheckBoxActionPerformed

        boolean showPhrase = decryptDatabaseShowPhraseCheckBox.isSelected();

        if (showPhrase) {
            decryptDatabasePasswordField.setEchoChar((char) 0);
        }
        else {
            decryptDatabasePasswordField.setEchoChar('*');
        }

    }//GEN-LAST:event_decryptDatabaseShowPhraseCheckBoxActionPerformed

    private void decryptDatabaseOKButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_decryptDatabaseOKButtonActionPerformed

        char[] checkPassword = decryptDatabasePasswordField.getPassword();
        char c = '¡';

        if (checkPassword.length < Constants.minPasswordChars) {
            Dialog.showDialog("Password must contain at least " + Constants.minPasswordChars + " characters!", "Note");
        }
        else if (new String(checkPassword).contains(Character.toString(c))) {
            Dialog.showDialog("No ¡ character allowed in password.", "Note");
        }
        else {
            try {
                decryptDatabaseFrame.setVisible(false);
                Db.connectToEncryptedWallet(String.valueOf(checkPassword).replace(' ', c));
                TableContent.getTable();
                encryptDatabaseMenuItem.setEnabled(false);
                MenuItem.encryptedEnableMenu(true);
            } catch (Exception e) {
                Dialog.showDialog("Wrong pasword, decryption failed.", "Note");
                decryptDatabaseFrame.setVisible(true);
            }

        }
        Memory.clearPasswordMemory(checkPassword);
    }//GEN-LAST:event_decryptDatabaseOKButtonActionPerformed

    private void decryptDatabaseCancelButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_decryptDatabaseCancelButtonActionPerformed

        System.exit(0);

    }//GEN-LAST:event_decryptDatabaseCancelButtonActionPerformed

    private void newAccountCancelButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_newAccountCancelButtonActionPerformed

        newAccountFrame.setVisible(false);
        newAccountFrame.dispose();
        accountMenuItem.setEnabled(true);
        MenuItem.enableMenu(true);

    }//GEN-LAST:event_newAccountCancelButtonActionPerformed

    private void confirmNewAccountCancelButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_confirmNewAccountCancelButtonActionPerformed

        confirmNewAccountAttemptLabel.setEnabled(false);
        confirmNewAccountAttemptValueLabel.setEnabled(false);
        confirmNewAccountGenerateNewPhraseButton.setEnabled(true);
        confirmNewAccountOKButton.setEnabled(true);
        confirmNewAccountIncludeLettersField.setEnabled(true);
        confirmNewAccountSearchAddressToggleButton.setSelected(false);
        backgroundMenu = 0;
        confirmNewAccountFrame.setVisible(false);
        accountMenuItem.setEnabled(true);
        confirmNewAccountFrame.dispose();
        MenuItem.enableMenu(true);

    }//GEN-LAST:event_confirmNewAccountCancelButtonActionPerformed

    private void confirmNewAccountSearchAddressToggleButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_confirmNewAccountSearchAddressToggleButtonActionPerformed

        boolean isToogled = confirmNewAccountSearchAddressToggleButton.isSelected();
        String r = ".*[*$-+.,10#?_&=!%{}/]+.*";
        Matcher m = Pattern.compile(r).matcher(confirmNewAccountIncludeLettersField.getText());

        if (isToogled) {
            if (confirmNewAccountIncludeLettersField.getText().equals("NXT-     ")) {
                Dialog.showDialog("Searchfield is empty!", "Note");
                confirmNewAccountSearchAddressToggleButton.setSelected(false);
            }
            else if (m.find()) {
                Dialog.showDialog("Wrong characters!", "Note");
                confirmNewAccountSearchAddressToggleButton.setSelected(false);
            }
            else {

                confirmNewAccountAttemptLabel.setEnabled(true);
                confirmNewAccountAttemptValueLabel.setEnabled(true);
                confirmNewAccountGenerateNewPhraseButton.setEnabled(false);
                confirmNewAccountOKButton.setEnabled(false);
                confirmNewAccountIncludeLettersField.setEnabled(false);
                backgroundMenu = 4;
            }
        }
        else {
            confirmNewAccountAttemptLabel.setEnabled(false);
            confirmNewAccountAttemptValueLabel.setEnabled(false);
            confirmNewAccountGenerateNewPhraseButton.setEnabled(true);
            confirmNewAccountOKButton.setEnabled(true);
            confirmNewAccountIncludeLettersField.setEnabled(true);
        }

    }//GEN-LAST:event_confirmNewAccountSearchAddressToggleButtonActionPerformed

    private void confirmNewAccountGenerateNewPhraseButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_confirmNewAccountGenerateNewPhraseButtonActionPerformed

        char[] myPhrase = null;
        try {
            myPhrase = PhraseGenerator.generatePhrase();
        } catch (NoSuchAlgorithmException | NoSuchProviderException ex) {
            Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
        }
        secret = myPhrase;
        byte[] secretPhrase = Crypto.getPublicKey(new String(secret));
        Long secretPhraseConvert = Convert.getId(secretPhrase);

        String addressRs = Convert.rsAccount(secretPhraseConvert);
        confirmNewAccountShowAddressRsLabel.setText(addressRs);
        confirmNewAccountPhraseField.setText(new String(myPhrase));
        int passLength = secret.length;
        String passLengthString = String.valueOf(passLength);
        double shannonEntropy = PasswordStrength.getShannonEntropy(new String(secret));
        String shannonEntropyString = String.valueOf(shannonEntropy);
        confirmNewAccountEntropyValue.setText(shannonEntropyString);
        confirmNewAccountLengthValue.setText(passLengthString);

    }//GEN-LAST:event_confirmNewAccountGenerateNewPhraseButtonActionPerformed

    private void confirmNewAccountShowPhraseCheckBoxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_confirmNewAccountShowPhraseCheckBoxActionPerformed

        boolean showPhrase = confirmNewAccountShowPhraseCheckBox.isSelected();

        if (showPhrase) {
            confirmNewAccountPhraseField.setEchoChar((char) 0);
        }
        else {
            confirmNewAccountPhraseField.setEchoChar('*');
        }

    }//GEN-LAST:event_confirmNewAccountShowPhraseCheckBoxActionPerformed

    private void confirmNewAccountOKButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_confirmNewAccountOKButtonActionPerformed

        char[] checkPassword = confirmNewAccountPhraseField.getPassword();
        int passLength = checkPassword.length;
        if (passLength < 35) {
            Dialog.showDialog("Minimum Length of phrase must be over 35 characters.", "Note");
        }
        else {
            if (enableApiMenuItem.isSelected()) {
                backgroundMenu = 3;
                try {
                    Thread.sleep(1000);
                } catch (InterruptedException ex) {
                    Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
                }
            }
            int accountId = Db.countAccountsWallet("keystash_wallet") + 1;
            String genSalt = null;
            try {
                genSalt = Aes.generateSaltOrIv(Constants.saltAndIvSize[0]);
            } catch (NoSuchAlgorithmException | NoSuchProviderException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }
            String tmpSalt = genSalt;
            String genIV = null;
            try {
                genIV = Aes.generateSaltOrIv(Constants.saltAndIvSize[1]);
            } catch (NoSuchAlgorithmException | NoSuchProviderException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }
            String tmpIV = genIV;

            String cipherPassPhrase = null;
            try {
                cipherPassPhrase = Aes.encrypt(String.valueOf(secret), String.valueOf(globalPassword), tmpSalt, tmpIV);
            } catch (NoSuchAlgorithmException | InvalidKeySpecException | NoSuchPaddingException | IllegalBlockSizeException | BadPaddingException | InvalidKeyException | InvalidAlgorithmParameterException | DecoderException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }

            byte[] secretPhrase = Crypto.getPublicKey(String.valueOf(secret));
            Long secretPhraseConvert = Convert.getId(secretPhrase);
            String publicKey = Convert.toHexString(secretPhrase);

            String addressClassic = Convert.toUnsignedLong(secretPhraseConvert);
            String addressRs = Convert.rsAccount(secretPhraseConvert);

            String label = Constants.accountLabel;
            int secretIteration = (Convert.stringToInt(Db.selectFromSettings("secret_iteration", "keystash_settings", "settings_id", 1)));
            int secretKeySize = (Convert.stringToInt(Db.selectFromSettings("secret_key_size", "keystash_settings", "settings_id", 1)));
            int shareAccount = (Convert.stringToInt(Db.selectFromSettings("share_account", "keystash_settings", "settings_id", 1)));
            String accountType = Db.selectFromSettings("account_type", "keystash_settings", "settings_id", 1);

            String createdTimestamp = Time.getDate();

            Db.walletInsertNewAccount(accountId, addressClassic, addressRs, publicKey, label, cipherPassPhrase, tmpSalt, tmpIV, secretIteration, secretKeySize, shareAccount, accountType, createdTimestamp);

            TableContent.deleteGuiTables();
            TableContent.getTable();

            int countRows = Db.countAccountsWallet("keystash_wallet") + 1;

            String[] getAccountid = new String[countRows];
            String[] getAddressClassic = new String[countRows];
            String[] getAddressRs = new String[countRows];
            String[] getPublicKey = new String[countRows];
            String[] getLabel = new String[countRows];
            String[] getSecret = new String[countRows];
            String[] getSalt = new String[countRows];
            String[] getIV = new String[countRows];
            String[] getSecretIteration = new String[countRows];
            String[] getSecretKeySize = new String[countRows];
            String[] getShareAccount = new String[countRows];
            String[] getAccountType = new String[countRows];
            String[] getTimestamp = new String[countRows];
            for (int i = 1; i < countRows; i++) {

                getAccountid[i] = Db.selectFromWallet("account_id", "keystash_wallet", "account_id", +i);
                getAddressClassic[i] = Db.selectFromWallet("address_classic", "keystash_wallet", "account_id", +i);
                getAddressRs[i] = Db.selectFromWallet("address_rs", "keystash_wallet", "account_id", +i);
                getPublicKey[i] = Db.selectFromWallet("public_key", "keystash_wallet", "account_id", +i);
                getLabel[i] = Db.selectFromWallet("label", "keystash_wallet", "account_id", +i);
                getSecret[i] = Db.selectFromWallet("secret", "keystash_wallet", "account_id", +i);
                getSalt[i] = Db.selectFromWallet("randomsalt", "keystash_wallet", "account_id", +i);
                getIV[i] = Db.selectFromWallet("randomiv", "keystash_wallet", "account_id", +i);
                getSecretIteration[i] = Db.selectFromWallet("secret_iteration", "keystash_wallet", "account_id", +i);
                getSecretKeySize[i] = Db.selectFromWallet("secret_key_size", "keystash_wallet", "account_id", +i);
                getShareAccount[i] = Db.selectFromWallet("share_account", "keystash_wallet", "account_id", +i);
                getAccountType[i] = Db.selectFromWallet("account_type", "keystash_wallet", "account_id", +i);
                getTimestamp[i] = Db.selectFromWallet("created_timestamp", "keystash_wallet", "account_id", +i);

                Api.getWalletData(countRows, getAccountid, getAddressClassic, getAddressRs, getPublicKey, getLabel, getSecret, getSalt, getIV, getSecretIteration, getSecretKeySize, getShareAccount, getAccountType, getTimestamp);

            }

            guiShowWarnings = Convert.stringToBoolean(Db.selectFromSettings("show_warnings", "keystash_settings", "settings_id", 1));
            if (guiShowWarnings) {
                Dialog.showDialog("Always backup your wallet after changes on a secure place!", "Note");
            }

            confirmNewAccountFrame.setVisible(false);
            accountMenuItem.setEnabled(true);
            MenuItem.enableMenu(true);
        }

        if (enableApiMenuItem.isSelected()) {
            try {
                Thread.sleep(1000);
            } catch (InterruptedException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }
            backgroundMenu = 2;
        }
        Memory.clearPasswordMemory(checkPassword);
        Memory.clearPasswordMemory(secret);
        Memory.clearPasswordMemory(globalPassword);

    }//GEN-LAST:event_confirmNewAccountOKButtonActionPerformed

    private void encryptDatabaseCancelButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_encryptDatabaseCancelButtonActionPerformed

        encryptDatabaseFrame.setVisible(false);
        encryptDatabaseFrame.dispose();
        accountMenuItem.setEnabled(true);
        MenuItem.enableMenu(true);

    }//GEN-LAST:event_encryptDatabaseCancelButtonActionPerformed

    private void enterPrimaryPasswordAccountDetailsCancelButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_enterPrimaryPasswordAccountDetailsCancelButtonActionPerformed

        enterPrimaryPasswordAccountDetailsFrame.setVisible(false);
        enterPrimaryPasswordAccountDetailsFrame.dispose();
        MenuItem.enableMenu(true);

    }//GEN-LAST:event_enterPrimaryPasswordAccountDetailsCancelButtonActionPerformed

    private void accountDetailsOKButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_accountDetailsOKButtonActionPerformed

        if (enableApiMenuItem.isSelected()) {
            backgroundMenu = 3;
            try {
                Thread.sleep(1000);
            } catch (InterruptedException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }
        }

        String labelValue = accountDetailsLabelField.getText().replaceAll("\\s+$", "");
        Db.walletUpdateAccount(row + 1, "label", labelValue);

        TableContent.deleteGuiTables();
        TableContent.getTable();

        int countRows = Db.countAccountsWallet("keystash_wallet") + 1;

        String[] getAccountid = new String[countRows];
        String[] getAddressClassic = new String[countRows];
        String[] getAddressRs = new String[countRows];
        String[] getPublicKey = new String[countRows];
        String[] getLabel = new String[countRows];
        String[] getSecret = new String[countRows];
        String[] getSalt = new String[countRows];
        String[] getIV = new String[countRows];
        String[] getSecretIteration = new String[countRows];
        String[] getSecretKeySize = new String[countRows];
        String[] getShareAccount = new String[countRows];
        String[] getAccountType = new String[countRows];
        String[] getTimestamp = new String[countRows];
        for (int i = 1; i < countRows; i++) {

            getAccountid[i] = Db.selectFromWallet("account_id", "keystash_wallet", "account_id", +i);
            getAddressClassic[i] = Db.selectFromWallet("address_classic", "keystash_wallet", "account_id", +i);
            getAddressRs[i] = Db.selectFromWallet("address_rs", "keystash_wallet", "account_id", +i);
            getPublicKey[i] = Db.selectFromWallet("public_key", "keystash_wallet", "account_id", +i);
            getLabel[i] = Db.selectFromWallet("label", "keystash_wallet", "account_id", +i);
            getSecret[i] = Db.selectFromWallet("secret", "keystash_wallet", "account_id", +i);
            getSalt[i] = Db.selectFromWallet("randomsalt", "keystash_wallet", "account_id", +i);
            getIV[i] = Db.selectFromWallet("randomiv", "keystash_wallet", "account_id", +i);
            getSecretIteration[i] = Db.selectFromWallet("secret_iteration", "keystash_wallet", "account_id", +i);
            getSecretKeySize[i] = Db.selectFromWallet("secret_key_size", "keystash_wallet", "account_id", +i);
            getShareAccount[i] = Db.selectFromWallet("share_account", "keystash_wallet", "account_id", +i);
            getAccountType[i] = Db.selectFromWallet("account_type", "keystash_wallet", "account_id", +i);
            getTimestamp[i] = Db.selectFromWallet("created_timestamp", "keystash_wallet", "account_id", +i);

            Api.getWalletData(countRows, getAccountid, getAddressClassic, getAddressRs, getPublicKey, getLabel, getSecret, getSalt, getIV, getSecretIteration, getSecretKeySize, getShareAccount, getAccountType, getTimestamp);

        }

        StringSelection stringSelection = new StringSelection("");
        Clipboard clpbrd = Toolkit.getDefaultToolkit().getSystemClipboard();
        clpbrd.setContents(stringSelection, null);

        accountDetailsCopyButton2.setEnabled(true);
        accountDetailsjProgressBar.setString("");
        accountDetailsjProgressBar.setValue(0);
        lockClearClipboardButton = false;
        backgroundMenu = 0;

        accountDetailsFrame.setVisible(false);
        accountDetailsFrame.dispose();
        MenuItem.enableMenu(true);

        if (enableApiMenuItem.isSelected()) {
            try {
                Thread.sleep(1000);
            } catch (InterruptedException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }
            backgroundMenu = 2;
        }

    }//GEN-LAST:event_accountDetailsOKButtonActionPerformed

    private void showPreferencesOKButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_showPreferencesOKButtonActionPerformed

        showPreferencesFrame.setVisible(false);
        showPreferencesFrame.dispose();
        MenuItem.enableMenu(true);

    }//GEN-LAST:event_showPreferencesOKButtonActionPerformed

    private void aboutOkButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_aboutOkButtonActionPerformed

        aboutFrame.setVisible(false);
        aboutFrame.dispose();

    }//GEN-LAST:event_aboutOkButtonActionPerformed

    private void showGenerateTokenItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_showGenerateTokenItemActionPerformed

        enterPrimaryPasswordGenerateTokenFrame.setVisible(true);
        enterPrimaryPasswordGenerateTokenFrame.setLocationRelativeTo(null);
        enterPrimaryPasswordGenerateTokenPasswordField.setText("");
        enterPrimaryPasswordGenerateTokenShowPhraseCheckBox.setSelected(false);
        enterPrimaryPasswordGenerateTokenPasswordField.setEchoChar('*');
        enterPrimaryPasswordGenerateTokenPasswordField.requestFocus();
        MenuItem.enableMenu(false);
        enterPrimaryPasswordGenerateTokenFrame.addWindowListener(new WindowAdapter() {
            @Override
            public void windowClosing(WindowEvent we) {
                MenuItem.enableMenu(true);
            }
        });

    }//GEN-LAST:event_showGenerateTokenItemActionPerformed

    @SuppressWarnings("UnusedAssignment")
    private void enterPrimaryPasswordGenerateTokenOKButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_enterPrimaryPasswordGenerateTokenOKButtonActionPerformed

        String getAccountRs = Db.selectFromWallet("address_rs", "keystash_wallet", "account_id", +row + 1);
        String getSecret = Db.selectFromWallet("secret", "keystash_wallet", "account_id", +row + 1);
        String getSalt = Db.selectFromWallet("randomSalt", "keystash_wallet", "account_id", +row + 1);
        String getIV = Db.selectFromWallet("randomIV", "keystash_wallet", "account_id", +row + 1);
        int getIteration = Convert.stringToInt(Db.selectFromWallet("secret_iteration", "keystash_wallet", "account_id", +row + 1));
        int getKeySize = Convert.stringToInt(Db.selectFromWallet("secret_key_size", "keystash_wallet", "account_id", +row + 1));

        char[] checkPassword = enterPrimaryPasswordGenerateTokenPasswordField.getPassword();

        if (checkPassword.length < Constants.minPasswordChars) {

            Dialog.showDialog("Password must contain at least " + Constants.minPasswordChars + " characters!", "Note");

        }
        else {

            String decipherSecret = null;
            try {
                decipherSecret = Aes.decrypt(getSecret, new String(checkPassword), getSalt, getIV, getIteration, getKeySize);
            } catch (NoSuchAlgorithmException | InvalidKeySpecException | NoSuchPaddingException | InvalidKeyException | InvalidAlgorithmParameterException | UnsupportedEncodingException | DecoderException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }

            try {
                decipherSecret = Aes.decrypt(getSecret, new String(checkPassword), getSalt, getIV, getIteration, getKeySize);
            } catch (java.lang.ArithmeticException e) {
            } catch (NoSuchAlgorithmException | InvalidKeySpecException | NoSuchPaddingException | InvalidKeyException | InvalidAlgorithmParameterException | UnsupportedEncodingException | DecoderException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            } finally {

            }

            if (decipherSecret == null) {
                Dialog.showDialog("Password does not match with encryption!", "Note");
            }
            else {

                byte[] secretPhrase = Crypto.getPublicKey(decipherSecret);
                Long secretPhraseConvert = Convert.getId(secretPhrase);
                String publicKey = Convert.toHexString(secretPhrase);

                String addressClassic = Convert.toUnsignedLong(secretPhraseConvert);
                String addressRs = Convert.rsAccount(secretPhraseConvert);

                if (getAccountRs.equals(addressRs)) {
                    secretToken = Convert.stringToChar(decipherSecret);
                    enterPrimaryPasswordGenerateTokenFrame.setVisible(false);
                    generateTokenFrame.setVisible(true);
                    generateTokenFrame.setLocationRelativeTo(null);
                    generateTokenFrame.setTitle("Generate Token: " + addressRs);
                    generateTokenGenerateTokenButton.requestFocus();
                    generateTokenFrame.addWindowListener(new WindowAdapter() {
                        @Override
                        public void windowClosing(WindowEvent we) {
                            MenuItem.enableMenu(true);
                            StringSelection stringSelection = new StringSelection("");
                            Clipboard clpbrd = Toolkit.getDefaultToolkit().getSystemClipboard();
                            clpbrd.setContents(stringSelection, null);

                        }
                    });
                    Timer timer;
                    timer = new Timer(Constants.closeAccountDetails * 1000, new ActionListener() {

                        @Override
                        public void actionPerformed(ActionEvent e) {
                            generateTokenFrame.setVisible(false);
                            generateTokenFrame.dispose();
                            MenuItem.enableMenu(true);
                        }
                    });
                    timer.setRepeats(false);
                    timer.start();

                }
                if (!getAccountRs.equals(addressRs)) {
                    Dialog.showDialog("Password does not match with encryption!", "Note");
                }

            }
            decipherSecret = "";
            Memory.clearPasswordMemory(checkPassword);
        }

    }//GEN-LAST:event_enterPrimaryPasswordGenerateTokenOKButtonActionPerformed

    private void enterPrimaryPasswordGenerateTokenShowPhraseCheckBoxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_enterPrimaryPasswordGenerateTokenShowPhraseCheckBoxActionPerformed

        boolean showPhrase = enterPrimaryPasswordGenerateTokenShowPhraseCheckBox.isSelected();

        if (showPhrase) {
            enterPrimaryPasswordGenerateTokenPasswordField.setEchoChar((char) 0);
        }
        else {
            enterPrimaryPasswordGenerateTokenPasswordField.setEchoChar('*');
        }

    }//GEN-LAST:event_enterPrimaryPasswordGenerateTokenShowPhraseCheckBoxActionPerformed

    private void enterPrimaryPasswordGenerateTokenCancelButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_enterPrimaryPasswordGenerateTokenCancelButtonActionPerformed

        enterPrimaryPasswordGenerateTokenFrame.setVisible(false);
        enterPrimaryPasswordGenerateTokenFrame.dispose();
        MenuItem.enableMenu(true);

    }//GEN-LAST:event_enterPrimaryPasswordGenerateTokenCancelButtonActionPerformed

    private void generateTokenCopyButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_generateTokenCopyButtonActionPerformed

        StringSelection stringSelection = new StringSelection(generateTokenTokenKeyField.getText());
        Clipboard clpbrd = Toolkit.getDefaultToolkit().getSystemClipboard();
        clpbrd.setContents(stringSelection, null);

    }//GEN-LAST:event_generateTokenCopyButtonActionPerformed

    private void generateTokenOKButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_generateTokenOKButtonActionPerformed

        Memory.clearPasswordMemory(secretToken);
        generateTokenFrame.setVisible(false);
        generateTokenFrame.dispose();
        MenuItem.enableMenu(true);

    }//GEN-LAST:event_generateTokenOKButtonActionPerformed

    private void showPreferencesANSICheckboxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_showPreferencesANSICheckboxActionPerformed

        boolean checkBox = showPreferencesANSICheckbox.isSelected();
        String checkBoxString = Boolean.toString(checkBox);
        int tableId = 1;
        String where = "enable_ansi";

        if (checkBox) {
            Db.walletUpdateSettings(tableId, where, checkBoxString);
        }
        else {
            Db.walletUpdateSettings(tableId, where, checkBoxString);
        }

    }//GEN-LAST:event_showPreferencesANSICheckboxActionPerformed

    private void generateTokenGenerateTokenButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_generateTokenGenerateTokenButtonActionPerformed

        String website = generateTokenTokenDataField.getText();
        String tokenString = Token.generateToken(String.valueOf(secretToken), website.trim());
        generateTokenTokenKeyField.setText(tokenString);

    }//GEN-LAST:event_generateTokenGenerateTokenButtonActionPerformed

    @SuppressWarnings("UnusedAssignment")
    private void enterPrimaryPasswordAccountDetailsOKButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_enterPrimaryPasswordAccountDetailsOKButtonActionPerformed

        String getAccountRs = Db.selectFromWallet("address_rs", "keystash_wallet", "account_id", +row + 1);
        String getSecret = Db.selectFromWallet("secret", "keystash_wallet", "account_id", +row + 1);
        String getSalt = Db.selectFromWallet("randomSalt", "keystash_wallet", "account_id", +row + 1);
        String getIV = Db.selectFromWallet("randomIV", "keystash_wallet", "account_id", +row + 1);
        String getLabel = Db.selectFromWallet("label", "keystash_wallet", "account_id", +row + 1);
        int getIteration = Convert.stringToInt(Db.selectFromWallet("secret_iteration", "keystash_wallet", "account_id", +row + 1));
        int getKeySize = Convert.stringToInt(Db.selectFromWallet("secret_key_size", "keystash_wallet", "account_id", +row + 1));

        char[] checkPassword = enterPrimaryPasswordAccountDetailsPasswordField.getPassword();

        if (checkPassword.length < Constants.minPasswordChars) {
            Dialog.showDialog("Password must contain at least " + Constants.minPasswordChars + " characters!", "Note");
        }
        else {
            String decipherSecret = null;
            try {
                decipherSecret = Aes.decrypt(getSecret, new String(checkPassword), getSalt, getIV, getIteration, getKeySize);
            } catch (NoSuchAlgorithmException | InvalidKeySpecException | NoSuchPaddingException | InvalidKeyException | InvalidAlgorithmParameterException | UnsupportedEncodingException | DecoderException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            }

            try {
                decipherSecret = Aes.decrypt(getSecret, new String(checkPassword), getSalt, getIV, getIteration, getKeySize);
            } catch (java.lang.ArithmeticException e) {
            } catch (NoSuchAlgorithmException | InvalidKeySpecException | NoSuchPaddingException | InvalidKeyException | InvalidAlgorithmParameterException | UnsupportedEncodingException | DecoderException ex) {
                Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
            } finally {

            }

            if (decipherSecret == null) {
                Dialog.showDialog("Password does not match with encryption!", "Note");
            }
            else {
                byte[] secretPhrase = Crypto.getPublicKey(decipherSecret);
                Long secretPhraseConvert = Convert.getId(secretPhrase);
                String publicKey = Convert.toHexString(secretPhrase);

                String addressClassic = Convert.toUnsignedLong(secretPhraseConvert);
                String addressRs = Convert.rsAccount(secretPhraseConvert);
                if (getAccountRs.equals(addressRs)) {

                    enterPrimaryPasswordAccountDetailsFrame.setVisible(false);
                    accountDetailsFrame.setVisible(true);
                    accountDetailsFrame.setLocationRelativeTo(null);
                    accountDetailsFrame.setTitle("Account Details: " + addressRs);
                    accountDetailsShowPhraseCheckBox.setSelected(false);
                    accountDetailsPhraseField.setText("");
                    accountDetailsOKButton.requestFocus();
                    accountDetailsFrame.addWindowListener(new WindowAdapter() {

                        @Override
                        public void windowClosing(WindowEvent we) {
                            StringSelection stringSelection = new StringSelection("");
                            Clipboard clpbrd = Toolkit.getDefaultToolkit().getSystemClipboard();
                            clpbrd.setContents(stringSelection, null);
                            accountDetailsCopyButton2.setEnabled(true);
                            accountDetailsjProgressBar.setString("");
                            accountDetailsjProgressBar.setValue(0);
                            lockClearClipboardButton = false;
                            backgroundMenu = 0;
                            MenuItem.enableMenu(true);
                        }
                    });

                    Timer timer;
                    timer = new Timer(Constants.closeAccountDetails * 1000, new ActionListener() {
                        @Override
                        public void actionPerformed(ActionEvent e) {
                            accountDetailsFrame.setVisible(false);
                            accountDetailsFrame.dispose();
                            MenuItem.enableMenu(true);

                        }
                    });
                    timer.setRepeats(false);
                    timer.start();
                    accountDetailsjProgressBar.setValue(0);
                    accountDetailsShowPhraseCheckBox.setSelected(false);
                    accountDetailsPhraseField.setEchoChar('*');
                    accountDetailsPhraseField.setText(decipherSecret);
                    accountDetailsLabelField.setText(getLabel);
                    accountDetailsPhraseField.putClientProperty("JPasswordField.cutCopyAllowed", true);
                    accountDetailsPublicKeyField.setText(publicKey);
                    accountDetailsPublicKeyField.putClientProperty("JPasswordField.cutCopyAllowed", true);

                }
                if (!getAccountRs.equals(addressRs)) {
                    Dialog.showDialog("Password does not match with encryption!", "Note");
                }
            }
            decipherSecret = "";
            Memory.clearPasswordMemory(checkPassword);
        }

    }//GEN-LAST:event_enterPrimaryPasswordAccountDetailsOKButtonActionPerformed

    @SuppressWarnings("SleepWhileInLoop")
    public static void main(String args[])
            throws Exception {

        if (Console.isSystemHeadless()) {
            System.out.println("KeyStash v" + Constants.keyStashVersion + " command console. Insert -? for help.");
            while (true) {
                Processor.userInput(null);
            }
        }
        else {

            try {
                for (javax.swing.UIManager.LookAndFeelInfo info : javax.swing.UIManager.getInstalledLookAndFeels()) {
                    if ("Nimbus".equals(info.getName())) {
                        javax.swing.UIManager.setLookAndFeel(info.getClassName());
                        break;
                    }
                }
            } catch (ClassNotFoundException | InstantiationException | IllegalAccessException | javax.swing.UnsupportedLookAndFeelException ex) {
                java.util.logging.Logger.getLogger(KeyStashGUI.class.getName()).log(java.util.logging.Level.SEVERE, null, ex);
            }

            java.awt.EventQueue.invokeLater(new Runnable() {
                @Override
                public void run() {
                    try {
                        new KeyStashGUI().setVisible(true);

                    } catch (SQLException | FontFormatException | IOException ex) {
                        Logger.getLogger(KeyStashGUI.class.getName()).log(Level.SEVERE, null, ex);
                    }
                }
            });

            backgroundMenu = 0;
            {
                boolean backgroundMenuLoop = true;
                while (backgroundMenuLoop) {
                    switch (backgroundMenu) {
                        default:
                            Thread.sleep(1000);
                            break;
                        case 1:
                            while (accountDetailsjProgressBar.getValue() > 0) {

                                long start_time = System.nanoTime();
                                int clearClipBoard = Convert.stringToInt(Db.selectFromSettings("clear_clipboard", "keystash_settings", "settings_id", 1));
                                long wait_time = clearClipBoard * 100000000;
                                long end_time = start_time + wait_time;
                                long passed_time;
                                double seconds;
                                int getProgressBarValue;
                                int calcProgressBarValue;

                                do {
                                    passed_time = start_time - System.nanoTime();
                                    seconds = Math.abs(passed_time / 1000000000.0);
                                    System.out.println("Wait For Clearing Passphase: " + passed_time / 100000000);

                                    if (System.nanoTime() > end_time) {
                                        getProgressBarValue = accountDetailsjProgressBar.getValue();
                                        calcProgressBarValue = getProgressBarValue - 10;
                                        System.out.println(getProgressBarValue);
                                        accountDetailsjProgressBar.setValue(calcProgressBarValue);
                                        start_time = System.nanoTime();
                                    }

                                } while (System.nanoTime() < end_time && accountDetailsjProgressBar.getValue() > 0);

                            }
                            StringSelection stringSelection = new StringSelection("");
                            Clipboard clpbrd = Toolkit.getDefaultToolkit().getSystemClipboard();
                            clpbrd.setContents(stringSelection, null);
                            accountDetailsCopyButton2.setEnabled(true);
                            accountDetailsOKButton.setEnabled(true);
                            accountDetailsjProgressBar.setString("");
                            lockClearClipboardButton = false;
                            backgroundMenu = 0;

                            break;
                        case 2:

                            int countRows = Db.countAccountsWallet("keystash_wallet");

                            String[] getAccountid = new String[countRows + 1];
                            String[] getAddressClassic = new String[countRows + 1];
                            String[] getAddressRs = new String[countRows + 1];
                            String[] getPublicKey = new String[countRows + 1];
                            String[] getLabel = new String[countRows + 1];
                            String[] getSecret = new String[countRows + 1];
                            String[] getSalt = new String[countRows + 1];
                            String[] getIV = new String[countRows + 1];
                            String[] getSecretIteration = new String[countRows + 1];
                            String[] getSecretKeySize = new String[countRows + 1];
                            String[] getShareAccount = new String[countRows + 1];
                            String[] getAccountType = new String[countRows + 1];
                            String[] getTimestamp = new String[countRows + 1];

                            for (int i = 1; i < countRows + 1; i++) {
                                getAccountid[i] = Db.selectFromWallet("account_id", "keystash_wallet", "account_id", +i);
                                getAddressClassic[i] = Db.selectFromWallet("address_classic", "keystash_wallet", "account_id", +i);
                                getAddressRs[i] = Db.selectFromWallet("address_rs", "keystash_wallet", "account_id", +i);
                                getPublicKey[i] = Db.selectFromWallet("public_key", "keystash_wallet", "account_id", +i);
                                getLabel[i] = Db.selectFromWallet("label", "keystash_wallet", "account_id", +i);
                                getSecret[i] = Db.selectFromWallet("secret", "keystash_wallet", "account_id", +i);
                                getSalt[i] = Db.selectFromWallet("randomsalt", "keystash_wallet", "account_id", +i);
                                getIV[i] = Db.selectFromWallet("randomiv", "keystash_wallet", "account_id", +i);
                                getSecretIteration[i] = Db.selectFromWallet("secret_iteration", "keystash_wallet", "account_id", +i);
                                getSecretKeySize[i] = Db.selectFromWallet("secret_key_size", "keystash_wallet", "account_id", +i);
                                getShareAccount[i] = Db.selectFromWallet("share_account", "keystash_wallet", "account_id", +i);
                                getAccountType[i] = Db.selectFromWallet("account_type", "keystash_wallet", "account_id", +i);
                                getTimestamp[i] = Db.selectFromWallet("created_timestamp", "keystash_wallet", "account_id", +i);

                                Api.getWalletData(countRows, getAccountid, getAddressClassic, getAddressRs, getPublicKey, getLabel, getSecret, getSalt, getIV, getSecretIteration, getSecretKeySize, getShareAccount, getAccountType, getTimestamp);
                            }

                            Api.startWalletServer(true);
                            backgroundMenu = 0;

                            break;
                        case 3:
                            Api.startWalletServer(false);
                            backgroundMenu = 0;

                            break;
                        case 4:

                            String findValue = confirmNewAccountIncludeLettersField.getText();
                            findValue = findValue.toUpperCase();
                            String[] getSearchValue = findValue.split("\\-", -1);

                            int countAttempts = 0;
                            do {

                                char[] myPhrase = PhraseGenerator.generatePhrase();
                                secret = myPhrase;
                                byte[] secretPhrase = Crypto.getPublicKey(new String(secret));
                                Long secretPhraseConvert = Convert.getId(secretPhrase);
                                String addressRs = Convert.rsAccount(secretPhraseConvert);
                                confirmNewAccountShowAddressRsLabel.setText(addressRs);
                                String[] splitAddress = addressRs.split("\\-", -1);

                                for (int i = 1; i < 5; i++) {
                                    String word = splitAddress[i].replaceAll("\\s+$", "");
                                    String searchingWord = getSearchValue[1].replaceAll("\\s+$", "");
                                    if (word.contains(searchingWord) && word.length() >= searchingWord.length()) {
                                        confirmNewAccountAttemptLabel.setEnabled(false);
                                        confirmNewAccountAttemptValueLabel.setEnabled(false);
                                        confirmNewAccountGenerateNewPhraseButton.setEnabled(true);
                                        confirmNewAccountIncludeLettersField.setEnabled(true);
                                        confirmNewAccountSearchAddressToggleButton.setSelected(false);
                                        backgroundMenu = 0;
                                    }

                                }

                                confirmNewAccountPhraseField.setText(new String(myPhrase));
                                int passLength = secret.length;
                                String passLengthString = String.valueOf(passLength);
                                double shannonEntropy = PasswordStrength.getShannonEntropy(new String(secret));
                                String shannonEntropyString = String.valueOf(shannonEntropy);
                                confirmNewAccountEntropyValue.setText(shannonEntropyString);
                                confirmNewAccountLengthValue.setText(passLengthString);
                                countAttempts++;
                                confirmNewAccountAttemptValueLabel.setText(Convert.intToString(countAttempts));

                            } while (confirmNewAccountSearchAddressToggleButton.isSelected() == true);
                            confirmNewAccountOKButton.setEnabled(true);
                            backgroundMenu = 0;

                            break;
                        case 99:
                            break;

                    }
                    if (backgroundMenu == 99) {
                        backgroundMenuLoop = false;
                    }
                }
            }
        }

    }

    private void setIconAndFont()
            throws FontFormatException,
            IOException {

        this.setIconImage(Toolkit.getDefaultToolkit().getImage(getClass().getResource("resources/keystashicon.png")));
        newAccountFrame.setIconImage(Toolkit.getDefaultToolkit().getImage(getClass().getResource("resources/keystashicon.png")));
        confirmNewAccountFrame.setIconImage(Toolkit.getDefaultToolkit().getImage(getClass().getResource("resources/keystashicon.png")));
        enterPrimaryPasswordAccountDetailsFrame.setIconImage(Toolkit.getDefaultToolkit().getImage(getClass().getResource("resources/keystashicon.png")));
        enterPrimaryPasswordGenerateTokenFrame.setIconImage(Toolkit.getDefaultToolkit().getImage(getClass().getResource("resources/keystashicon.png")));
        accountDetailsFrame.setIconImage(Toolkit.getDefaultToolkit().getImage(getClass().getResource("resources/keystashicon.png")));
        generateTokenFrame.setIconImage(Toolkit.getDefaultToolkit().getImage(getClass().getResource("resources/keystashicon.png")));
        showPreferencesFrame.setIconImage(Toolkit.getDefaultToolkit().getImage(getClass().getResource("resources/keystashicon.png")));
        aboutFrame.setIconImage(Toolkit.getDefaultToolkit().getImage(getClass().getResource("resources/keystashicon.png")));
        encryptDatabaseFrame.setIconImage(Toolkit.getDefaultToolkit().getImage(getClass().getResource("resources/keystashicon.png")));
        decryptDatabaseFrame.setIconImage(Toolkit.getDefaultToolkit().getImage(getClass().getResource("resources/keystashicon.png")));
        InputStream is2;
        try ( InputStream is1 = this.getClass().getResourceAsStream("resources/OpenSans-Regular.ttf") ) {
            Font.createFont(Font.TRUETYPE_FONT, is1);
            is2 = this.getClass().getResourceAsStream("resources/OpenSans-Bold.ttf");
            Font.createFont(Font.TRUETYPE_FONT, is2);
        }
        is2.close();
    }


    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JLabel aboutBackgroundLabel;
    private javax.swing.JFrame aboutFrame;
    private javax.swing.JLabel aboutKeyStashDevelopersLabel;
    private javax.swing.JLabel aboutKeyStashExperimentelLabel;
    private javax.swing.JLabel aboutKeyStashIncludesSoftwareLabel;
    private javax.swing.JLabel aboutKeyStashIncludesSoftwareLinkLabel;
    private javax.swing.JLabel aboutKeyStashLicenseLabel;
    private javax.swing.JLabel aboutKeyStashLicenseLinkLabel;
    private javax.swing.JMenuItem aboutMenuItem;
    private javax.swing.JButton aboutOkButton;
    public static javax.swing.JScrollPane aboutScrollPane;
    public static javax.swing.JTable aboutTable;
    private javax.swing.JSeparator aboutjSeparator;
    private javax.swing.JLabel accountDetailsBackgroundLabel;
    private javax.swing.JLabel accountDetailsClearLabel;
    private static javax.swing.JButton accountDetailsCopyButton1;
    private static javax.swing.JButton accountDetailsCopyButton2;
    private javax.swing.JFrame accountDetailsFrame;
    private javax.swing.JFormattedTextField accountDetailsLabelField;
    private javax.swing.JLabel accountDetailsLabelLabel;
    private static javax.swing.JButton accountDetailsOKButton;
    private javax.swing.JPasswordField accountDetailsPhraseField;
    private javax.swing.JLabel accountDetailsPhraseLabel;
    private javax.swing.JTextField accountDetailsPublicKeyField;
    private javax.swing.JLabel accountDetailsPublicKeyLabel;
    private javax.swing.JCheckBox accountDetailsShowPhraseCheckBox;
    public static javax.swing.JProgressBar accountDetailsjProgressBar;
    private javax.swing.JSeparator accountDetailsjSeparator;
    public static javax.swing.JMenuItem accountMenuItem;
    public static javax.swing.JScrollPane accountScrollPane;
    public static javax.swing.JTable accountTable;
    public static javax.swing.JMenuItem backupMenuItem;
    private javax.swing.JSeparator confirmAccountSeparator;
    public static javax.swing.JLabel confirmNewAccountAddressLabel;
    private static javax.swing.JLabel confirmNewAccountAttemptLabel;
    public static javax.swing.JLabel confirmNewAccountAttemptValueLabel;
    private javax.swing.JLabel confirmNewAccountBackgroundLabel;
    private static javax.swing.JButton confirmNewAccountCancelButton;
    private javax.swing.JLabel confirmNewAccountEntropyLabel;
    private static javax.swing.JLabel confirmNewAccountEntropyValue;
    private javax.swing.JFrame confirmNewAccountFrame;
    private static javax.swing.JButton confirmNewAccountGenerateNewPhraseButton;
    private static javax.swing.JFormattedTextField confirmNewAccountIncludeLettersField;
    private javax.swing.JLabel confirmNewAccountLengthLabel;
    private static javax.swing.JLabel confirmNewAccountLengthValue;
    private static javax.swing.JButton confirmNewAccountOKButton;
    private static javax.swing.JPasswordField confirmNewAccountPhraseField;
    private javax.swing.JLabel confirmNewAccountPhraseLabel;
    private static javax.swing.JToggleButton confirmNewAccountSearchAddressToggleButton;
    public static javax.swing.JLabel confirmNewAccountShowAddressRsLabel;
    private javax.swing.JCheckBox confirmNewAccountShowPhraseCheckBox;
    private javax.swing.JLabel decryptDatabaseBackgroundLabel;
    private javax.swing.JButton decryptDatabaseCancelButton;
    public static javax.swing.JFrame decryptDatabaseFrame;
    private javax.swing.JButton decryptDatabaseOKButton;
    private javax.swing.JPasswordField decryptDatabasePasswordField;
    private javax.swing.JLabel decryptDatabasePasswordFieldLabel;
    private javax.swing.JSeparator decryptDatabaseSeparator;
    private javax.swing.JCheckBox decryptDatabaseShowPhraseCheckBox;
    public static javax.swing.JCheckBoxMenuItem enableApiMenuItem;
    private javax.swing.JLabel encryptDatabaseBackgroundLabel;
    private javax.swing.JButton encryptDatabaseCancelButton;
    private javax.swing.JLabel encryptDatabaseEntropyLabel;
    private javax.swing.JLabel encryptDatabaseEntropyValue;
    public static javax.swing.JFrame encryptDatabaseFrame;
    private javax.swing.JButton encryptDatabaseGeneratePasswordButton;
    private javax.swing.JLabel encryptDatabaseLengthLabel;
    private static javax.swing.JLabel encryptDatabaseLengthValue;
    public static javax.swing.JMenuItem encryptDatabaseMenuItem;
    private javax.swing.JButton encryptDatabaseOKButton;
    private javax.swing.JPasswordField encryptDatabasePasswordConfirmField;
    private javax.swing.JLabel encryptDatabasePasswordConfirmFieldLabel;
    private static javax.swing.JPasswordField encryptDatabasePasswordField;
    private javax.swing.JLabel encryptDatabasePasswordFieldLabel;
    private javax.swing.JLabel encryptDatabasePasswordStrengthLabel;
    private javax.swing.JSeparator encryptDatabaseSeparator;
    private javax.swing.JCheckBox encryptDatabaseShowPhraseCheckBox;
    public static javax.swing.JProgressBar encryptDatabasejProgressBar;
    private javax.swing.JLabel enterPrimaryPasswordAccountDetailsBackgroundLabel;
    private javax.swing.JButton enterPrimaryPasswordAccountDetailsCancelButton;
    private javax.swing.JFrame enterPrimaryPasswordAccountDetailsFrame;
    private javax.swing.JButton enterPrimaryPasswordAccountDetailsOKButton;
    private javax.swing.JPasswordField enterPrimaryPasswordAccountDetailsPasswordField;
    private javax.swing.JLabel enterPrimaryPasswordAccountDetailsPasswordFieldLabel;
    private javax.swing.JSeparator enterPrimaryPasswordAccountDetailsSeparator;
    private javax.swing.JCheckBox enterPrimaryPasswordAccountDetailsShowPhraseCheckBox;
    private javax.swing.JLabel enterPrimaryPasswordGenerateTokenBackgroundLabel;
    private javax.swing.JButton enterPrimaryPasswordGenerateTokenCancelButton;
    private javax.swing.JFrame enterPrimaryPasswordGenerateTokenFrame;
    private javax.swing.JButton enterPrimaryPasswordGenerateTokenOKButton;
    private javax.swing.JPasswordField enterPrimaryPasswordGenerateTokenPasswordField;
    private javax.swing.JLabel enterPrimaryPasswordGenerateTokenPasswordFieldLabel;
    private javax.swing.JSeparator enterPrimaryPasswordGenerateTokenSeparator;
    private javax.swing.JCheckBox enterPrimaryPasswordGenerateTokenShowPhraseCheckBox;
    private javax.swing.JMenuItem exitMenuItem;
    public static javax.swing.JMenu fileMenu;
    private javax.swing.JPopupMenu.Separator fileMenuSeperator;
    private javax.swing.JLabel generateTokenBackgroundLabel;
    private javax.swing.JLabel generateTokenClearLabel;
    private static javax.swing.JButton generateTokenCopyButton;
    private javax.swing.JFrame generateTokenFrame;
    private static javax.swing.JButton generateTokenGenerateTokenButton;
    private static javax.swing.JButton generateTokenOKButton;
    private javax.swing.JSeparator generateTokenSeparator;
    private javax.swing.JTextField generateTokenTokenDataField;
    private javax.swing.JTextField generateTokenTokenKeyField;
    private javax.swing.JLabel generateTokenTokenKeyLabel;
    private javax.swing.JLabel generateTokenTokenValueLabel;
    public static javax.swing.JMenu helpMenu;
    public static javax.swing.JMenuBar mainMenuBar;
    private javax.swing.JLabel newAccountBackgroundLabel;
    private javax.swing.JButton newAccountCancelButton;
    private javax.swing.JLabel newAccountEntropyLabel;
    private javax.swing.JLabel newAccountEntropyValue;
    public static javax.swing.JFrame newAccountFrame;
    private javax.swing.JButton newAccountGeneratePasswordButton;
    private javax.swing.JLabel newAccountLengthLabel;
    private static javax.swing.JLabel newAccountLengthValue;
    private javax.swing.JButton newAccountOKButton;
    private javax.swing.JPasswordField newAccountPasswordConfirmField;
    private static javax.swing.JPasswordField newAccountPasswordField;
    private javax.swing.JLabel newAccountPasswordStrengthLabel;
    private javax.swing.JSeparator newAccountSeparator;
    private javax.swing.JCheckBox newAccountShowPhraseCheckBox;
    public static javax.swing.JProgressBar newAccountjProgressBar;
    private javax.swing.JLabel newAccountlPasswordConfirmFieldLabel;
    private javax.swing.JLabel newAccountlPasswordFieldLabel;
    public static javax.swing.JMenuItem preferencesMenuItem;
    public static javax.swing.JMenu settingsMenu;
    public static javax.swing.JMenuItem showAccountDetailsItem;
    public static javax.swing.JMenuItem showCopyAddressItem;
    public static javax.swing.JPopupMenu showDetailPopup;
    public static javax.swing.JMenuItem showGenerateTokenItem;
    private javax.swing.JLabel showPreferecesBackgroundLabel;
    private javax.swing.JLabel showPreferenceKeySizesLabel;
    private javax.swing.JCheckBox showPreferencesANSICheckbox;
    private javax.swing.JLabel showPreferencesANSILabel;
    private javax.swing.JLabel showPreferencesClearClipboardLabel;
    private javax.swing.JSpinner showPreferencesClearClipboardSpinner;
    private javax.swing.JFrame showPreferencesFrame;
    private javax.swing.JLabel showPreferencesIterationLabel;
    private javax.swing.JSpinner showPreferencesIterationSpinner;
    public static javax.swing.JComboBox showPreferencesKeySizeComboBox;
    private javax.swing.JLabel showPreferencesLengthMaximumLabel;
    private javax.swing.JSpinner showPreferencesLengthMaximumMaxSpinner;
    private javax.swing.JSpinner showPreferencesLengthMaximumMinSpinner;
    private javax.swing.JLabel showPreferencesLengthMinimumLabel;
    private javax.swing.JSpinner showPreferencesLengthMinimumMaxSpinner;
    private javax.swing.JSpinner showPreferencesLengthMinimumMinSpinner;
    private javax.swing.JLabel showPreferencesLowerCaseLabel;
    private javax.swing.JSpinner showPreferencesLowerCaseMaxSpinner;
    private javax.swing.JSpinner showPreferencesLowerCaseMinSpinner;
    private javax.swing.JLabel showPreferencesNumeraryLabel;
    private javax.swing.JSpinner showPreferencesNumeraryMaxSpinner;
    private javax.swing.JSpinner showPreferencesNumeraryMinSpinner;
    private javax.swing.JButton showPreferencesOKButton;
    private javax.swing.JLabel showPreferencesPhraseBlocksLabel;
    private javax.swing.JSpinner showPreferencesPhraseBlocksSpinner;
    private javax.swing.JCheckBox showPreferencesRandomGenerationCheckbox;
    private javax.swing.JLabel showPreferencesRandomGenerationLabel;
    private javax.swing.JButton showPreferencesResetSettingsButton;
    private javax.swing.JLabel showPreferencesSpecialCharLabel;
    private javax.swing.JSpinner showPreferencesSpecialCharMaxSpinner;
    private javax.swing.JSpinner showPreferencesSpecialCharMinSpinner;
    private javax.swing.JLabel showPreferencesUpperCaseLabel;
    private javax.swing.JSpinner showPreferencesUpperCaseMaxSpinner;
    private javax.swing.JSpinner showPreferencesUpperCaseMinSpinner;
    private javax.swing.JCheckBox showPreferencesWarningsCheckbox;
    private javax.swing.JLabel showPreferencesWarningsLabel;
    private javax.swing.JCheckBox showPreferencesWhitespaceCheckbox;
    private javax.swing.JLabel showPreferencesWhitespaceLabel;
    private javax.swing.JSeparator showPreferencesjSeparator;
    // End of variables declaration//GEN-END:variables

}
